@@ -60,6 +60,7 @@
 #include "Interfaces/cpc/irconf.h"
 #include "vpr09Config.h"
 #include "SAPDBCommon/SAPDB_Names.h"
+#include "RunTime/RTE_IniFileHandling.h"
 
 #ifdef WIN32
 #define IRCONF_DEFAULTPATH "%INSTROOT%"
@@ -150,6 +151,8 @@ int main(int argc, char ** argv)
   ConfigHandle_tpr09 hConfig;
   ConfigResult_tpr09 ret;
   Result_irconf result;
+
+  RTE_InitIniFileHandling( );
   if ( argc <= 1 ) {
     return(irconf_PrintUsage(argc, argv));
   }
