@@ -39,6 +39,8 @@
 
 #include "gsp00.h"
 #include "DataAccess/Data_Types.hpp"
+#include "Converter/Converter_Types.hpp"
+
 
 class IOMan_BlockAddress;
 class Converter_LeafPage;
@@ -67,10 +69,14 @@ public:
                 occupied blocks of the database are marked within the FBM to
                 be included in the back up
        @param   taskId [in] task id
-       @return  none
+       @return  Converter_ReturnCode
+                - Converter_Ok
+                - Converter_MemoryAllocationFailed
      */
 
-    virtual void BeginSaveData( const tsp00_TaskId taskId ) = 0;
+    virtual Converter_ReturnCode BeginSaveData( const tsp00_TaskId taskId ) = 0;
+
+	virtual Converter_ReturnCode CheckConverterFBM( const tsp00_TaskId taskId ) = 0;
 
     /*!
        @brief   Starts a differential backup (also called save pages). All
@@ -79,10 +85,12 @@ public:
                 to be included in the back up. A list off all page numbers
                 used in the current data base is created
        @param   taskId [in] task id
-       @return  none
+       @return  Converter_ReturnCode
+                - Converter_Ok
+                - Converter_MemoryAllocationFailed
      */
 
-    virtual void BeginSavePages( const tsp00_TaskId taskId ) = 0;
+    virtual Converter_ReturnCode BeginSavePages( const tsp00_TaskId taskId ) = 0;
 
     /*!
         @brief  Ends the backup of data or pages. The back up active flag in
