@@ -37,6 +37,12 @@
 #include "Converter/Converter_MapControl.hpp"
 #include "Converter/Converter_MapSection.hpp"
 #include "Converter/Converter_Dump.hpp"
+#include "Converter/Converter_BlockAddressIterator.hpp"
+#include "Converter/Converter_Exception.hpp"
+#include "Converter/Converter_MapError.hpp"
+
+#include "FreeBlockManagement/FBM_IManager.hpp"
+
 #include "KernelCommon/Kernel_Dump.hpp"
 
 
@@ -208,6 +214,108 @@ Converter_MapControl::RequestNewPageNo(
 
     return( bFound );
 }
+/*---------------------------------------------------------------------------*/
+
+Converter_ReturnCode
+Converter_MapControl::MarkPagesForCheckConverterFBM(
+			const tsp00_TaskId  taskId, 
+			SAPDB_UInt&         numPages,
+			SAPDB_UInt&         numReserved)
+{
+	SAPDBTRACE_ROUTINE_DEBUG( "MapControl::MarkPagesForCheckConverterFBM", Converter_Trace, 5 );
+
+	numPages          = 0;
+	numReserved       = 0;
+	SAPDB_UInt pages  = 0;
+	SAPDB_UInt reserved = 0;
+
+	Converter_MapSection    sections[ MAX_CONVERTER_SECTIONS ];
+
+	SectionDataIterator         iter;
+	const SectionDataIterator   endIter = m_SectionData.End();
+
+	for( iter = m_SectionData.Begin(); iter != endIter; ++iter )
+	{
+		sections[ GetSectionNo( iter ) ].Lock( taskId, *iter );
+	}
+	
+	for( SAPDB_UInt sectionNo = 0; sectionNo < GetSectionCount(); ++sectionNo )
+	{
+		/* lock the current section to keep the chains of PartiallyUsedEntries  */
+		/* and FullEntries constant while the iterators walk along this chains  */
+
+		//Converter_MapSection section( taskId, m_SectionData[ sectionNo ]);
+
+		// iterator over partially used entry chain
+
+		Converter_MapSection::PartiallyUsedEntryIterator
+		partUsedIter = sections[sectionNo].PartiallyUsedEntriesBegin();
+
+		const Converter_MapSection::PartiallyUsedEntryIterator
+		partUsedEndIter = sections[sectionNo].PartiallyUsedEntriesEnd();
+
+		for( ; partUsedIter != partUsedEndIter; ++partUsedIter )
+		{
+			SAPDBERR_ASSERT_STATE( ! (*partUsedIter).PageIsFull() );
+
+			MarkPagesForCheckFBM( taskId, sections[sectionNo], (*partUsedIter).GetPage(), pages, reserved );
+			numPages += pages;
+			numReserved += reserved;
+		}
+
+		// iterator over full used entry chain
+
+		Converter_MapSection::FullEntryUsedIterator
+		fullUsedIter = sections[sectionNo].FullUsedEntriesBegin();
+
+		const Converter_MapSection::FullEntryUsedIterator
+		fullUsedEndIter = sections[sectionNo].FullUsedEntriesEnd();
+
+		for( ; fullUsedIter != fullUsedEndIter; ++fullUsedIter )
+		{
+			SAPDBERR_ASSERT_STATE( (*fullUsedIter).PageIsFull() );
+
+			MarkPagesForCheckFBM( taskId, sections[sectionNo], (*fullUsedIter).GetPage(), pages, reserved );
+			numPages += pages;
+			numReserved += reserved;
+		}
+	}
+	return( Converter_Ok );
+}
+
+void
+Converter_MapControl::MarkPagesForCheckFBM(
+	const tsp00_TaskId          taskId,
+	Converter_MapSection    &section,
+	Converter_LeafPage          &leafPage,
+	SAPDB_UInt                  &numPages,
+	SAPDB_UInt                  &numReserved)
+{
+	SAPDBERR_ASSERT_STATE( leafPage.GetEntryCount() > 0);
+
+	numReserved = 0;
+	Converter_BlockAddressIterator leafIter = leafPage.elements();
+
+	if( SAPDB_TRUE != FBM_IManager::Instance().SetBlockStateToBackup( taskId, leafIter, numPages ))
+	{
+		Converter_Exception errMsg( __CONTEXT__, CONVERTER_BAD_ENTRY_STATE,
+									SAPDB_ToString( leafPage.GetPageNo( leafIter.GetPosition()), _T_d),
+									((GetRecoveryMode().UseDynamicPageAddressing()) ? "perm" : "static"));
+		RTE_Crash( errMsg );
+	}
+	
+	Converter_PageEntryIterator iter = leafPage.Begin();
+	Converter_PageEntryIterator endIter = leafPage.End();
+	while(iter != endIter)
+	{
+		if ((iter.EntryInUse()) && (iter.GetPackedBlockAddress().IsReserved()))
+		{
+			numReserved++;
+		}
+		++iter;
+	}
+}
+
 
 /*---------------------------------------------------------------------------*/
 
