@@ -60,6 +60,11 @@
 #include "hsp41.h"
 #include "hsp81.h"
 
+/* PTS 1139212 */
+#ifndef HSP77_H
+#include "hsp77.h"
+#endif
+
 #include "livecachetypes.h"  /* no check */
 #include "SAPDBCommon/SAPDB_MemCopyMove.hpp"
 
@@ -112,7 +117,7 @@ int SQL_ColumnDesc::addParmToBuffer( PIn_Part * part,
   int  rc = 1;
   char buf1[32];
   char buf2[6];
-  char buf3[6];
+  char buf3[7]; // PTS 1139212
 
   switch (vfi.vtype) {
     case SqlCol::VBYTE_DB :
@@ -129,9 +134,13 @@ int SQL_ColumnDesc::addParmToBuffer( PIn_Part * part,
           rc = addParmVBool( part, sess, stmt, idx );
           break;
         default :
-          sprintf( buf1, "Prm:%d", idx);
-          sprintf( buf2, "VT:%x", vfi.vtype);                   /* PTS 1111983 %d -> %x */
-          sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+          // PTS 1139212
+          // sprintf( buf1, "Prm:%d", idx);
+          // sprintf( buf2, "VT:%x", vfi.vtype);                   /* PTS 1111983 %d -> %x */
+          // sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+          sp77sprintf( buf1, sizeof(buf1), "Prm:%d", idx);
+          sp77sprintf( buf2, sizeof(buf2), "VT:%x", vfi.vtype);                   /* PTS 1111983 %d -> %x */
+          sp77sprintf( buf3, sizeof(buf3), "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
           sess.setRtError( e_incompatible_datatype, buf1, buf2, buf3 );
           rc = 0;
           break;
@@ -159,9 +168,13 @@ int SQL_ColumnDesc::addParmToBuffer( PIn_Part * part,
       rc = addParmVBool( part, sess, stmt, idx );
       break;
     default :
-      sprintf( buf1, "Prm:%d", idx );
-      sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
-      sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+      // PTS 1139212
+      // sprintf( buf1, "Prm:%d", idx );
+      // sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+      // sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+      sp77sprintf( buf1, sizeof(buf1), "Prm:%d", idx );
+      sp77sprintf( buf2, sizeof(buf2), "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+      sp77sprintf( buf3, sizeof(buf3), "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
       sess.setRtError( e_incompatible_datatype, buf1, buf2, buf3 );
       rc = 0;
       break;
@@ -178,7 +191,7 @@ int SQL_ColumnDesc::addOpenLongDataToBuffer( PIn_Part * part,
   int  rc = 1;
   char buf1[32];
   char buf2[6];
-  char buf3[6];
+  char buf3[7]; // PTS 1139212
 
   switch (sfi.sp1i_data_type) {
     case dstra :
@@ -199,9 +212,13 @@ int SQL_ColumnDesc::addOpenLongDataToBuffer( PIn_Part * part,
           rc = addParmVSTDString( part, sess, stmt, idx );
           break;
         default :
-          sprintf( buf1, "Prm:%d", idx );
-          sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
-          sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+          // PTS 1139212
+          // sprintf( buf1, "Prm:%d", idx );
+          // sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+          // sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+          sp77sprintf( buf1, sizeof(buf1), "Prm:%d", idx );
+          sp77sprintf( buf2, sizeof(buf2), "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+          sp77sprintf( buf3, sizeof(buf3), "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
           sess.setRtError( e_incompatible_datatype, buf1, buf2, buf3 );
           rc = 0;
       }
@@ -287,7 +304,7 @@ int SQL_ColumnDesc::getParmFromBuffer( const teo00_Byte * dataPtr,
   int  rc = 1;
   char buf1[32];
   char buf2[6];
-  char buf3[6];
+  char buf3[7]; // PTS 1139212
 
   vfi.ind = 0;     /* PTS 1112804 */
 
@@ -306,9 +323,13 @@ int SQL_ColumnDesc::getParmFromBuffer( const teo00_Byte * dataPtr,
           rc = getParmVBool( dataPtr, sess, stmt, idx );
           break;
       default :
-        sprintf( buf1, "Prm:%d", idx );
-        sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
-        sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+        // PTS 1139212
+        // sprintf( buf1, "Prm:%d", idx );
+        // sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+        // sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+        sp77sprintf( buf1, sizeof(buf1), "Prm:%d", idx );
+        sp77sprintf( buf2, sizeof(buf2), "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+        sp77sprintf( buf3, sizeof(buf3), "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
         sess.setRtError( e_incompatible_datatype, buf1, buf2, buf3 );
         rc = 0;
       }
@@ -335,9 +356,13 @@ int SQL_ColumnDesc::getParmFromBuffer( const teo00_Byte * dataPtr,
       rc = getParmVBool( dataPtr,sess, stmt, idx );
       break;
     default :
-      sprintf( buf1, "Prm:%d", idx );
-      sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
-      sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+      // PTS 1139212
+      // sprintf( buf1, "Prm:%d", idx );
+      // sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+      // sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+      sp77sprintf( buf1, sizeof(buf1), "Prm:%d", idx );
+      sp77sprintf( buf2, sizeof(buf2), "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+      sp77sprintf( buf3, sizeof(buf3), "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
       sess.setRtError( e_incompatible_datatype, buf1, buf2, buf3 );
       rc = 0;
   }
@@ -488,11 +513,15 @@ int SQL_ColumnDesc::getOpenLongDataFromBuffer( const tsp00_Byte * dataPtr,
             if (converted_len < (unsigned int)len) {
               char buf1[32];
               char buf2[6];
-              char buf3[6];
+              char buf3[7]; // PTS 1139212
               vfi.ind = converted_len + 1;
-              sprintf( buf1, "Prm:%d", idx );
-              sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
-              sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+              // PTS 1139212
+              // sprintf( buf1, "Prm:%d", idx );
+              // sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+              // sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+              sp77sprintf( buf1, sizeof(buf1), "Prm:%d", idx );
+              sp77sprintf( buf2, sizeof(buf2), "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+              sp77sprintf( buf3, sizeof(buf3), "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
               sess.setRtError( e_uni_to_ascii_conv_failed,
                                buf1, buf2, buf3 );
               rc = 0;
@@ -556,7 +585,7 @@ int SQL_ColumnDesc::addParmVBool( PIn_Part * part,
   int  rc = 1;
   char buf1[32];
   char buf2[6];
-  char buf3[6];
+  char buf3[7]; // PTS 1139212
 
   switch (sfi.sp1i_data_type) {
     case dboolean :
@@ -580,9 +609,13 @@ int SQL_ColumnDesc::addParmVBool( PIn_Part * part,
   }
 
   if (0 == rc) {
-    sprintf( buf1, "Prm:%d", idx );
-    sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
-    sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+    // PTS 1139212
+    // sprintf( buf1, "Prm:%d", idx );
+    // sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+    // sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+    sp77sprintf( buf1, sizeof(buf1), "Prm:%d", idx );
+    sp77sprintf( buf2, sizeof(buf2), "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+    sp77sprintf( buf3, sizeof(buf3), "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
     sess.setRtError( e_incompatible_datatype, buf1, buf2, buf3 );
   }
   return rc;
@@ -603,7 +636,7 @@ int SQL_ColumnDesc::addParmVChar( PIn_Part * part,
   tsp00_DataType   data_type;
   char             buf1[32];
   char             buf2[6];
-  char             buf3[6];
+  char             buf3[7]; // PTS 1139212
   char defChar;
 
   UCS2Blank.s = 32;
@@ -1039,9 +1072,13 @@ int SQL_ColumnDesc::addParmVChar( PIn_Part * part,
   }
 
   if (0 >= rc) { /* PTS 1130628 */
-    sprintf( buf1, "Prm:%d", idx );
-    sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
-    sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+    // PTS 1139212
+    // sprintf( buf1, "Prm:%d", idx );
+    // sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+    // sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+    sp77sprintf( buf1, sizeof(buf1), "Prm:%d", idx );
+    sp77sprintf( buf2, sizeof(buf2), "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+    sp77sprintf( buf3, sizeof(buf3), "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
     sess.setRtError( rtError, buf1, buf2, buf3 );
   }
   return rc;
@@ -1058,7 +1095,7 @@ int SQL_ColumnDesc::addParmVNum( PIn_Part * part,
   tgg00_BasisError rtError;
   char             buf1[32];
   char             buf2[6];
-  char             buf3[6];
+  char             buf3[7]; // PTS 1139212
 
   switch (sfi.sp1i_data_type) {
     case dfixed :
@@ -1203,9 +1240,13 @@ int SQL_ColumnDesc::addParmVNum( PIn_Part * part,
   }
 
   if (0 == rc) {
-    sprintf( buf1, "Prm:%d", idx );
-    sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
-    sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+    // PTS 1139212
+    // sprintf( buf1, "Prm:%d", idx );
+    // sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+    // sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+    sp77sprintf( buf1, sizeof(buf1), "Prm:%d", idx );
+    sp77sprintf( buf2, sizeof(buf2), "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+    sp77sprintf( buf3, sizeof(buf3), "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
     sess.setRtError( rtError, buf1, buf2, buf3 );
   }
   return rc;
@@ -1229,7 +1270,7 @@ int SQL_ColumnDesc::getParmVBool( const teo00_Byte * dataPtr,
   int  rc = 1;
   char buf1[32];
   char buf2[6];
-  char buf3[6];
+  char buf3[7]; // PTS 1139212
 
   switch (sfi.sp1i_data_type) {
     case dboolean :
@@ -1251,9 +1292,13 @@ int SQL_ColumnDesc::getParmVBool( const teo00_Byte * dataPtr,
   }
 
   if (0 == rc) {
-    sprintf( buf1, "Prm:%d", idx );
-    sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
-    sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+    // PTS 1139212
+    // sprintf( buf1, "Prm:%d", idx );
+    // sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+    // sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+    sp77sprintf( buf1, sizeof(buf1), "Prm:%d", idx );
+    sp77sprintf( buf2, sizeof(buf2), "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+    sp77sprintf( buf3, sizeof(buf3), "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
     sess.setRtError( e_incompatible_datatype, buf1, buf2, buf3 );
   }
   return rc;
@@ -1274,7 +1319,7 @@ int SQL_ColumnDesc::getParmVChar( const teo00_Byte * dataPtr,
   tsp00_DataType   data_type;
   char             buf1[32];
   char             buf2[6];
-  char             buf3[6];
+  char             buf3[7]; // PTS 1139212
   char             defChar;
 
   UCS2Blank.s = 32;
@@ -1685,9 +1730,13 @@ int SQL_ColumnDesc::getParmVChar( const teo00_Byte * dataPtr,
   }
 
   if (rc <= 0) { /* PTS 1130628 */
-    sprintf( buf1, "Prm:%d", idx );
-    sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
-    sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+    // PTS 1139212
+    // sprintf( buf1, "Prm:%d", idx );
+    // sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+    // sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+    sp77sprintf( buf1, sizeof(buf1), "Prm:%d", idx );
+    sp77sprintf( buf2, sizeof(buf2), "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+    sp77sprintf( buf3, sizeof(buf3), "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
     sess.setRtError( rtError, buf1, buf2, buf3 );
   }
   return rc;
@@ -1704,7 +1753,7 @@ int SQL_ColumnDesc::getParmVNum( const teo00_Byte * dataPtr,
   tgg00_BasisError rtError;
   char             buf1[32];
   char             buf2[6];
-  char             buf3[6];
+  char             buf3[7]; // PTS 1139212
 
   switch (sfi.sp1i_data_type) {
     case dfixed :
@@ -1864,9 +1913,13 @@ int SQL_ColumnDesc::getParmVNum( const teo00_Byte * dataPtr,
   }
 
   if (0 == rc) {
-    sprintf( buf1, "Prm:%d", idx );
-    sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
-    sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+    // PTS 1139212
+    // sprintf( buf1, "Prm:%d", idx );
+    // sprintf( buf2, "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+    // sprintf( buf3, "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
+    sp77sprintf( buf1, sizeof(buf1), "Prm:%d", idx );
+    sp77sprintf( buf2, sizeof(buf2), "VT:%x", vfi.vtype );                  /* PTS 1111983 %d -> %x */
+    sp77sprintf( buf3, sizeof(buf3), "DBT:%x", (int)(sfi.sp1i_data_type) ); /* PTS 1111983 %d -> %x */
     sess.setRtError( rtError, buf1, buf2, buf3 );
   }
   return rc;
