@@ -6,9 +6,8 @@
                   from a backup history
 
 \if EMIT_LICENCE
-
     ========== licence begin  GPL
-    Copyright (c) 2002-2005 SAP AG
+    Copyright (c) 2002-2007 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -24,9 +23,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
-
-
-
 \endif
 */
 
@@ -486,7 +482,7 @@ tcn00_Error DBMSrvBHist_RestorePlanner::RestoreABackup(const DBMSrvBHist_Restore
 
             if(0!=Medium) //add the medium with help of an artificial group
             {
-                rc=cn30AddMedium(replyData, replyLen, &Media, Medium);
+                rc=cn30AddMedium(replyData, replyLen, replyLenMax, &Media, Medium);
 
                 if(OK_CN00!=rc)
                 {
@@ -558,27 +554,30 @@ tcn00_Error DBMSrvBHist_RestorePlanner::RestoreABackup(const DBMSrvBHist_Restore
                                   replyLen,
                                   replyLenMax);
 
-        rc=cn31BackupSession(vcontrol, replyData, replyLen, &pBackupSession);
-
-        //do explicit autoignore, if needed
-        if(OK_CN00==rc &&
-           (0==Backup->NextNeededBackup() ||                                                                                        //if this is the last backup
-            0!=cn36_StrUprCmp(Backup->getBackup()->GiveBackupType(), Backup->NextNeededBackup()->getBackup()->GiveBackupType())))   //the next backup has not the same type (e.g. LOG after Pages, but not LOG after LOG)
+        if(OK_CN00==rc)
         {
-            while(OK_CN00==rc &&
-                  BA_NEXTMEDIUM_RC_CN003==pBackupSession->tBackupResult.nBackupRC) //we got a -8020 from the kernel
+            rc=cn31BackupSession(vcontrol, replyData, replyLen, &pBackupSession);
+
+            //do explicit autoignore, if needed
+            if(OK_CN00==rc &&
+            (0==Backup->NextNeededBackup() ||                                                                                        //if this is the last backup
+                0!=cn36_StrUprCmp(Backup->getBackup()->GiveBackupType(), Backup->NextNeededBackup()->getBackup()->GiveBackupType())))   //the next backup has not the same type (e.g. LOG after Pages, but not LOG after LOG)
             {
-                if(0!=pBackupSession->pBackupTool)    //If we used a backup tool, forget it (so we make sure that cn31BackupRestoreIgnore(...) works as advertised)
+                while(OK_CN00==rc &&
+                    BA_NEXTMEDIUM_RC_CN003==pBackupSession->tBackupResult.nBackupRC) //we got a -8020 from the kernel
                 {
-                    delete pBackupSession->pBackupTool;
-                    pBackupSession->pBackupTool=0;
+                    if(0!=pBackupSession->pBackupTool)    //If we used a backup tool, forget it (so we make sure that cn31BackupRestoreIgnore(...) works as advertised)
+                    {
+                        delete pBackupSession->pBackupTool;
+                        pBackupSession->pBackupTool=0;
+                    }
+
+                    rc=cn31BackupRestoreIgnore(vcontrol, &DummyCommand, replyData, replyLen, replyLenMax);
                 }
-
-                rc=cn31BackupRestoreIgnore(vcontrol, &DummyCommand, replyData, replyLen, replyLenMax);
             }
-        }
 
-        BackupResult=pBackupSession->tBackupResult.nBackupRC;
+            BackupResult=pBackupSession->tBackupResult.nBackupRC;
+        }
     }
 
     return rc;
@@ -922,13 +921,13 @@ tcn00_Error DBMSrvBHist_RestorePlanner::DetermineRestartInfo(VControlDataT * vco
 
     if(OK_CN00==rc)
     {
-        if(!cn36_StrToUInt8(UsedLogPage, RestartInfo.szUsedLogPage))
-            rc=cn90AnswerEvent(replyData, replyLen, teo200_EventList(FUNCTION_NAME_MCN00_1, ERR_UTLIOSEQNEED_CN00_1, RestartInfo.szUsedLogPage));
+        if(!cn36_StrToUInt8(UsedLogPage, RestartInfo.FirstIoSequenceNeeded))
+            rc=cn90AnswerEvent(replyData, replyLen, teo200_EventList(FUNCTION_NAME_MCN00_1, ERR_UTLIOSEQNEED_CN00_1, RestartInfo.FirstIoSequenceNeeded));
 
-        if(!cn36_StrToUInt8(FirstLogPage, RestartInfo.szFirstLogPage))
-            rc=cn90AnswerEvent(replyData, replyLen, teo200_EventList(FUNCTION_NAME_MCN00_1, ERR_UTLIOSEQAVAIL_CN00_1, RestartInfo.szFirstLogPage));
+        if(!cn36_StrToUInt8(FirstLogPage, RestartInfo.FirstIoSequenceOnLog))
+            rc=cn90AnswerEvent(replyData, replyLen, teo200_EventList(FUNCTION_NAME_MCN00_1, ERR_UTLIOSEQAVAIL_CN00_1, RestartInfo.FirstIoSequenceOnLog));
 
-        Restartable=(RestartInfo.szRestartable[0]=='1');
+        Restartable=(RestartInfo.Restartable[0]=='1');
     }
 
     return rc;
