@@ -44,13 +44,36 @@
 
 extern DBA_error gError;
 
-#define DBA_SQL_PARAM_INSTANCETYPE  "SELECT VALUE FROM DBPARAMETERS WHERE DESCRIPTION = 'INSTANCE_TYPE'"
-#define DBA_SQL_INFO_KERNELVERSION  "SELECT KERNEL FROM VERSIONS"
-#define DBA_SQL_PARAM_RUNDIRECTORY  "SELECT VALUE FROM DBPARAMETERS WHERE DESCRIPTION = 'RUNDIRECTORY'"
-#define DBA_SQL_INFO_SESSION        "SELECT SESSION FROM CONNECTPARAMETERS"
-#define DBA_SQL_INFO_PID            "SELECT T.APPLPROCESS FROM TRANSACTIONS T,CONNECTPARAMETERS C WHERE T.SESSION = C.SESSION"
-#define DBA_SQL_CHECK_ANALYZER      "SELECT T.APPLPROCESS FROM TRANSACTIONS T,CONNECTPARAMETERS C WHERE T.SESSION = %u AND T.APPLPROCESS = %u"
-#define DBA_SQL_INFO_DATETIME       "SELECT YEAR(NOW()),MONTH(NOW()),DAY(NOW()),HOUR(NOW()),MINUTE(NOW()),SECOND(NOW()) FROM DUAL"
+#define DBA_NEW_SQL_PARAM_INSTANCETYPE  "SELECT VALUE FROM SYSINFO.ACTIVECONFIGURATION  WHERE PARAMETERNAME = 'INSTANCE_TYPE'"
+#define DBA_NEW_SQL_INFO_KERNELVERSION  "SELECT ID FROM  SYSINFO.VERSION"
+#define DBA_NEW_SQL_PARAM_RUNDIRECTORY  "SELECT VALUE FROM SYSINFO.ACTIVECONFIGURATION  WHERE PARAMETERNAME = 'RUNDIRECTORY'"
+#define DBA_NEW_SQL_INFO_SESSION        "SELECT SESSIONID FROM SYSINFO.SESSIONS WHERE OWN='YES'"
+#define DBA_NEW_SQL_CHECK_SESSION       "SELECT SESSIONID FROM SYSINFO.SESSIONS WHERE OWN='YES' AND SESSIONID=%d"
+#define DBA_NEW_SQL_INFO_PID            "SELECT APPLICATIONPROCESS FROM SYSINFO.SESSIONS WHERE OWN='YES'"
+#define DBA_NEW_SQL_CHECK_ANALYZER      "SELECT APPLICATIONPROCESS FROM SYSINFO.SESSIONS WHERE SESSIONID=%u AND APPLICATIONPROCESS=%u"
+#define DBA_NEW_SQL_INFO_DATETIME       "SELECT YEAR(NOW()),MONTH(NOW()),DAY(NOW()),HOUR(NOW()),MINUTE(NOW()),SECOND(NOW()) FROM DUAL"
+
+#define DBA_OLD_SQL_PARAM_INSTANCETYPE  "SELECT VALUE FROM DBPARAMETERS WHERE DESCRIPTION = 'INSTANCE_TYPE'"
+#define DBA_OLD_SQL_INFO_KERNELVERSION  "SELECT KERNEL FROM VERSIONS"
+#define DBA_OLD_SQL_PARAM_RUNDIRECTORY  "SELECT VALUE FROM DBPARAMETERS WHERE DESCRIPTION = 'RUNDIRECTORY'"
+#define DBA_OLD_SQL_INFO_SESSION        "SELECT SESSION FROM CONNECTPARAMETERS"
+#define DBA_OLD_SQL_CHECK_SESSION       "SELECT SESSION FROM CONNECTPARAMETERS WHERE SESSION=%d"
+#define DBA_OLD_SQL_INFO_PID            "SELECT T.APPLPROCESS FROM TRANSACTIONS T,CONNECTPARAMETERS C WHERE T.SESSION = C.SESSION"
+#define DBA_OLD_SQL_CHECK_ANALYZER      "SELECT T.APPLPROCESS FROM TRANSACTIONS T,CONNECTPARAMETERS C WHERE T.SESSION = %u AND T.APPLPROCESS = %u"
+#define DBA_OLD_SQL_INFO_DATETIME       DBA_NEW_SQL_INFO_DATETIME
+
+#define DBA_SQL_PARAM_INSTANCETYPE     (m_bUseOldSysTables ? DBA_OLD_SQL_PARAM_INSTANCETYPE : DBA_NEW_SQL_PARAM_INSTANCETYPE)
+#define DBA_SQL_INFO_KERNELVERSION     (m_bUseOldSysTables ? DBA_OLD_SQL_INFO_KERNELVERSION : DBA_NEW_SQL_INFO_KERNELVERSION)
+#define DBA_SQL_PARAM_RUNDIRECTORY     (m_bUseOldSysTables ? DBA_OLD_SQL_PARAM_RUNDIRECTORY : DBA_NEW_SQL_PARAM_RUNDIRECTORY)
+#define DBA_SQL_INFO_SESSION           (m_bUseOldSysTables ? DBA_OLD_SQL_INFO_SESSION       : DBA_NEW_SQL_INFO_SESSION      )
+#define DBA_SQL_CHECK_SESSION          (m_bUseOldSysTables ? DBA_OLD_SQL_CHECK_SESSION      : DBA_NEW_SQL_CHECK_SESSION     )
+#define DBA_SQL_INFO_PID               (m_bUseOldSysTables ? DBA_OLD_SQL_INFO_PID           : DBA_NEW_SQL_INFO_PID          )
+#define DBA_SQL_CHECK_ANALYZER         (m_bUseOldSysTables ? DBA_OLD_SQL_CHECK_ANALYZER     : DBA_NEW_SQL_CHECK_ANALYZER    )
+#define DBA_SQL_INFO_DATETIME          (m_bUseOldSysTables ? DBA_OLD_SQL_INFO_DATETIME      : DBA_NEW_SQL_INFO_DATETIME     )
+
+#define DBA_SQL_LOCK_CHECK             "EXISTS TABLE SYSDBANA.DBANLOCK"
+#define DBA_SQL_LOCK_LOCK              "LOCK (WAIT) TABLE SYSDBANA.DBANLOCK IN EXCLUSIVE MODE"
+#define DBA_SQL_COMMIT                 "COMMIT"
 
 class DBA_handles {
 private:
@@ -75,9 +98,6 @@ DBA_database::DBA_database (const DBA_string & sServer,
                m_sUser(sUser),
                m_sPassword(sPassword)
 {
-  m_bReconnectEnabled = false;
-  m_bReconnect = false;
-
   m_pError = NULL;
 
   m_pHandles = new DBA_handles();
@@ -87,6 +107,8 @@ DBA_database::DBA_database (const DBA_string & sServer,
   m_sRundirectory  = "";
   m_nSid           = 0;
   m_nPid           = 0;
+
+  m_bUseOldSysTables = false;
 } // end DBA_database::DBA_database
 
 // ========================================================
@@ -167,7 +189,7 @@ DBA_bool DBA_database::Connect()
     m_sPassword.ToUpper();
   } // end if
 
-  m_sDriver = "SAP DB <MAJOR_VERSION>.<MINOR_VERSION>";
+  m_sDriver = "MaxDB <MAJOR_VERSION>.<MINOR_VERSION>";
   sprintf((char *)sConnect, "DRIVER=%s;SERVERDB=%s;SERVERNODE=%s;UID=%s;PWD=%s",
           m_sDriver.CharPtr(),
           m_sDatabase.CharPtr(),
@@ -182,7 +204,7 @@ DBA_bool DBA_database::Connect()
   bool bError =  (!m_pError->checkSQLReturnCode(nRC, NULL));
 
   if (bError && (m_pError->getSQLStateErrorNumber() == "IM002")) {
-    m_sDriver = "SAP DB";
+    m_sDriver = "MaxDB";
     sprintf((char *)sConnect, "DRIVER=%s;SERVERDB=%s;SERVERNODE=%s;UID=%s;PWD=%s",
             m_sDriver.CharPtr(),
             m_sDatabase.CharPtr(),
@@ -195,24 +217,27 @@ DBA_bool DBA_database::Connect()
   } // end if
 
   if (bError) {
-    CheckReconnectError(m_pError->getNativeError());
-    if (!m_bReconnectEnabled || !m_bReconnect) {
-      SQLFreeHandle(SQL_HANDLE_DBC, m_pHandles->hDbc);
-      SQLFreeHandle(SQL_HANDLE_ENV, m_pHandles->hEnv);
-      m_pHandles->hEnv = NULL;
-      m_pHandles->hDbc = NULL;
-      gError.SetError(DBA_ERR_CONNECT);
-      gError.SetExtText(GetErrorMsg());
-      return false;
-    } else {
-      gError.SetReconnect(true);
-      return true;
-    }
-  }
+    // create error object
+    gError.SetReconnect(CheckReconnectError(m_pError->getNativeError()));
+    gError.SetError(DBA_ERR_CONNECT);
+    gError.SetExtText(GetErrorMsg());
+
+    // free resources
+    SQLFreeHandle(SQL_HANDLE_DBC, m_pHandles->hDbc);
+    SQLFreeHandle(SQL_HANDLE_ENV, m_pHandles->hEnv);
+    m_pHandles->hEnv = NULL;
+    m_pHandles->hDbc = NULL;
 
-  if(!GetInfos()) {
     return false;
-  }
+  } // end if
+
+  if (SQLSetConnectAttr( m_pHandles->hDbc, SQL_ATTR_AUTOCOMMIT, (SQLPOINTER) SQL_AUTOCOMMIT_OFF, SQL_IS_UINTEGER ) != SQL_SUCCESS) {
+    SQLFreeHandle(SQL_HANDLE_DBC, m_pHandles->hDbc);
+    SQLFreeHandle(SQL_HANDLE_ENV, m_pHandles->hEnv);
+    m_pHandles->hEnv = NULL;
+    m_pHandles->hDbc = NULL;
+    return false;
+  } // end if
 
   return true;
 } // DBA_database::Connect
@@ -227,7 +252,8 @@ DBA_bool DBA_database::Execute(const DBA_string & sSQL, DBA_snapshot * pSnapshot
   if (!PrepareQuery(sSQL, pResult)) {
     return false;
   } // end if
-  return Execute(sSQL, pSnapshot, pResult);
+  DBA_bool bReturn = Execute(sSQL, pSnapshot, pResult);
+  return bReturn;
 } // end DBA_database::Execute
 
 // ========================================================
@@ -236,19 +262,29 @@ DBA_bool DBA_database::Execute(const DBA_string & sSQL, DBA_snapshot * pSnapshot
 DBA_bool DBA_database::PrepareQuery (const DBA_string & sSQL, StudioOAL_WResult * & pPreparedQuery)
 {
   gError.Clear(); 
+  bool bNew = false;
 
   if (pPreparedQuery == NULL) {
     pPreparedQuery = new StudioOAL_WResult(m_pHandles->hDbc, m_pHandles->hEnv);
     if (pPreparedQuery == NULL) {
       gError.SetError(DBA_ERR_NOMEM);
       return false;
-     } // end if
+    } // end if
+    bNew = true;
   } // end if
 
   if (!pPreparedQuery->openResultPrepare (sSQL)) {
-    gError.SetError(DBA_ERR_PREPARE);
+    gError.SetReconnect(CheckReconnectError(pPreparedQuery->getNativeError()));
+    gError.SetIgnore(CheckIgnoreError(pPreparedQuery->getNativeError()));
+    gError.SetError(DBA_ERR_PREPARE, pPreparedQuery->getNativeError());
     DBA_string sError = pPreparedQuery->getErrorText();
     gError.SetExtText(sError.Append("\n").Append(sSQL));
+
+    if (bNew) {
+      delete pPreparedQuery;
+      pPreparedQuery = NULL;
+    } // end if
+
     return false;
   } // end if
 
@@ -262,24 +298,6 @@ DBA_bool DBA_database::Execute (const DBA_string & sSQL, DBA_snapshot * pSnapsho
 {
   gError.Clear(); 
 
-  if (m_bReconnectEnabled && m_bReconnect) {
-    Disconnect();
-    if (!Connect()) {
-      return false;
-    } else {
-      if (gError.GetReconnect()) { 
-        return true;
-      } else {
-        m_bReconnect = false;
-        if (!PrepareQuery(sSQL, pPreparedQuery)) {
-          return false;
-        } // end if
-      } // end if
-    } // end if
-  } // end if
-
-  gError.SetIgnore(false);
-
   if (pPreparedQuery == NULL) {
     if (!PrepareQuery(sSQL, pPreparedQuery)) {
       return false;
@@ -287,35 +305,22 @@ DBA_bool DBA_database::Execute (const DBA_string & sSQL, DBA_snapshot * pSnapsho
   } // end if
 
   if (!pPreparedQuery->executePreparedStmt()) {
-    CheckReconnectError(pPreparedQuery->getNativeError());
-    if (!m_bReconnectEnabled || !m_bReconnect) {
-      if (CheckIgnoreError(pPreparedQuery->getNativeError())) {
-        gError.SetError(DBA_ERR_EXECUTE);
-        DBA_string sError = pPreparedQuery->getErrorText();
-        gError.SetExtText(sError.Append("\n").Append(sSQL));
-        gError.SetIgnore(true);
-        return true;
-      } else {
-        gError.SetError(DBA_ERR_EXECUTE);
-        DBA_string sError = pPreparedQuery->getErrorText();
-        gError.SetExtText(sError.Append("\n").Append(sSQL));
-        // prepare again
-        if (!PrepareQuery(sSQL, pPreparedQuery)) {
-          return false;
-        } // end if
-        // excute again
-        if (!pPreparedQuery->executePreparedStmt()) {
-          gError.SetError(DBA_ERR_EXECUTE);
-          DBA_string sError = pPreparedQuery->getErrorText();
-          gError.SetExtText(sError.Append("\n").Append(sSQL));
-          return false;
-        } // end if
-      } // end if
-    } else {
-      gError.SetReconnect(true);
-      return true;
-    }
-  }
+    // prepare again
+    if (!PrepareQuery(sSQL, pPreparedQuery)) {
+      return false;
+    } // end if
+
+    // execute again
+    gError.Clear(); 
+    if (!pPreparedQuery->executePreparedStmt()) {
+      gError.SetReconnect(CheckReconnectError(pPreparedQuery->getNativeError()));
+      gError.SetIgnore(CheckIgnoreError(pPreparedQuery->getNativeError()));
+      gError.SetError(DBA_ERR_EXECUTE, pPreparedQuery->getNativeError());
+      DBA_string sError = pPreparedQuery->getErrorText();
+      gError.SetExtText(sError.Append("\n").Append(sSQL));
+      return false;
+    } // end if
+  } // end if
 
   if (pSnapshot) {
     pSnapshot->Clear();  
@@ -336,25 +341,15 @@ DBA_bool DBA_database::Execute (const DBA_string & sSQL, DBA_snapshot * pSnapsho
     while (bFetch) {
       bFetch = pPreparedQuery->fetch();
       if(!bFetch) {
-        CheckReconnectError(pPreparedQuery->getNativeError());
-        if (!m_bReconnectEnabled || !m_bReconnect) {
-          if (CheckIgnoreError(pPreparedQuery->getNativeError())) {
-            gError.SetError(DBA_ERR_EXECUTE);
-            DBA_string sError = pPreparedQuery->getErrorText();
-            gError.SetExtText(sError.Append("\n").Append(sSQL));
-            gError.SetIgnore(true);
-            return true;
-          } else {
-            gError.SetError(DBA_ERR_EXECUTE);
-            DBA_string sError = pPreparedQuery->getErrorText();
-            gError.SetExtText(sError.Append("\n").Append(sSQL));
-            return false;
-          } // end if
-        } else {
-          gError.SetReconnect(true);
-          pPreparedQuery->closeCursor ();
-          return true;
-        }
+        gError.SetReconnect(CheckReconnectError(pPreparedQuery->getNativeError()));
+        gError.SetIgnore(CheckIgnoreError(pPreparedQuery->getNativeError()));
+
+        gError.SetError(DBA_ERR_EXECUTE, pPreparedQuery->getNativeError());
+        DBA_string sError = pPreparedQuery->getErrorText();
+        gError.SetExtText(sError.Append("\n").Append(sSQL));
+
+        pPreparedQuery->closeCursor ();
+        return false;
       } else {
         if (pPreparedQuery->noRows()) {
           pPreparedQuery->closeCursor ();
@@ -366,14 +361,13 @@ DBA_bool DBA_database::Execute (const DBA_string & sSQL, DBA_snapshot * pSnapsho
               pPreparedQuery->getColumnDataAsString(nCol+1, sValue);
               if (!pSnapshot->AddField(sValue)) {
                 return false;
-              }
-            }
-          }
-        }
-      }
-    }
-
-  } 
+              } // end if
+            } // end for
+          } // end if
+        }  // end if
+      } // end if
+    } // end while
+  } // end if
 
   pPreparedQuery->closeCursor ();
   return true;
@@ -404,11 +398,13 @@ DBA_bool DBA_database::Disconnect ()
 // ========================================================
 DBA_bool DBA_database::GetTimestamp(time_t & tTime)
 {
-  StudioOAL_WResult oResult(m_pHandles->hDbc, m_pHandles->hEnv);
   gError.Clear(); 
 
+  StudioOAL_WResult oResult(m_pHandles->hDbc, m_pHandles->hEnv);
+
   // select date and time
   if (!oResult.openResult(DBA_SQL_INFO_DATETIME)) {
+    gError.SetReconnect(CheckReconnectError(oResult.getNativeError()));
     gError.SetError(DBA_ERR_EXECUTE);
     DBA_string sError = oResult.getErrorText();
     gError.SetExtText(sError.Append("\n").Append(DBA_SQL_INFO_DATETIME));
@@ -416,8 +412,10 @@ DBA_bool DBA_database::GetTimestamp(time_t & tTime)
   } // end if
 
   if (!oResult.fetch()) {
+    gError.SetReconnect(CheckReconnectError(oResult.getNativeError()));
     gError.SetError(DBA_ERR_EXECUTE);
-    gError.SetExtText(oResult.getErrorText());
+    DBA_string sError = oResult.getErrorText();
+    gError.SetExtText(sError.Append("\n").Append(DBA_SQL_INFO_DATETIME));
     return false;
   } // end if
   
@@ -440,8 +438,10 @@ DBA_bool DBA_database::GetTimestamp(time_t & tTime)
     oTime.tm_isdst = -1;
     tTime = mktime(&oTime);
   } else {
+    gError.SetReconnect(CheckReconnectError(oResult.getNativeError()));
     gError.SetError(DBA_ERR_EXECUTE);
-    gError.SetExtText(DBA_SQL_INFO_DATETIME);
+    DBA_string sError = oResult.getErrorText();
+    gError.SetExtText(sError.Append("\n").Append(DBA_SQL_INFO_DATETIME));
     tTime = 0;
     return false;
   } // end if
@@ -466,6 +466,18 @@ DBA_bool DBA_database::GetInfos()
 
   gError.Clear(); 
 
+  // check for new systemtables
+  if (!oResult.openResult(DBA_NEW_SQL_PARAM_INSTANCETYPE)) {
+        if (oResult.getNativeError() == -4004) {
+            m_bUseOldSysTables = true;
+        } else {
+            gError.SetError(DBA_ERR_EXECUTE);
+            DBA_string sError = oResult.getErrorText();
+            gError.SetExtText(sError.Append("\n").Append(DBA_SQL_PARAM_INSTANCETYPE));
+            return false;
+        } 
+  }
+
   // get INSTANCE_TYPE from table DBPARAMETERS
   if (!oResult.openResult(DBA_SQL_PARAM_INSTANCETYPE)) {
     gError.SetError(DBA_ERR_EXECUTE);
@@ -578,40 +590,33 @@ DBA_bool DBA_database::GetInfos()
 
   oResult.closeResult();
 
-//
-  
   return true;
 } // DBA_database::GetInfos
 
 //
-// SetReconnect
+// CheckReconnectError
 //
-DBA_void DBA_database::ReconnectEnabled(const DBA_bool bEnabled) 
+DBA_bool DBA_database::CheckReconnectError
+  ( DBA_long nError ) const
 {
-  m_bReconnectEnabled = bEnabled;
-}
-
-//
-// IsReconnectError
-//
-DBA_bool DBA_database::CheckReconnectError(DBA_long nError)
-{
-  m_bReconnect = false;
-
   switch (nError) {
-    case DBA_ODBC_RECONNECT_ERR1:
-    case DBA_ODBC_RECONNECT_ERR2:
-    case DBA_ODBC_RECONNECT_ERR3:
-    case DBA_ODBC_RECONNECT_ERR4:
-    case DBA_ODBC_RECONNECT_ERR5:
-    case DBA_ODBC_RECONNECT_ERR6:
-    case DBA_ODBC_RECONNECT_ERR7:
-      m_bReconnect = true;
+    case    -708:
+    case    -709:
+    case    -807:
+    case    -906:
+    case    -907:
+    case   -9807:
+    case     710:
+    case  -10708:
+    case  -10709:
+    case  -10807:
+    case  -10906:
+    case  -10907:
       return true;
-    default:
-      return false;
-  }
-}
+  } // end switch
+
+  return false;
+} // end DBA_database::CheckReconnectError
 
 //
 // DBA_database::SetIgnoreErrors
@@ -671,7 +676,7 @@ DBA_string DBA_database::GetErrorMsg()
 }
 
 //
-// CheckSid
+// CheckAnalyzer
 // 
 DBA_bool DBA_database::CheckAnalyzer(DBA_uint nSid, DBA_uint nPid, const DBA_string & sDir)
 {
@@ -707,4 +712,85 @@ DBA_bool DBA_database::CheckAnalyzer(DBA_uint nSid, DBA_uint nPid, const DBA_str
   oResult.closeResult();
 
   return true;
-} // end DBA_database::CheckSid
+} // end DBA_database::CheckAnalyzer
+
+//
+// CheckSession
+// 
+DBA_bool DBA_database::CheckSession( )
+{
+    if (!LockSystemTables()) {
+        return false;
+    } // end if
+
+    char              szStatement[200];
+    StudioOAL_WResult oResult(m_pHandles->hDbc, m_pHandles->hEnv);
+  
+    gError.Clear(); 
+
+    sprintf(szStatement, DBA_SQL_CHECK_SESSION, GetSid());
+
+    // select a record
+    if (!oResult.openResult(szStatement)) {
+        gError.SetError(DBA_ERR_EXECUTE);
+        DBA_string sError = oResult.getErrorText();
+        gError.SetExtText(sError.Append("\n").Append(szStatement));
+        return false;
+    } // end if
+
+    if (!oResult.fetch()) {
+        gError.SetError(DBA_ERR_EXECUTE);
+        gError.SetExtText(oResult.getErrorText());
+        return false;
+    } // end if
+  
+    if (oResult.noRows()) {
+        // active session found
+        gError.SetError(DBA_ERR_DISCONNECT);
+        return false;
+    } // end if
+
+    oResult.closeResult();
+
+    if (!Commit()) {
+        return false;
+    } // end if
+
+    return true;
+} // end DBA_database::CheckSession
+
+//
+// LockSystemTables
+// 
+DBA_bool DBA_database::LockSystemTables( )
+{
+    // check for locktable
+    if (!Execute(DBA_SQL_LOCK_CHECK, NULL)) {
+        if (gError.GetNativeError() == -4004) {
+            gError.Clear(); 
+            return true;
+        } else {
+            return false;
+        } // end if
+    } // end if
+ 
+    // use the lock table
+    if (!Execute(DBA_SQL_LOCK_LOCK, NULL)) {
+        return false;
+    } // end if
+
+    return true;
+} // end DBA_database::LockSystemTables
+
+//
+// Commit
+// 
+DBA_bool DBA_database::Commit( )
+{
+    // send COMMIT statement
+    if (!Execute(DBA_SQL_COMMIT, NULL)) {
+        return false;
+    } // end if
+
+    return true;
+} // end DBA_database::Commit
