@@ -58,6 +58,8 @@ public:
     	@brief   This checks if the split space begins at an aligned position
     */
     virtual bool CheckAlignment() const = 0;
+    /// returns false, if given reference is not properly aligned
+    virtual bool CheckAlignment(SAPDB_Byte const * reference) const = 0;
 };
 /*!
    @class  Data_SplitSpaceWriter
@@ -261,7 +263,7 @@ public:
     /// definition of the result
     enum Result
     {
-        ok, moreSpaceAvailable, noMoreToRead, spaceToSmall
+        ok, moreSpaceAvailable, noMoreToRead, spaceToSmall, reservedSpaceNotAligned
     };
     /*!
        @brief This is used to read from a split space. Space must be assigned.
@@ -292,7 +294,8 @@ public:
      */
     void Reserve (SAPDB_UInt   Length,
                   SAPDB_Byte* &Space,
-                  Result      &NewResult)
+                  Result      &NewResult,
+                  bool         checkAlignment = false)
     {
         SAPDBTRACE_METHOD_DEBUG ("Data_SplitSpaceReader::Reserve", DataChain_Trace, 5);
         SAPDBTRACE_WRITELN (DataChain_Trace, 6, "Length: " << Length);
@@ -307,6 +310,13 @@ public:
 
         Space = m_CurrentValue + (m_CurrentLength - m_CurrentPartRestLength);
 
+        if ( checkAlignment && ! m_Space.CheckAlignment(Space) )
+        { 
+            NewResult = reservedSpaceNotAligned;
+            WriteToTrace ("Data_SplitSpaceReader::Reserve() => reservedSpaceNotAligned");
+            return;
+        }
+
         m_CurrentPartRestLength -= Length;
 
         if ( m_CurrentPartRestLength <= 0 )
@@ -500,6 +510,11 @@ public:
             }
         }
     }
+    /// returns false if the alignent of the given pointer is not correct
+    bool CheckAlignment ( SAPDB_Byte * reference )
+    {
+        return m_Space.CheckAlignment(reference);
+    }
 private:
     /// this is used, to take the next part of the space.
     void TakeNextPart()
