@@ -113,15 +113,8 @@ public:
          if ( ! IsAssigned() )
              return true;
              
-         SAPDB_UInt8 address =
-                         #ifdef BIT64
-                         reinterpret_cast<SAPDB_UInt8>(m_Parts[0].Value);
-                         #else
-                         reinterpret_cast<SAPDB_UInt4>(m_Parts[0].Value);
-                         #endif
-         
-         if ( address % T::Alignment() == 0 )
-             return true;
+         if ( CheckAlignment(m_Parts[0].Value) )
+            return true;
 
          WriteToTrace("SplitSpace is not properly aligned");
 
@@ -134,6 +127,18 @@ public:
 
         return false;
     }
+    /// returns false, if given reference is not properly aligned
+    virtual bool CheckAlignment(SAPDB_Byte const * reference) const
+    {
+        SAPDB_UInt8 address =
+                        #ifdef BIT64
+                        reinterpret_cast<SAPDB_UInt8>(reference);
+                        #else
+                        reinterpret_cast<SAPDB_UInt4>(reference);
+                        #endif
+         
+        return address % T::Alignment() == 0;
+    }
     /*!
         @brief  This part must not be used before.
         @return The reference to the next free page.
