@@ -22,7 +22,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -39,6 +39,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -182,6 +183,49 @@ FBM_DataVolume::RestoreAllBlockStatesMarkedForBackup (SAPDB_Int4 &NumBlocksResto
 
 /*---------------------------------------------------------------------------*/
 
+SAPDB_UInt
+FBM_DataVolume::CheckConverterFBM(SAPDB_Int volNo)
+{
+	SAPDB_UInt numBlocksOK = 0;
+	SAPDB_UInt numBlocksBad = 0;
+	SAPDB_UInt numBlocksFreeAfterSVP = 0;
+	bool dummy;
+	
+	for (SAPDB_Int block = 1; block < m_NumBlocks; block++)
+	{
+		if (BlockState_BackUp == GetBlockState (block)) // OK
+		{ 
+			numBlocksOK++;
+			RestoreBlockStateMarkedForBackup (block, dummy);
+		}
+		else if  (BlockState_Occupied == GetBlockState (block))     // error
+		{
+			numBlocksBad++;
+			FBM_BlockNoConverter blkInfo(__CONTEXT__, volNo, block, GetBlockState (block));
+			RTE_Message(blkInfo);
+		}
+		else if  (BlockState_FreeAfterSVP == GetBlockState (block))     // skip
+		{
+			numBlocksFreeAfterSVP++;
+		}
+	}
+	
+	FBM_Exception counter(__CONTEXT__,
+	FBM_INFO_COUNTER,
+	SAPDB_ToString( m_NumBlocks, _T_d ),
+	SAPDB_ToString( m_NumBlocksUsed, _T_d ),
+	SAPDB_ToString( m_NumBlocksFreeAfterSVP, _T_d ),
+	SAPDB_ToString( numBlocksOK + numBlocksBad + numBlocksFreeAfterSVP + 1, _T_d ),  // + 1 for info page
+	SAPDB_ToString( numBlocksBad, _T_d ),
+	SAPDB_ToString( numBlocksFreeAfterSVP, _T_d ));
+	RTE_Message(counter);
+	
+	return numBlocksOK;
+
+}
+    
+/*---------------------------------------------------------------------------*/
+
 SAPDB_Int4
 FBM_DataVolume::GetMultFreeBlocks  (const SAPDB_Int4  NumBlocksWanted,
                                     SAPDB_Int4       &NumBlocksSupplied)
