@@ -429,16 +429,19 @@ FBM_Manager::SetBlockStateToBackup(
 
 SAPDB_Bool
 FBM_Manager::SetBlockStateToBackup (
-    const tsp00_TaskId        TaskId,
-    IOMan_IBlockAddressIterator &BlockIterator,
-    const SAPDB_Bool          bAbortIfErrorOccured)
+    const tsp00_TaskId           TaskId,
+    IOMan_IBlockAddressIterator& BlockIterator,
+	SAPDB_UInt&                  numBlocks,
+	const SAPDB_Bool             bAbortIfErrorOccured)
 {
     SAPDBTRACE_ROUTINE_DEBUG ("FBM_Manager::SetBlockStateToBackup", FBM_Trace, 5);
 
+	numBlocks = 0;
     FBM_SynchObject SynchronizeFBM (TaskId);
 
     while (BlockIterator.hasMoreElements()){
         IOMan_BlockAddress BlockAddress = BlockIterator.getNextElement();
+		numBlocks++;
 
         if (!SetBlockStateToBackupUnsynched ( BlockAddress, bAbortIfErrorOccured))
         {
@@ -889,6 +892,32 @@ FBM_Manager::RestoreAllBlockStatesMarkedForBackup( const tsp00_TaskId TaskId )
 
 /*---------------------------------------------------------------------------*/
 
+SAPDB_UInt
+FBM_Manager::CheckConverterFBM(
+		const tsp00_TaskId taskId)
+{
+	SAPDB_Int4      volNo;
+	SAPDB_UInt numberOfBlocks = 0;
+	
+	FBM_SynchObject SynchronizeFBM (taskId);
+
+	for (volNo=FirstDevNo(); volNo<=LastDevNo(); volNo++)
+	{
+		FBM_IDataVolume &IVolume = m_DataVolume[volNo];
+
+		if (RTE_VolumeAccessModeNormal != IVolume.VolMode())
+			continue;
+
+		FBM_DataVolume &Volume = (FBM_DataVolume&) IVolume;
+
+		numberOfBlocks += Volume.CheckConverterFBM(volNo);
+	}
+	
+	return numberOfBlocks;
+}
+
+/*---------------------------------------------------------------------------*/
+
 void
 FBM_Manager::RestoreBlockStateMarkedForBackup(
     const tsp00_TaskId       TaskId,
