@@ -132,9 +132,10 @@ public:
         const SAPDB_Bool          bAbortIfErrorOccured = ! FBM_ABORT_IF_ERROR );
 
     SAPDB_Bool SetBlockStateToBackup(
-        const tsp00_TaskId        TaskId,
-              IOMan_IBlockAddressIterator &BlockIterator,
-        const SAPDB_Bool          bAbortIfErrorOccured = ! FBM_ABORT_IF_ERROR );
+        const tsp00_TaskId           TaskId,
+        IOMan_IBlockAddressIterator& BlockIterator,
+		SAPDB_UInt&                  numBlocks,
+        const SAPDB_Bool             bAbortIfErrorOccured = ! FBM_ABORT_IF_ERROR );
 
     /*!
        @brief          Sets the state of block to 'occupied'
@@ -151,7 +152,7 @@ public:
      */
     SAPDB_Bool SetBlockStateToOccupied(
         const tsp00_TaskId                 TaskId,
-              IOMan_IBlockAddressIterator &BlockIterator,
+        IOMan_IBlockAddressIterator &BlockIterator,
         const SAPDB_Bool                   bAbortIfErrorOccured = ! FBM_ABORT_IF_ERROR);
 
 
@@ -291,6 +292,9 @@ public:
      */
     void RestoreAllBlockStatesMarkedForBackup( const tsp00_TaskId TaskId );
 
+	SAPDB_UInt CheckConverterFBM(
+			const tsp00_TaskId taskId);
+	
     /*!
        @brief          Removes the flags indicating that a block must be saved
        @param          TaskId [in] task id
@@ -393,6 +397,14 @@ public:
         return (m_DataVolume [DevNo].GetNumBlocksUsed());
     }
 
+    /*!
+        @brief	Returns the number of blocks in state FreeAfterSavepoint
+        @return  int4
+      */
+    SAPDB_Int4 GetNumberOfFreeAfterSVPBlocks() const{
+        return m_TotalNumBlocksFreeAfterSVP;
+    }
+
     /*!
        @brief          Returns the volume mode of a device
        @param          DevNo [in] number of the device for which the volume mode is requested
