@@ -7,7 +7,7 @@
  *
  * @par last changed by:
  * <br>
- * $Author: d024980 $ $DateTime: 2006/02/08 14:05:41 $
+ * $Author: d026026 $ $DateTime: 2007/04/10 17:59:46 $
  *
  * @sa Join_AccessDesc.hpp
  */
@@ -40,7 +40,6 @@
 #include "Join/Join_Trace.hpp"
 #include "gsp00.h"
 #include "gsp03_1.h"
-#include "hak07.h"
 #include "hta01.h"
 #include "hta01_3.h"
 #include "ggg07.h"
@@ -61,6 +60,7 @@ Join_AccessDesc::Join_AccessDesc(SQLMan_Context& acv):
 m_acv( acv ), 
 m_mblock( acv.a_mblock ), 
 m_strategy(0), 
+m_onetab_strategy(0), 
 m_segment_ptr1(0),
 m_segment_ptr2( acv.GetAllocator() ),
 m_subqfile_id( acv.GetAllocator() )
@@ -79,9 +79,22 @@ m_subqfile_id( acv.GetAllocator() )
              m_mblock.mb_qual()->mstrat_cnt() > 0 )
         {
             SAPDBTRACE_WRITELN( Join_Trace, 7, "mstrat_pos : " << m_mblock.mb_qual()->mstrat_pos() );
-            m_strategy = reinterpret_cast<tgg07_StrategyInfo*>(m_mblock.mb_strat() + strategy_pos() - 1);
+            m_strategy = reinterpret_cast<tgg07_StrategyInfo*>(m_mblock.mb_strat() + 
+                         (*m_mblock.mb_st())[m_mblock.mb_qual()->mstrat_pos()-1].epos() - 1);
+            if ( 4 == m_mblock.mb_qual()->mstrat_cnt() )
+            {
+                m_onetab_strategy = reinterpret_cast<tgg07_StrategyInfo*>(m_mblock.mb_strat() + (*m_mblock.mb_st())[m_mblock.mb_qual()->mstrat_pos()+cgg07_OneTabStrat_Offset-1].epos() - 1);
+            } else
+                m_onetab_strategy = m_strategy;
             SAPDBTRACE_IF( Join_Trace, 5, 
-                    a725output_gg_strat( td_always, "STRATEGY    ", *m_strategy ));
+                    a725output_gg_strat( td_always, "join strat  ", *m_strategy ));
+#ifdef SAPDB_SLOW
+            if ( m_onetab_strategy != m_strategy )
+            {
+                SAPDBTRACE_IF( Join_Trace, 5, 
+                        a725output_gg_strat( td_always, "onetab strat", *m_onetab_strategy ));
+            }
+#endif
             if ( m_mblock.mb_qual()->msubquery() )
             {
                 SAPDB_AutoPtr<tgg00_Rec> _rec( m_acv.GetAllocator(), 
@@ -159,26 +172,23 @@ m_subqfile_id( acv.GetAllocator() )
 
         if ( IsIndexAccess() ) 
         {
-            if ( IsJoinInvAccess() )
-            {
-                g04index_tree_build( m_fileids.file_id, m_fileids.inv_id, 
-                        m_strategy->str_join_multfields().sjmf_index_no );
-                m_fileids.inv_id.fileRoot_gg00() = 
-                    m_strategy->str_join_multfields().sjmf_invroot;
-            }
-            else
-            {
-                g04index_tree_build( m_fileids.file_id, m_fileids.inv_id, 
-                        m_strategy->str_inv_in_range().siir_indexno );
-                m_fileids.inv_id.fileRoot_gg00() = 
-                    m_strategy->str_inv_in_range().siir_invroot;
-            }
+            g04index_tree_build( m_fileids.file_id, m_fileids.inv_id, 
+                    m_strategy->str_inv_in_range().siir_indexno );
+            m_fileids.inv_id.fileRoot_gg00() = 
+                m_strategy->str_inv_in_range().siir_invroot;
+        }
+        else if ( IsJoinInvAccess() )
+        {
+            g04index_tree_build( m_fileids.file_id, m_fileids.inv_id, 
+                    m_strategy->str_join_multfields().sjmf_index_no );
+            m_fileids.inv_id.fileRoot_gg00() = 
+                m_strategy->str_join_multfields().sjmf_invroot;
         }
         else
             m_fileids.inv_id = b01niltree_id;
     }
 
-    if ( e_ok != _b_err ) a07_b_put_error( m_acv, _b_err, 1 );
+    if ( e_ok != _b_err ) m_acv.ThrowError( _b_err );
 }
 
 /*!
@@ -206,101 +216,109 @@ tgg00_BasisError Join_AccessDesc::CreateKeys(
 {
     SAPDBTRACE_METHOD_DEBUG( "Join_AccessDesc::CreateKeys", Join_Trace, 1 );
     tgg00_BasisError _b_err = e_ok;
+    pasbool _use_stopkeys = true; // check for fullkey
+
     if (  m_strategy )
     {
         // create primary keys 
-        if ( strat_viewkey == m_strategy->str_strategy )
+        if  ( this->IsKeyAccess() )
         {
-            startkey.reckey.len() = m_mblock.mb_data()->mbp_key().keyLen_gg00();
-            startkey.listkey.len() = 0;
-            SAPDB_MemCopyNoCheck( startkey.reckey.k(), 
-                    m_mblock.mb_data()->mbp_key().keyVal_gg00(), 
-                    startkey.reckey.len());
-            stopkey = startkey;
-        } 
-        else if (( strat_no_result     == m_strategy->str_strategy ) || 
-                 ( strat_more_than_one == m_strategy->str_strategy ))
-        {
-            startkey.reckey.len() = startkey.listkey.len() = 0;
-            stopkey.reckey.len()  = stopkey.listkey.len()  = 0;
-        }
-        else
-        {
-            pasbool _use_stopkeys = true; // check for fullkey
-            if (( strat_key_in == m_strategy->str_strategy ) )
+            startkey.listkey.len() = stopkey.listkey.len() = 0;
+
+            if ( strat_viewkey == m_strategy->str_strategy )
             {
-                SAPDBERR_ASSERT_STATE( m_segment_ptr1 > 0 );
-                while ( st_dummy == 
-                      (*m_mblock.mb_st())[  m_strategy->str_key_in_range().skir_IN_SUBQ_stpos + m_segment_ptr1 - 1 ].etype() )
-                    ++m_segment_ptr1;
-                SAPDBTRACE_IF( Join_Trace, 7, 
-                        t01stackentry( td_always, (*m_mblock.mb_st())[  m_strategy->str_key_in_range().skir_IN_SUBQ_stpos + m_segment_ptr1 - 1 ], 
-                             m_strategy->str_key_in_range().skir_IN_SUBQ_stpos + m_segment_ptr1 ));
-                if ( st_value == (*m_mblock.mb_st())[  m_strategy->str_key_in_range().skir_IN_SUBQ_stpos + m_segment_ptr1 - 1 ].etype())
-                {
-                    SAPDBTRACE_WRITELN(
-                        Join_Trace, 3, "switch to next stream segment" );
-                    g04limitprimkeys( m_mblock, 
-                        m_strategy->str_key_in_range().skir_keystart, 
-                        startkey.reckey, 
-                        m_strategy->str_key_in_range().skir_keystop,
-                        stopkey.reckey, _use_stopkeys, 
-                        m_strategy->str_key_in_range().skir_IN_SUBQ_stpos, 
-                        m_segment_ptr1++ );
-                    _b_err = m_mblock.mb_trns()->trError_gg00;
-                }
-                else
-                {
-                    m_segment_ptr1 = 0;
-                    _b_err = e_no_next_record;
-                }
-            }
-            else if (( strat_key_subq == m_strategy->str_strategy ) )
+                startkey.reckey.len() = m_mblock.mb_data()->mbp_key().keyLen_gg00();
+                SAPDB_MemCopyNoCheck( startkey.reckey.k(), 
+                        m_mblock.mb_data()->mbp_key().keyVal_gg00(), 
+                        startkey.reckey.len());
+                stopkey.reckey = startkey.reckey;
+            } 
+            else
             {
-                SAPDBERR_ASSERT_STATE( m_segment_ptr2.IsAssigned() );
-                SAPDBERR_ASSERT_STATE( m_subqfile_id.IsAssigned() );
-                
-                pasbool    _ok;
-                SAPDB_AutoPtr<tgg00_Rec> _rec( 
-                        m_acv.GetAllocator(),
-                        reinterpret_cast<tgg00_Rec*>( 
-                        m_acv.GetAllocator().Allocate( BUF_MXSP00 )));
-                if  ( _rec.IsAssigned() )
+                if (( strat_key_in == m_strategy->str_strategy ) )
                 {
-                    g04read_subquery( m_acv.TransContext(), *_rec, 
-                            *m_subqfile_id, *m_segment_ptr2, _b_err, _ok );
-                    if  ( _ok )
+                    SAPDBERR_ASSERT_STATE( m_segment_ptr1 > 0 );
+                    while ( st_dummy == 
+                          (*m_mblock.mb_st())[  m_strategy->str_key_in_range().skir_IN_SUBQ_stpos + m_segment_ptr1 - 1 ].etype() )
+                        ++m_segment_ptr1;
+                    SAPDBTRACE_IF( Join_Trace, 7, 
+                            t01stackentry( td_always, (*m_mblock.mb_st())[  m_strategy->str_key_in_range().skir_IN_SUBQ_stpos + m_segment_ptr1 - 1 ], 
+                                 m_strategy->str_key_in_range().skir_IN_SUBQ_stpos + m_segment_ptr1 ));
+                    if ( st_value == (*m_mblock.mb_st())[  m_strategy->str_key_in_range().skir_IN_SUBQ_stpos + m_segment_ptr1 - 1 ].etype())
                     {
-                        _use_stopkeys = false;
-                        gg04one_subq_limitprimkey( m_mblock, 
-                              *_rec,
-                              m_strategy->str_key_in_range().skir_keystart,
-                              startkey.reckey, _use_stopkeys );
+                        SAPDBTRACE_WRITELN(
+                            Join_Trace, 3, "switch to next stream segment" );
+                        g04limitprimkeys( m_mblock, 
+                            m_strategy->str_key_in_range().skir_keystart, 
+                            startkey.reckey, 
+                            m_strategy->str_key_in_range().skir_keystop,
+                            stopkey.reckey, _use_stopkeys, 
+                            m_strategy->str_key_in_range().skir_IN_SUBQ_stpos, 
+                            m_segment_ptr1++ );
                         _b_err = m_mblock.mb_trns()->trError_gg00;
-                        if ( (e_ok == _b_err) || (e_key_not_found == _b_err) ) 
-                        {
-                            _use_stopkeys = true;
-                            gg04one_subq_limitprimkey( m_mblock, 
-                                  *_rec,
-                                  m_strategy->str_key_in_range().skir_keystop,
-                                  stopkey.reckey, _use_stopkeys );
-                            _b_err = m_mblock.mb_trns()->trError_gg00;
-                        }
                     }
                     else
                     {
-                        if ( e_ok == _b_err ) 
-                        {
-                            _b_err = m_mblock.mb_trns()->trError_gg00;
-                        }
-                            
+                        m_segment_ptr1 = 0;
+                        _b_err = e_no_next_record;
                     }
                 }
+                else if (( strat_key_subq == m_strategy->str_strategy ) )
+                {
+                    SAPDBERR_ASSERT_STATE( m_segment_ptr2.IsAssigned() );
+                    SAPDBERR_ASSERT_STATE( m_subqfile_id.IsAssigned() );
+                    
+                    pasbool    _ok;
+                    SAPDB_AutoPtr<tgg00_Rec> _rec( 
+                            m_acv.GetAllocator(),
+                            reinterpret_cast<tgg00_Rec*>( 
+                            m_acv.GetAllocator().Allocate( BUF_MXSP00 )));
+                    if  ( _rec.IsAssigned() )
+                    {
+                        g04read_subquery( m_acv.TransContext(), *_rec, 
+                                *m_subqfile_id, *m_segment_ptr2, _b_err, _ok );
+                        if  ( _ok )
+                        {
+                            _use_stopkeys = false;
+                            gg04one_subq_limitprimkey( m_mblock, 
+                                  *_rec,
+                                  m_strategy->str_key_in_range().skir_keystart,
+                                  startkey.reckey, _use_stopkeys );
+                            _b_err = m_mblock.mb_trns()->trError_gg00;
+                            if ( (e_ok == _b_err) || (e_key_not_found == _b_err) ) 
+                            {
+                                _use_stopkeys = true;
+                                gg04one_subq_limitprimkey( m_mblock, 
+                                      *_rec,
+                                      m_strategy->str_key_in_range().skir_keystop,
+                                      stopkey.reckey, _use_stopkeys );
+                                _b_err = m_mblock.mb_trns()->trError_gg00;
+                            }
+                        }
+                        else
+                        {
+                            if ( e_ok == _b_err ) 
+                                _b_err = m_mblock.mb_trns()->trError_gg00;
+                                
+                        }
+                    }
+                    else
+                        _b_err = e_no_more_memory;
+                }
                 else
-                    _b_err = e_no_more_memory;
+                {
+                    g04limitprimkeys( m_mblock, 
+                            m_strategy->str_key_in_range().skir_keystart, 
+                            startkey.reckey, 
+                            m_strategy->str_key_in_range().skir_keystop,
+                            stopkey.reckey, _use_stopkeys, 
+                            IS_UNDEFINED_GG07, -1 /* use an IN as range */ );
+                    _b_err = m_mblock.mb_trns()->trError_gg00;
+                }
             }
-            else
-            {
+        }
+        else if ( this->IsIndexAccess() )
+        {
             g04limitprimkeys( m_mblock, 
                     m_strategy->str_key_in_range().skir_keystart, 
                     startkey.reckey, 
@@ -308,85 +326,81 @@ tgg00_BasisError Join_AccessDesc::CreateKeys(
                     stopkey.reckey, _use_stopkeys, 
                     IS_UNDEFINED_GG07, -1 /* use an IN as range */ );
             _b_err = m_mblock.mb_trns()->trError_gg00;
-            }
-            // create index keys 
-            if ( e_ok == _b_err && IsIndexAccess() )
+
+            if ( e_ok == _b_err &&
+                 (m_strategy->str_inv_in_range().siir_startcnt > 0 || 
+                 m_strategy->str_inv_in_range().siir_stopcnt > 0 ))
             {
-                if ( m_strategy->str_inv_in_range().siir_startcnt > 0 || 
-                     m_strategy->str_inv_in_range().siir_stopcnt > 0 )
+                if (( strat_inv_in == m_strategy->str_strategy ) )
                 {
-                    if (( strat_inv_in == m_strategy->str_strategy ) )
+                    SAPDBERR_ASSERT_STATE( m_segment_ptr1 > 0 );
+                    while ( st_dummy == (*m_mblock.mb_st())[ m_strategy->
+                            str_inv_in_range().siir_IN_SUBQ_stpos + 
+                            m_segment_ptr1 - 1 ].etype() )
+                        ++m_segment_ptr1;
+                    SAPDBTRACE_IF( Join_Trace, 7, 
+                            t01stackentry( td_always, (*m_mblock.mb_st())[ m_strategy->str_inv_in_range().siir_IN_SUBQ_stpos + m_segment_ptr1 - 1 ], 
+                                m_strategy->str_inv_in_range().siir_IN_SUBQ_stpos + m_segment_ptr1 ));
+                    if ( st_value == (*m_mblock.mb_st())[ m_strategy->
+                         str_inv_in_range().siir_IN_SUBQ_stpos + 
+                         m_segment_ptr1 - 1 ].etype())
                     {
-                        SAPDBERR_ASSERT_STATE( m_segment_ptr1 > 0 );
-                        while ( st_dummy == (*m_mblock.mb_st())[ m_strategy->
-                                str_inv_in_range().siir_IN_SUBQ_stpos + 
-                                m_segment_ptr1 - 1 ].etype() )
-                            ++m_segment_ptr1;
-                        SAPDBTRACE_IF( Join_Trace, 7, 
-                                t01stackentry( td_always, (*m_mblock.mb_st())[ m_strategy->str_inv_in_range().siir_IN_SUBQ_stpos + m_segment_ptr1 - 1 ], 
-                                    m_strategy->str_inv_in_range().siir_IN_SUBQ_stpos + m_segment_ptr1 ));
-                        if ( st_value == (*m_mblock.mb_st())[ m_strategy->
-                             str_inv_in_range().siir_IN_SUBQ_stpos + 
-                             m_segment_ptr1 - 1 ].etype())
+                        SAPDBTRACE_WRITELN(
+                            Join_Trace, 3, "switch to next stream segment" );
+                        g04limitinvkeys( m_mblock, 
+                                m_strategy->str_inv_in_range(), 
+                                startkey.listkey, stopkey.listkey, 
+                                m_strategy->str_inv_in_range().siir_IN_SUBQ_stpos,
+                                m_segment_ptr1++ );
+                        _b_err = m_mblock.mb_trns()->trError_gg00;
+                    }
+                    else
+                    {
+                        m_segment_ptr1 = 0;
+                        _b_err = e_no_next_record;
+                    }
+                } 
+                else if (( strat_inv_subq == m_strategy->str_strategy ) )
+                {
+                    SAPDBERR_ASSERT_STATE( m_segment_ptr2.IsAssigned() );
+                    SAPDBERR_ASSERT_STATE( m_subqfile_id.IsAssigned() );
+                    
+                    pasbool    _ok;
+                    SAPDB_AutoPtr<tgg00_Rec> _rec(
+                            m_acv.GetAllocator(),
+                            reinterpret_cast<tgg00_Rec*>( m_acv.GetAllocator().Allocate( BUF_MXSP00 )));
+                    if  ( _rec.IsAssigned() )
+                    {
+                        g04read_subquery( m_acv.TransContext(), *_rec, 
+                                *m_subqfile_id, *m_segment_ptr2, _b_err, _ok );
+                        if  ( _ok )
                         {
-                            SAPDBTRACE_WRITELN(
-                                Join_Trace, 3, "switch to next stream segment" );
-                            g04limitinvkeys( m_mblock, 
-                                    m_strategy->str_inv_in_range(), 
-                                    startkey.listkey, stopkey.listkey, 
-                                    m_strategy->str_inv_in_range().siir_IN_SUBQ_stpos,
-                                    m_segment_ptr1++ );
+                            gg04one_subq_limitinvkey( m_mblock, 
+                                  *_rec,
+                                  m_strategy->str_inv_in_range(),
+                                  startkey.listkey, true );
                             _b_err = m_mblock.mb_trns()->trError_gg00;
-                        }
-                        else
-                        {
-                            m_segment_ptr1 = 0;
-                            _b_err = e_no_next_record;
-                        }
-                    } 
-                    else if (( strat_inv_subq == m_strategy->str_strategy ) )
-                    {
-                        SAPDBERR_ASSERT_STATE( m_segment_ptr2.IsAssigned() );
-                        SAPDBERR_ASSERT_STATE( m_subqfile_id.IsAssigned() );
-                        
-                        pasbool    _ok;
-                        SAPDB_AutoPtr<tgg00_Rec> _rec(
-                                m_acv.GetAllocator(),
-                                reinterpret_cast<tgg00_Rec*>( m_acv.GetAllocator().Allocate( BUF_MXSP00 )));
-                        if  ( _rec.IsAssigned() )
-                        {
-                            g04read_subquery( m_acv.TransContext(), *_rec, 
-                                    *m_subqfile_id, *m_segment_ptr2, _b_err, _ok );
-                            if  ( _ok )
+                            if ( (e_ok == _b_err) || (e_key_not_found == _b_err) )
                             {
                                 gg04one_subq_limitinvkey( m_mblock, 
                                       *_rec,
                                       m_strategy->str_inv_in_range(),
-                                      startkey.listkey, false );
+                                      stopkey.listkey, false );
                                 _b_err = m_mblock.mb_trns()->trError_gg00;
-                                if ( (e_ok == _b_err) || (e_key_not_found == _b_err) )
-                                {
-                                    gg04one_subq_limitinvkey( m_mblock, 
-                                          *_rec,
-                                          m_strategy->str_inv_in_range(),
-                                          stopkey.listkey, true );
-                                    _b_err = m_mblock.mb_trns()->trError_gg00;
-                                }
-                            }
-                            else
-                            {
-                                if ( e_ok == _b_err ) 
-                                {
-                                    _b_err = m_mblock.mb_trns()->trError_gg00;
-                                }
-                                    
                             }
                         }
                         else
-                            _b_err = e_no_more_memory;
+                        {
+                            if ( e_ok == _b_err ) 
+                                _b_err = m_mblock.mb_trns()->trError_gg00;
+                                
+                        }
                     }
-                    else 
-                    {
+                    else
+                        _b_err = e_no_more_memory;
+                }
+                else 
+                {
                     g04limitinvkeys( m_mblock, 
                             m_strategy->str_inv_in_range(), 
                             startkey.listkey, stopkey.listkey, 
@@ -394,19 +408,21 @@ tgg00_BasisError Join_AccessDesc::CreateKeys(
                             -1 /* use an IN as range */ );
                     _b_err = m_mblock.mb_trns()->trError_gg00;
                 }
-                }
-                else
-                {
-                    startkey.listkey.len() = 0;
-                    stopkey.listkey.len() = MAX_KEYLEN_GG00;
-                    stopkey.listkey.k() = b01fullkey;
-                }
             }
             else
             {
-                startkey.listkey.len() = stopkey.listkey.len() = 0;
+                startkey.listkey.len() = 0;
+                stopkey.listkey.len() = MAX_KEYLEN_GG00;
+                stopkey.listkey.k() = b01fullkey;
             }
         }
+        else
+        {
+            // strat_no_result, strat_more_than_one, strat_catalog
+            // read whole result file created
+            startkey.reckey.len() = startkey.listkey.len() = 0;
+            stopkey.reckey.len()  = stopkey.listkey.len()  = 0;
+        }
     }
     else
         _b_err = e_unknown_strategy;
