@@ -7,7 +7,7 @@
  *
  * @par last changed by:
  * <br>
- * $Author: d024980 $ $DateTime: 2006/02/08 14:05:41 $
+ * $Author: d026026 $ $DateTime: 2007/04/10 17:59:46 $
  *
  * @sa Join_AccessOperator.hpp
  */
@@ -388,7 +388,7 @@ bool Join_AccessOperator::is_same_key(
         if ( _diff )
             SAPDBTRACE_WRITELN( Join_Trace, 7, "different key content" );
 #endif
-        if ( (!_diff) && m_AccessDesc.IsIndexAccess() )
+        if ( (!_diff) && m_AccessDesc.IsIndexAccess() || m_AccessDesc.IsJoinInvAccess()  )
         {
             if ( old_key.listkey.keyLen_gg00() == new_key.listkey.keyLen_gg00() )
             {
