@@ -7,7 +7,7 @@
  *
  * \par last changed by:
  * 
- * $Author: d024980 $ $DateTime: 2006/02/08 14:05:41 $
+ * $Author: d026026 $ $DateTime: 2007/04/10 17:59:46 $
  *
  */
 /*
@@ -96,6 +96,7 @@ tgg00_BasisError new_group(
                      op_f_variance  == context.m_RecordDesc[ _func_pos - 1 ].eop_func() ||
                      op_f_dis_variance == context.m_RecordDesc[ _func_pos - 1 ].eop_func() )
                 {
+                    ++_disfile_cnt;
                     if ( csp_undef_byte != group_rec.recBuf_gg00()[ context.m_RecordDesc[ _out_pos - 1 ].epos() - 1 ] && 
                          csp_oflw_byte  != group_rec.recBuf_gg00()[ context.m_RecordDesc[ _out_pos - 1 ].epos() - 1 ] )
                     {
@@ -142,9 +143,9 @@ tgg00_BasisError new_group(
                             _dist_buffer.recLen_gg00() += RESCNT_MXGG04;
                         }
 
-                        _htree.fileRoot_gg00() = context.m_DistinctFileRoot[ _disfile_cnt ].m_Root;
-                        _htree.fileRootCheck_gg00() = context.m_DistinctFileRoot[ _disfile_cnt ].m_RootCheck;
-                        _htree.fileTempCnt_gg00() = ++_disfile_cnt;
+                        _htree.fileRoot_gg00() = context.m_DistinctFileRoot[ _disfile_cnt -1].m_Root;
+                        _htree.fileRootCheck_gg00() = context.m_DistinctFileRoot[ _disfile_cnt -1].m_RootCheck;
+                        _htree.fileTempCnt_gg00() = _disfile_cnt;
                         SAPDBTRACE_WRITELN( Join_Trace, 3, "add _dist_buffer" );
                         SAPDBTRACE_IF( Join_Trace, 3, 
                         t01buf( td_always, &_dist_buffer, 1, _dist_buffer.recLen_gg00() <= 300 ? _dist_buffer.recLen_gg00() : 300 ));
@@ -293,6 +294,14 @@ tgg00_BasisError update_group(
             }
             else
             {
+                if ( op_f_dis_avg   == _operator ||
+                     op_f_dis_sum   == _operator ||
+                     op_f_dis_count == _operator ||
+                     op_f_stddev    == _operator ||
+                     op_f_dis_stddev == _operator ||
+                     op_f_variance  == _operator ||
+                     op_f_dis_variance == _operator )
+                    ++_disfile_cnt;
                 if ( csp_undef_byte != record.recBuf_gg00()[ context.m_RecordDesc[ _out_pos - 1 ].epos() - 1 ]  || 
                      op_f_all_count == _operator )
                 {
@@ -399,9 +408,9 @@ tgg00_BasisError update_group(
                                         _dist_buffer.recLen_gg00() += RESCNT_MXGG04;
                                     }
     
-                                    _htree.fileRoot_gg00() = context.m_DistinctFileRoot[ _disfile_cnt ].m_Root;
-                                    _htree.fileRootCheck_gg00() = context.m_DistinctFileRoot[ _disfile_cnt ].m_RootCheck;
-                                    _htree.fileTempCnt_gg00() = ++_disfile_cnt;
+                                    _htree.fileRoot_gg00() = context.m_DistinctFileRoot[ _disfile_cnt -1].m_Root;
+                                    _htree.fileRootCheck_gg00() = context.m_DistinctFileRoot[ _disfile_cnt -1].m_RootCheck;
+                                    _htree.fileTempCnt_gg00() = _disfile_cnt;
                                     if ( csp_oflw_byte != record.recBuf_gg00()[ context.m_RecordDesc[ _out_pos - 1 ].epos() - 1 ] )
                                     {
                                         if ( e_ok == _b_err )
