@@ -133,10 +133,6 @@ private :
        @param rowCount number of rows provides by the calling server
      */
     void IncRowCount(int rowCount);
-    /*!
-      @brief increments the number of running servers by 1
-     */
-    void IncRunningServers();
     /*!
       @brief returns true, if iterator is is suspended; otherwise false.
      */
