@@ -7,7 +7,7 @@
  *
  * @par last changed by:
  * <br>
- * $Author: d024980 $ $DateTime: 2006/02/08 14:05:41 $
+ * $Author: d026026 $ $DateTime: 2007/04/10 17:59:46 $
  *
  * @sa Join_JoinOperator.hpp
  */
@@ -49,6 +49,7 @@
 #include "Join/Join_HashAccessAllocator.hpp"
 #include "Join/Join_HashAccessOperator.hpp"
 #include "Join/Join_NopAccessOperator.hpp"
+#include "Join/Join_SortOperator.hpp"
 #include "Join/Join_LegacyAccessOperator.hpp"
 #include "hak682.h"
 #include "hak683.h"
@@ -296,7 +297,7 @@ tgg00_BasisError Join_JoinOperator::Next( tgg00_Rec*& recptr )
 
             if ( e_ok == _b_err )
             {
-                SAPDB_Bool _joining;
+                SAPDB_Bool _joining = false;
 
                 if ( ! m_RightOp->IsOpened() )
                 {
@@ -1445,19 +1446,20 @@ IOperator* Join_JoinOperator::AccessOperatorFactory(
 
     if ( ! ( accessDesc.IsKnownAccess() || accessDesc.IsJoinAccess() ))
     {
-        a07_b_put_error( m_acv, e_unknown_strategy, 1 );
+        m_acv.ThrowError( e_unknown_strategy );
         return 0;
     }
 
     if ( strat_inv_range_merge_fetch == accessDesc.Strategy()->str_strategy )
     {
-        a07_b_put_error( m_acv, e_not_implemented, 1 );
+        m_acv.ThrowError( e_not_implemented );
         return 0;
     }
 
 
     if  ( strat_no_result == accessDesc.Strategy()->str_strategy )
     {
+        SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_NopAccessOperator" );
         accessOp = new ( m_acv.GetAllocator())
             Join_NopAccessOperator(
                 acv,
@@ -1465,12 +1467,40 @@ IOperator* Join_JoinOperator::AccessOperatorFactory(
                 !m_JoinDesc.gi_linkrec.kbjr_right_oj,
                 recordBuffer,
                 recBufSize );
-    }
-    else
+    } else if ( strat_more_than_one == accessDesc.Strategy()->str_strategy || 
+                strat_catalog       == accessDesc.Strategy()->str_strategy ) 
     {
-        if ( accessDesc.UseHashJoin()
-             && a01use_join_hashtable ) 
+        SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_LegacyOperator" );
+        accessOp = new (m_acv.GetAllocator())
+            Join_LegacyAccessOperator(
+                acv,
+                tabno,
+                recordBuffer,
+                recBufSize );
+    } else if  ( accessDesc.Strategy()->str_access_mod.includes( strmod_sorted ) )
+    {
+        SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_SortOperator" );
+        if  ( strat_more_than_one == accessDesc.OneTableStrategy()->str_strategy ||
+              strat_catalog       == accessDesc.OneTableStrategy()->str_strategy )
+            accessOp = new (m_acv.GetAllocator())
+                Join_LegacyAccessOperator(
+                    acv,
+                    tabno,
+                    recordBuffer,
+                    recBufSize );
+        else
+            accessOp = new (m_acv.GetAllocator())
+                Join_SortOperator(
+                    acv,
+                    tabno,
+                    recordBuffer,
+                    recBufSize );
+    } else
+    {
+        if ( accessDesc.UseHashJoin() && a01use_join_hashtable ) 
         {
+            SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_HashOperator" );
+            // create hash access operator
             SAPDB_UInt4 expectedTableSize =
                 static_cast<SAPDB_UInt4>(
                     expectedRecordCount * accessDesc.GetRecordLength() * 1.1 );
@@ -1520,6 +1550,7 @@ IOperator* Join_JoinOperator::AccessOperatorFactory(
                 new (m_acv.GetAllocator()) Join_HashAccessOperator(
                     acv,
                     tabno,
+                    a70glob_join_key_strats.includes( accessDesc.Strategy()->str_strategy ),
                     uniqueKeys,
                     keySizes,
                     expectedTableSize,
@@ -1535,8 +1566,9 @@ IOperator* Join_JoinOperator::AccessOperatorFactory(
             }
         }
 
-        if ( accessDesc.IsIndexAccess() ) 
+        if ( accessDesc.IsIndexAccess() || accessDesc.IsJoinInvAccess() ) 
         {
+            SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_InvAccessOperatorEx" );
             if ( accessDesc.UseParallelIndexAccess() && 
                  maxServerTasks > 0 )
             {
@@ -1549,6 +1581,7 @@ IOperator* Join_JoinOperator::AccessOperatorFactory(
                         recBufSize,
                         maxServerTasks );
             } else {
+                SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_InvAccessOperator" );
                 accessOp = new (m_acv.GetAllocator())
                     Join_InvAccessOperator(
                         acv,
@@ -1557,15 +1590,9 @@ IOperator* Join_JoinOperator::AccessOperatorFactory(
                         recordBuffer,
                         recBufSize );
             }
-        } else if ( strat_more_than_one == accessDesc.Strategy()->str_strategy ) 
+        } else 
         {
-            accessOp = new (m_acv.GetAllocator())
-                Join_LegacyAccessOperator(
-                    acv,
-                    tabno,
-                    recordBuffer,
-                    recBufSize );
-        } else {
+            SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_TableAccessOperator" );
             accessOp = new (m_acv.GetAllocator())
                 Join_TableAccessOperator(
                     acv,
@@ -1588,12 +1615,14 @@ IOperator* Join_JoinOperator::AccessOperatorFactory(
         accessOp->SetMaximumRowsReadAtATime( 1 );
     }
 
-    if ( hashAccessOp && accessOp ) {
+    if ( hashAccessOp && accessOp ) 
+    {
         hashAccessOp->SetAccessOperator( accessOp );
         accessOp = hashAccessOp;
     }
 
-    if ( ! accessOp ) {
+    if ( ! accessOp ) 
+    {
         destroy( hashAccessOp,  m_acv.GetAllocator() );
         m_acv.TransContext().trError_gg00 = e_no_more_memory;
         if ( Join_Trace.TracesLevel( 1 ) )
