@@ -7,7 +7,7 @@
  *
  * @par last changed by:
  * <br>
- * $Author: d024980 $ $DateTime: 2006/02/08 14:05:41 $
+ * $Author: d026026 $ $DateTime: 2007/04/10 17:59:46 $
  *
  * @sa Join_JoinOperator2.hpp
  */
@@ -415,7 +415,7 @@ tgg00_BasisError Join_JoinOperator2::next( tgg00_Rec* *records )
 
             if ( e_ok == _left_err )
             {
-                SAPDB_Bool _joining;
+                SAPDB_Bool _joining = false;
                 
                 // open right operator
                 if ( ! m_RightOp->IsOpened() )
@@ -625,22 +625,22 @@ tgg00_BasisError Join_JoinOperator2::operator_init()
 
     SAPDB_MemCopyNoCheck( &m_JoinInfo, 
             (SAPDB_Char *)m_acv.GetMessBlock().StratPtr() + 
-            (m_acv.GetMessBlock().StackEntry( m_acv.GetMessBlock().StratPos()+2-1 ).epos() - 1 ), 
-            m_acv.GetMessBlock().StackEntry( m_acv.GetMessBlock().StratPos()+2-1 ).elen_var() );
+            (m_acv.GetMessBlock().StackEntry( m_acv.GetMessBlock().StratPos()+cgg07_JoinInfo_Offset-1 ).epos() - 1 ), 
+            m_acv.GetMessBlock().StackEntry( m_acv.GetMessBlock().StratPos()+cgg07_JoinInfo_Offset-1 ).elen_var() );
     SAPDBTRACE_IF( Join_Trace, 3, 
         a683trace_joininfo( td_always, m_d_joins, m_JoinInfo ));
 
     if ( m_IsTopJoinOp )
     {
         m_OutputInfoSize = *(tsp00_Int2*)((SAPDB_Char *) m_acv.GetMessBlock().StratPtr() + 
-            (m_acv.GetMessBlock().StackEntry(  m_acv.GetMessBlock().StratPos()+1-1 ).epos() - 1 ));
+            (m_acv.GetMessBlock().StackEntry(  m_acv.GetMessBlock().StratPos()+cgg07_OutputDesc_Offset-1 ).epos() - 1 ));
         SAPDBTRACE_WRITELN( Join_Trace, 3, "m_OutputInfoSize: " << m_OutputInfoSize );
         if ( m_OutputInfo.SetPtr( (tak68_outcol*) 
                     m_acv.GetAllocator().Allocate( m_OutputInfoSize * sizeof( tak68_outcol ) )))
         {
             SAPDBTRACE_WRITELN( Join_Trace, 3, "allocate m_OutputInfo @ " << (void*)m_OutputInfo.GetPtr() );
             SAPDB_MemCopyNoCheck( m_OutputInfo.GetPtr(), (SAPDB_Char *) m_acv.GetMessBlock().StratPtr() + 
-                    (m_acv.GetMessBlock().StackEntry( m_acv.GetMessBlock().StratPos()+1-1 ).epos() - 1 ) + 
+                    (m_acv.GetMessBlock().StackEntry( m_acv.GetMessBlock().StratPos()+cgg07_OutputDesc_Offset-1 ).epos() - 1 ) + 
                     sizeof( tsp00_Int2 ), 
                     m_OutputInfoSize * sizeof( tak68_outcol ) );
 #ifdef SAPDB_SLOW
@@ -1172,7 +1172,8 @@ SAPDB_Bool Join_JoinOperator2::join(
             case op_not_like:
                 {
                     tgg00_Rec *_like_pattern = 0;
-                    SAPDB_Int4 _change_pos, _ix;
+                    SAPDB_Int4 _change_pos = _joinpred.jo_recs[ _src_side ].jop_outpos;
+                    SAPDB_Int4 _ix = 0;
                     if ( _reverse_operands )
                     {
                         SAPDBTRACE_WRITELN( Join_Trace, 5, "reverse operands " << "\tleft record changed: " << m_LeftRecChanged );
@@ -1181,8 +1182,8 @@ SAPDB_Bool Join_JoinOperator2::join(
                             m_LeftRecChanged = true;
                             // left record
                             _like_pattern = *(records+_src_tabno-1);
-                            _change_pos   = _joinpred.jo_recs[ _src_side ].jop_outpos;
-                            _ix           = 0;
+                            //_change_pos   = _joinpred.jo_recs[ _src_side ].jop_outpos;
+                            //_ix           = 0;
                         }
                     }
                     else
@@ -1578,17 +1579,20 @@ IOperator* Join_JoinOperator2::AccessOperatorFactory(
     SAPDB_Byte*               _recordBuffer = 0;
     SAPDB_UInt                _recBufSize   = buffersize;
 
+    // important!!! proof for right creation of _accessDesc !!!
+    if ( ! m_acv.IsOk() ) return 0;
+
     SAPDBTRACE_WRITELN( Join_Trace, 3, "access strategy : " << _accessDesc.Strategy()->str_strategy );
 
     if ( ! ( _accessDesc.IsKnownAccess() || _accessDesc.IsJoinAccess() ) )
     {
-        a07_b_put_error( m_acv, e_unknown_strategy, 1 );
+        m_acv.ThrowError( e_unknown_strategy );
         return 0;
     }
 
     if ( strat_inv_range_merge_fetch == _accessDesc.Strategy()->str_strategy )
     {
-        a07_b_put_error( m_acv, e_not_implemented, 1 );
+        m_acv.ThrowError( e_not_implemented );
         return 0;
     }
 
@@ -1602,21 +1606,40 @@ IOperator* Join_JoinOperator2::AccessOperatorFactory(
                 !m_JoinInfo.jn_rightoj,
                 _recordBuffer,
                 _recBufSize );
-    }
-    else if  ( _accessDesc.Strategy()->str_access_mod.includes( strmod_sorted ) )
+    } else if ( strat_more_than_one == _accessDesc.Strategy()->str_strategy || 
+                strat_catalog       == _accessDesc.Strategy()->str_strategy ) 
     {
-        SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_SortOperator" );
+        SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_LegacyOperator" );
         _accessOp = new (m_acv.GetAllocator())
-            Join_SortOperator(
+            Join_LegacyAccessOperator(
                 acv,
                 tabno,
                 _recordBuffer,
                 _recBufSize );
-    }
-    else
+    } else if  ( _accessDesc.Strategy()->str_access_mod.includes( strmod_sorted ) )
+    {
+        SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_SortOperator" );
+        if  ( strat_more_than_one == _accessDesc.OneTableStrategy()->str_strategy ||
+              strat_catalog       == _accessDesc.OneTableStrategy()->str_strategy )
+            _accessOp = new (m_acv.GetAllocator())
+                Join_LegacyAccessOperator(
+                    acv,
+                    tabno,
+                    _recordBuffer,
+                    _recBufSize );
+        else
+            _accessOp = new (m_acv.GetAllocator())
+                Join_SortOperator(
+                    acv,
+                    tabno,
+                    _recordBuffer,
+                    _recBufSize );
+    } else
     {
         if ( _accessDesc.UseHashJoin() && a01use_join_hashtable ) 
         {
+            SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_HashOperator" );
+            // create hash access operator
             SAPDB_UInt4 _expectedTableSize =
                 static_cast<SAPDB_UInt4>(
                     expectedRecordCount * _accessDesc.GetRecordLength() * 1.1 );
@@ -1667,6 +1690,7 @@ IOperator* Join_JoinOperator2::AccessOperatorFactory(
                 new (m_acv.GetAllocator()) Join_HashAccessOperator(
                     acv,
                     tabno,
+                    a70glob_join_key_strats.includes( _accessDesc.Strategy()->str_strategy ),
                     _uniqueKeys,
                     _keySizes,
                     _expectedTableSize,
@@ -1683,11 +1707,12 @@ IOperator* Join_JoinOperator2::AccessOperatorFactory(
             }
         }
 
-        if ( _accessDesc.IsIndexAccess() ) 
+        if ( _accessDesc.IsIndexAccess() || _accessDesc.IsJoinInvAccess() ) 
         {
             if ( _accessDesc.UseParallelIndexAccess() && 
                  maxServerTasks > 0 )
             {
+                SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_InvAccessOperatorEx" );
                 _accessOp = new (m_acv.GetAllocator())
                     Join_InvAccessOperatorEx(
                         acv,
@@ -1696,7 +1721,9 @@ IOperator* Join_JoinOperator2::AccessOperatorFactory(
                         _recordBuffer,
                         _recBufSize,
                         maxServerTasks);
-            } else {
+            } else 
+            {
+                SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_InvAccessOperator" );
                 _accessOp = new (m_acv.GetAllocator())
                     Join_InvAccessOperator(
                         acv,
@@ -1705,15 +1732,9 @@ IOperator* Join_JoinOperator2::AccessOperatorFactory(
                         _recordBuffer,
                         _recBufSize );
             }
-        } else if ( strat_more_than_one == _accessDesc.Strategy()->str_strategy ) 
+        } else 
         {
-            _accessOp = new (m_acv.GetAllocator())
-                Join_LegacyAccessOperator(
-                    acv,
-                    tabno,
-                    _recordBuffer,
-                    _recBufSize );
-        } else {
+            SAPDBTRACE_WRITELN( Join_Trace, 3, "create Join_TableAccessOperator" );
             _accessOp = new (m_acv.GetAllocator())
                 Join_TableAccessOperator(
                     acv,
