@@ -9,7 +9,7 @@
  *
  * @par last changed by:
  * <br>
- * $Author: d024980 $ $DateTime: 2005/06/23 17:29:07 $
+ * $Author: d026026 $ $DateTime: 2007/04/10 17:59:46 $
  *
  * @sa Join_IOperator.hpp
  */
@@ -84,7 +84,7 @@ protected:
 private:
     virtual SAPDB_Int4& result_cnt() { return m_SelectDesc.bd_rec_cnt; }
     virtual SAPDB_Int4 result_cnt() const { return m_SelectDesc.bd_rec_cnt; }
-    virtual SAPDB_Int4 rec_offset() const { return m_RecLength; }
+    virtual SAPDB_Int4 rec_offset() const { return m_RecOffset; }
     
     tgg00_BasisError legacy_access();
     
@@ -92,7 +92,7 @@ private:
     tgg00_FileId  m_ResultFile;
     tgg00_FilePos m_TreePos;
     tgg00_BdSetResultRecord m_SelectDesc;
-    SAPDB_Int4 m_RecLength;
+    SAPDB_Int4 m_RecOffset;
     bool m_ResultCreated;
 };
 
