@@ -44,13 +44,13 @@
 ///	date value (e.g. 20010213 == 13.02.2001)
 typedef SAPDB_Invalidatable<SAPDB_UInt4, KERNEL_INVALID_DATE> Kernel_Date;
 
-/// the invalid value is ZERO
-#define KERNEL_INVALID_TIME 0
+/// the invalid value must not be zero, because this is a valid time (00:00:00)
+/// (2006-06-26 mb PTS 1141894)
+#define KERNEL_INVALID_TIME SAPDB_MAX_UINT4
 
 /// time value (e.g. 00154857 == 15:48:57)
 typedef SAPDB_Invalidatable<SAPDB_UInt4, KERNEL_INVALID_TIME> Kernel_Time;
 
-
 /*!
    @brief   kernel time handling
 */
