@@ -132,6 +132,8 @@
 #define KERNELPARAM_INSTANCE_TYPE (SAPDB_UTF8 *)"INSTANCE_TYPE"
 /*! cserv name of the configuration parameter _IOPROCS_FOR_PRIO */
 #define KERNELPARAM__IOPROCS_FOR_PRIO (SAPDB_UTF8 *)"_IOPROCS_FOR_PRIO"
+/*! cserv name of the configuration parameter _IOPROCS_FOR_READER */
+#define KERNELPARAM__IOPROCS_FOR_READER (SAPDB_UTF8 *)"_IOPROCS_FOR_READER"
 /*! cserv name of the configuration parameter _KERNELDUMPFILE */
 #define KERNELPARAM__KERNELDUMPFILE (SAPDB_UTF8 *)"_KERNELDUMPFILE"
 /*! cserv name of the configuration parameter _KERNELTRACEFILE */
@@ -306,10 +308,14 @@
 #define KERNELPARAM__UNICODE (SAPDB_UTF8 *)"_UNICODE"
 /*! cserv name of the configuration parameter _USE_ASYNC_IO */
 #define KERNELPARAM__USE_ASYNC_IO (SAPDB_UTF8 *)"_USE_ASYNC_IO"
+/*! cserv name of the configuration parameter USE_BACKUP_SECURITY_DESCRIPTOR */
+#define KERNELPARAM__USE_BCK_SECURDESC (SAPDB_UTF8 *)"USE_BACKUP_SECURITY_DESCRIPTOR"
 /*! cserv name of the configuration parameter _USE_IOPROCS_ONLY */
 #define KERNELPARAM__USE_IOPROCS_ONLY (SAPDB_UTF8 *)"_USE_IOPROCS_ONLY"
 /*! cserv name of the configuration parameter USE_OPEN_DIRECT */
 #define KERNELPARAM_USE_OPEN_DIRECT (SAPDB_UTF8 *)"USE_OPEN_DIRECT"
+/*! cserv name of the configuration parameter USE_OPEN_DIRECT_FOR_BACKUP */
+#define KERNELPARAM_USE_OPEN_DIRECT_FOR_BACKUP (SAPDB_UTF8 *)"USE_OPEN_DIRECT_FOR_BACKUP"
 /*! cserv name of the configuration parameter _USE_PROC_SCOPE */
 #define KERNELPARAM__USE_PROC_SCOPE (SAPDB_UTF8 *)"_USE_PROC_SCOPE"
 /*! cserv name of the configuration parameter USE_SYSTEM_PAGE_CACHE */
@@ -339,8 +345,6 @@
 #define KERNELPARAM_ALLOW_COMPR_DEVSP (SAPDB_UTF8 *)"ALLOW_COMPR_DEVSP"
 /*! cserv name of the configuration parameter DYNAMIC_SERVER */
 #define KERNELPARAM_DYNAMIC_SERVER (SAPDB_UTF8 *)"DYNAMIC_SERVER"
-/*! cserv name of the configuration parameter HIRES_TIMER_TYPE */
-#define KERNELPARAM_HIRES_TIMER_TYPE (SAPDB_UTF8 *)"HIRES_TIMER_TYPE"
 /*! cserv name of the configuration parameter MEM_ENHANCE_LIMIT */
 #define KERNELPARAM_MEM_ENHANCE_LIMIT (SAPDB_UTF8 *)"MEM_ENHANCE_LIMIT"
 /*! cserv name of the configuration parameter RESTART_SHUTDOWN */
@@ -378,6 +382,26 @@
 #endif
 /***************************************************************/
 
+/***************************************************************/
+#if defined(_WIN32) || defined(LINUX)
+/***************************************************************/
+
+/*! cserv name of the configuration parameter HIRES_TIMER_TYPE */
+#define KERNELPARAM_HIRES_TIMER_TYPE (SAPDB_UTF8 *)"HIRES_TIMER_TYPE"
+
+/***************************************************************/
+#endif
+/***************************************************************/
+
+/***************************************************************/
+#if defined(LINUX)
+/***************************************************************/
+/*! cserv name of the configuration parameter UKT_CPU_RELATIONSHIP */
+#define KERNELPARAM_UKT_CPU_RELATIONSHIP (SAPDB_UTF8 *)"UKT_CPU_RELATIONSHIP"
+/***************************************************************/
+#endif
+/***************************************************************/
+
 #endif /* KERNELPARAM_RUNTIME_HPP */
 
 
