@@ -602,6 +602,31 @@ bool LVCSim_KernelInterface::UseReaderWriterLocks()
 
 /*-----------------------------------------------------*/
 
+void LVCSim_KernelInterface::Crash(const char* msg)
+{
+}
+
+/*-----------------------------------------------------*/
+
+void LVCSim_KernelInterface::DumpChunk (void* p, int size)
+{
+}
+
+/*-----------------------------------------------------*/
+
+tsp00_Int4 LVCSim_KernelInterface::GetHeapCheckLevel()
+{
+  return 0;
+}
+
+/*-----------------------------------------------------*/
+
+void LVCSim_KernelInterface::Trace(const char* msg)
+{
+}
+
+/*-----------------------------------------------------*/
+
 void LVCSim_KernelInterface::SetErrorCallback(DbpErrorCallbackInterface *cb){
 }
 
