@@ -156,6 +156,29 @@ public:
         }
         return Result;
     }
+    virtual bool CheckAlignment(SAPDB_Byte const * reference) const
+    {
+        SAPDB_UInt8 address =
+                        #ifdef BIT64
+                        reinterpret_cast<SAPDB_UInt8>(reference);
+                        #else
+                        reinterpret_cast<SAPDB_UInt4>(reference);
+                        #endif
+         
+        return address % LOG_PAGE_ALIGNMENT == 0;
+    }
+    /*! ---------------------------------------------------------------------------
+    function:    CheckAlignment
+    returns:     returns false, if space begin is not properly aligned
+    description: This checks if the split space begins at an aligned position
+    */
+     virtual bool CheckAlignment() const
+     {
+         if ( ! IsAssigned() )
+             return true;
+             
+         return CheckAlignment(m_Parts[0].m_Value);
+     }
     /* -----------------------------------------------------------------------*/
     /*@}*/
     /* -----------------------------------------------------------------------*/
