@@ -676,6 +676,7 @@ void Log_History::RemoveHistory (tgg00_TransContext        &trans,
     tgg91_TransNo   minUsedTransNo;
     pasbool         isTransUsed = 0;
     SAPDB_UInt      pagecount;
+    bool            currentUndoFileRemoved = false;
     
     m_Directory.GetHistoryFileInfo ( trans.trTaskId_gg00, fileno,
                                      fileinfo, pagecount);
@@ -858,7 +859,8 @@ void Log_History::RemoveHistory (tgg00_TransContext        &trans,
 
         if ( removeHistory )
         {
-            anythingRemoved = RemoveUndoFileWithObjects             // PTS 1113934 UH 2002-02-01
+            anythingRemoved = true;
+            currentUndoFileRemoved = RemoveUndoFileWithObjects             // PTS 1113934 UH 2002-02-01
                                       (trans, undoRoot, undoLast,
                                        IGarbColl,                   // PTS 1113185 UH 2001-12-18
                                        file, undoFileInfoIter);     // PTS 1113934 UH 2002-02-01
@@ -882,7 +884,7 @@ void Log_History::RemoveHistory (tgg00_TransContext        &trans,
     }
     else
     {
-        if ( anythingRemoved )
+        if ( currentUndoFileRemoved )
         {
             // determine new oldest transno
             tgg91_TransNo newOldestTransno = DetermineOldestTransNo(file);
@@ -1175,9 +1177,7 @@ bool Log_History::RemoveUndoFileWithObjects (tgg00_TransContext        &trans,
     iter.Invalidate();
 
     // PTS 1113934 UH 2002-02-01 begin
-    if ( IGarbColl.IsInterrrupted()
-         &&
-         ! allUndoEntriesDone ) // PTS ? UH 2002-03-15
+    if ( ! allUndoEntriesDone ) // PTS ? UH 2002-03-15
     {
         // Save pageno and offset to start there at the next run.
         undofile.SaveLastGarbageCollectorPosition (pageno, offset); // PTS ? UH 2002-03-15
@@ -1185,42 +1185,37 @@ bool Log_History::RemoveUndoFileWithObjects (tgg00_TransContext        &trans,
         undofile.Invalidate(); // prevent Drop() in destructor
         return false;
     }
-    else
+
+    if ( ! undoFileInfoIter.Continue() )
     {
-        if ( ! undoFileInfoIter.Continue() )
-        {
-            undoFileInfoIter.WriteToTrace ("undoFileInfoIter");
-            RTE_Crash( SAPDBErr_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED,
-                   "iter.Continue() failed") );
-        }
-
-        if ( (*undoFileInfoIter).root != root )
-        {
-            undoFileInfoIter.WriteToTrace ("undoFileInfoIter");
-            RTE_Crash( SAPDBErr_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED,
-                   "iter points to wrong entry") );
-        }
-                   
-        const SAPDB_UInt  transno      = (*undoFileInfoIter).transno.gg90GetInt4();
-        const Data_PageNo histfileroot = historyfile.GetRootId().PageNo();
-
-        historyfile.RemoveUndoFileInfo (undoFileInfoIter);
-
-		const bool breakIterator = iter.IsValid(); // PTS 1135450 UH 10-05-2005
-
-		if ( breakIterator ) // PTS 1135450 UH 10-05-2005
-			undoFileInfoIter.Break();
-
-		undofile.Drop();
-
-		if ( breakIterator && ! undoFileInfoIter.Continue() ) // PTS 1135450 UH 10-05-2005
-        {
-            undoFileInfoIter.WriteToTrace ("undoFileInfoIter");
-            RTE_Crash( SAPDBErr_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED,
-                   "iter.Continue() failed") );
-        }
-        return true;
+        undoFileInfoIter.WriteToTrace ("undoFileInfoIter");
+        RTE_Crash( SAPDBErr_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED,
+               "iter.Continue() failed") );
     }
+
+    if ( (*undoFileInfoIter).root != root )
+    {
+        undoFileInfoIter.WriteToTrace ("undoFileInfoIter");
+        RTE_Crash( SAPDBErr_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED,
+               "iter points to wrong entry") );
+    }
+               
+    historyfile.RemoveUndoFileInfo (undoFileInfoIter);
+
+    const bool breakIterator = iter.IsValid(); // PTS 1135450 UH 10-05-2005
+
+    if ( breakIterator ) // PTS 1135450 UH 10-05-2005
+        undoFileInfoIter.Break();
+
+    undofile.Drop();
+
+    if ( breakIterator && ! undoFileInfoIter.Continue() ) // PTS 1135450 UH 10-05-2005
+    {
+        undoFileInfoIter.WriteToTrace ("undoFileInfoIter");
+        RTE_Crash( SAPDBErr_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED,
+               "iter.Continue() failed") );
+    }
+    return true;
     // PTS 1113934 UH 2002-02-01 end
 }
 
@@ -1337,18 +1332,15 @@ Log_History::GetBeforeImage
     Log_BeforeImage       image;
     bool                  isOK = true;
     
-    image.ReadPersistentFormat (reader, isOK);
+    image.ReadPersistentFormat (reader, isOK, true);
 
     if ( ! isOK )
     {
-        if ( LogHistory_Trace.TracesLevel(6) )
-        {
-            Kernel_VTrace() << "GetBeforeImage() history get: " << pageno << "." << offset
-                            << " for oid: " << TestOid.gg92GetPno() << "." << TestOid.gg92GetPos()
-                            << " with view: " << Trans.trConsistView_gg00.gg90GetInt4()
-                            << NewLine;
-            Kernel_VTrace() << "GetBeforeImage() could not read image" << NewLine;
-        }
+        Kernel_VTrace() << "GetBeforeImage() history get: " << pageno << "." << offset
+                        << " for oid: " << TestOid.gg92GetPno() << "." << TestOid.gg92GetPos()
+                        << " with view: " << Trans.trConsistView_gg00.gg90GetInt4()
+                        << NewLine;
+        Kernel_VTrace() << "GetBeforeImage() could not read image" << NewLine;
         Trans.trError_gg00 = e_obj_history_not_found;
         iter.Invalidate();
         file.Invalidate();
