@@ -313,14 +313,6 @@ public:
     /// true, if this transaction needs to be written during savepoint
     bool IsSavepointRelevant();
     
-    /*!
-       @brief          true, if this transaction entry is needed by redo.
-
-       This filters the open transactions which are collected after the end
-       of the one transaction and before the open of the new transaction.
-     */
-    bool IsRedoRelevant();
-    
     /// used for writing the savepoint file
     static SAPDB_UInt GetPersistentLength()
     {
@@ -565,7 +557,8 @@ private: // member
     /// @attention this MUST not copied in the copy-operator, because the RTE must allocate
     /// a new spinlock for undo/redo
     mutable RTESync_Spinlock m_PersistentAccess;
-	/// redo entries which are written as a block to the redo log
+
+    /// redo entries which are written as a block to the redo log
     Log_ActionMultiple m_LocalRedoEntries; // PTS 1131107 UH 2004-08-24 added
 };
 
