@@ -196,10 +196,12 @@ public:
     /// Deletes log queues and log writer
     void Delete();
     /// Destructor
+    #ifdef DONT_USE_THIS
     ~Log_Volume()
     {
         Delete();
     }
+    #endif
     /*!
         @brief   called for setting the correct IOSeqence and WriteOffset after restart/restore log
 
@@ -368,7 +370,9 @@ public:
     /// Checks whether no more log can be written (Not valid for utility)
     SAPDB_Bool LogIsFull ()
     {
-        return m_LogWriter.LogIsFull();
+        return m_LogWriter.LogIsFull()
+               ||
+               (**m_LogQueues.Anchor()).IsLogFull();
     }
 
     /// Checks whether nothing was written to the log device since a clear log
@@ -545,6 +549,7 @@ public:
     /// infopage. The loginfo page is written to disk. The version is set
     /// if the corresponding flag is true (i.e. for a restart-savepoint)
     void WriteSavepointValuesAndFlushInfoPage (TaskID                   taskid,
+                                               const bool               isRestartSavepoint, // PTS 1137938 mb 2005-09-19
                                                tsp00_Version            kernelVersion,
                                                const SAPDBFields_Field& rrpart);
 
