@@ -47,7 +47,7 @@
 inline void OMS_Context::AssignLcSink(IliveCacheSink* pSink) 
 {
   m_currLcSink = pSink; 
-  m_sysLcSink  = OMS_Globals::GetCurrentLcSink();
+  //m_sysLcSink  = OMS_Globals::GetCurrentLcSink();
 }
 
 /*----------------------------------------------------------------------*/
@@ -253,9 +253,9 @@ inline bool OMS_Context::CheckOid (const OmsVarOid& oid)
         m_session->m_lcSink->MultiPurpose (m_change, mm_nil, &len, (unsigned char*) &DBError, &SqlError);
 
         if (SqlError != -102) {
-           return false;
+          return false;
         }
-        else {          
+        else {
           throw DbpError (DbpError::DB_ERROR, SqlError, msg, oid, __MY_FILE__, __LINE__);
           return false;
         }
