@@ -46,6 +46,7 @@
 #include "Oms/OMS_KernelDefaultInterface.hpp"
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_DefaultRawAllocator.hpp"
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_NewDestroy.hpp"
+#include "RunTime/RTE_IInterface.hpp"
 
 OMS_KernelDefaultInterface* OMS_KernelDefaultInterface::m_instance = 0;
 
@@ -90,6 +91,13 @@ void OMS_KernelDefaultInterface::DeregisterAllocator(RTEMem_AllocatorInfo& alloc
 
 /*-----------------------------------------------------*/
 
+bool OMS_KernelDefaultInterface::IsOneDBSystem() 
+{
+    return false;
+}
+
+/*-----------------------------------------------------*/
+
 SAPDBMem_IRawAllocator* OMS_KernelDefaultInterface::GetOmsAllocator()
 {
   return &SAPDBMem_DefaultRawAllocator::Instance(); 
@@ -285,5 +293,37 @@ bool OMS_KernelDefaultInterface::UseReaderWriterLocks(){
 
 /*-----------------------------------------------------*/
 
+void OMS_KernelDefaultInterface::Crash(const char* msg)
+{
+
+}
+
+/*-----------------------------------------------------*/
+
+void OMS_KernelDefaultInterface::DumpChunk (void* p, int size)
+{
+}
+
+/*-----------------------------------------------------*/
+
+tsp00_Int4 OMS_KernelDefaultInterface::GetHeapCheckLevel()
+{
+	return 0;
+}
+
+/*-----------------------------------------------------*/
+
+void OMS_KernelDefaultInterface::Trace(const char* msg)
+{
+}
+
+/*-----------------------------------------------------*/
+
 void OMS_KernelDefaultInterface::SetErrorCallback(DbpErrorCallbackInterface *cb){
 }
+
+/*-----------------------------------------------------*/
+
+RTE_IInterface &OMS_KernelDefaultInterface::GetKernelRunTimeInterface() {
+    return RTE_IInterface::Instance();
+}
