@@ -42,6 +42,35 @@
 
 /*----------------------------------------------------------------------*/
 
+#ifndef USE_SYSTEM_ALLOC_CO13
+
+
+OMS_Session::OMS_SessionAllocator::OMS_SessionAllocator(tsp00_TaskId taskId)
+: SAPDBMem_RawAllocator((const SAPDB_UTF8*) "", *OMS_Globals::GetKernelInterface()->GetOmsAllocator(), 32 * 1024, 32 * 1024, 
+                        SAPDBMem_RawAllocator::FREE_RAW_EXTENDS, SAPDBMEM_ALLOCATOR_UNLIMITED, !REGISTER_ALLOCATOR)
+, m_heapTracer(OMS_AllocatorTracer::KERNEL_CRASH)
+{
+  SAPDB_UTF8 heapName[41];
+  sp77sprintf (REINTERPRET_CAST(char*, &heapName[0]), sizeof(heapName), "OMS default session T%03d", taskId);
+
+  SetIdentifier (&heapName[0]);
+  SetTracer     (&m_heapTracer);
+  SetBadAllocHandler(SAPDBMem_RawAllocator::THROW_STD_BAD_ALLOC);
+  SetCheckLevel (OMS_Globals::GetKernelInterface()->GetHeapCheckLevel());
+  OMS_Globals::GetKernelInterface()->RegisterAllocator(GetAllocatorInfo());
+}
+
+/*----------------------------------------------------------------------*/
+
+OMS_Session::OMS_SessionAllocator::~OMS_SessionAllocator()
+{
+  OMS_Globals::GetKernelInterface()->DeregisterAllocator(GetAllocatorInfo());
+}
+
+#endif
+
+/*----------------------------------------------------------------------*/
+
 static
 OMS_ContainerInfo* omsRegisterContainer (IliveCacheSink*        lcSink, 
                                            const ClassIDRef       guid, 
@@ -80,8 +109,7 @@ OMS_Session::OMS_Session
   m_lockObjects(NULL),
   m_context(NULL), m_defaultContext(NULL), m_beforeImages(),
   #ifndef USE_SYSTEM_ALLOC_CO13
-  m_heap((const SAPDB_UTF8*) "", *OMS_Globals::GetKernelInterface()->GetOmsAllocator(), 32 * 1024, 32 * 1024, 
-  SAPDBMem_RawAllocator::FREE_RAW_EXTENDS, SAPDBMEM_ALLOCATOR_UNLIMITED, !REGISTER_ALLOCATOR) ,
+  m_heap(taskId),
   m_stackHeap(),
   #endif
   m_monitor(taskId),
@@ -107,12 +135,6 @@ OMS_Session::OMS_Session
   for (ix = 0; ix < cntRegions; ++ix) {
     m_critical_section_in_use[ix] = false;
   }
-#ifndef USE_SYSTEM_ALLOC_CO13
-  SAPDB_UTF8 heapName[41];  
-  sp77sprintf (REINTERPRET_CAST(char*, &heapName[0]), sizeof(heapName), "OMS default session T%03d", taskId);
-  m_heap.SetIdentifier(&heapName[0]);
-  OMS_Globals::GetKernelInterface()->RegisterAllocator(m_heap.GetAllocatorInfo());
-#endif
 }
 
 /*----------------------------------------------------------------------*/
@@ -135,9 +157,6 @@ OMS_Session::~OMS_Session()
     = m_handleList.begin(); iter; ++iter) {
  	(*iter())->m_pSession = NULL; 
   }
-#ifndef USE_SYSTEM_ALLOC_CO13
-   OMS_Globals::GetKernelInterface()->DeregisterAllocator(m_heap.GetAllocatorInfo());
-#endif
 }
 
 /*----------------------------------------------------------------------*/
