@@ -549,11 +549,6 @@ inline void OMS_Session::IncDeref()
 {
   --m_rescheduleDistance;
   if (m_rescheduleDistance <= 0) { /* PTS 1107849 */
-    if (m_toCancel) 
-    {
-      m_toCancel = false;
-      ThrowDBError(e_cancelled, "IncDeref", __MY_FILE__, __LINE__);
-    }
     m_rescheduleDistance = RESCHEDULE_DISTANCE;
     this->Reschedule();
   }  
@@ -1017,6 +1012,21 @@ inline void OMS_Session::OpenVersionProlog(const OmsVersionId &versionId, bool c
       ++iter;
     }
   }
+
+  // As the consistent view is closed when opening a version, remove all non-changed objects
+  // out of the hash. Otherwise these objects would become visible again (in a different 
+  // consistent view) after the version has been closed.
+  // Objects which has been changed can remain in the cache, as these objects could not be
+  // modified by concurrent transactions, as they are locked.
+  OMS_OidHash::OidIter iter = m_defaultContext->m_oidDir.First();
+  while (iter) {
+    OmsObjectContainer *p = iter();
+    ++iter;
+
+    if (!p->DeletedFlag() && !p->StoredFlag() && !p->LockedFlag()){
+      m_defaultContext->DeleteObjInContext(p, p->GetContainerInfo (m_defaultContext));
+    }
+  }
 }
 
 /*----------------------------------------------------------------------*/
@@ -1123,7 +1133,7 @@ inline void OMS_Session::ReleaseObj(OmsObjectContainerPtr p, bool unchangedOnly)
       return;
     }
   }
-  else if (p->existBeforeImage(m_subtrans_lvl, InVersion())){  // PTS 1128262
+  else if (p->GetBeforeImageMask() != 0){  // PTS 1140951
     if (!releaseUpdatedObj){
       return;
     }
@@ -1155,7 +1165,14 @@ inline bool OMS_Session::RequiredExceptionThrown() const
 /*----------------------------------------------------------------------*/
 
 /* PTS 1107849 */  
-inline void OMS_Session::Reschedule() {
+inline void OMS_Session::Reschedule() 
+{
+  if (m_toCancel) 
+  {
+    m_toCancel = false;
+    ThrowDBError(e_cancelled, "Reschedule", __MY_FILE__, __LINE__);
+  }
+
   m_lcSink->Reschedule();
 }
 
