@@ -30,11 +30,13 @@
 #ifndef __OMS_SESSIONDEF_HPP
 #define __OMS_SESSIONDEF_HPP
 
+#include "SAPDBCommon/MemoryManagement/SAPDBMem_RawAllocator.hpp"
 #include "Oms/OMS_Monitor.hpp"
 #include "Oms/OMS_BeforeImageList.hpp"
 #include "Oms/OMS_StackAllocator.hpp"
 #include "Oms/OMS_VarObj.hpp"
 #include "Oms/OMS_MassDerefIterators.hpp"    // PTS 1120478
+#include "Oms/OMS_AllocatorTracer.hpp"
 
 #include "geo00.h"
 #include "ggg251.h"
@@ -52,9 +54,20 @@ class OmsObjectContainer;
 class OMS_Session {   
 
 #ifndef USE_SYSTEM_ALLOC_CO13
-  SAPDBMem_RawAllocator m_heap; // caution! must be declared prior to session member 
-                                // that require the allocator
-  OMS_StackAllocator        m_stackHeap;
+  class OMS_SessionAllocator : public SAPDBMem_RawAllocator
+  {
+  public :
+      /*! constructor */
+      OMS_SessionAllocator(tsp00_TaskId taskId);
+      /*! destructor */
+      virtual ~OMS_SessionAllocator();
+  private :
+      /*! Tracer for the m_heap */
+      OMS_AllocatorTracer m_heapTracer;    
+  };
+  OMS_SessionAllocator  m_heap;   // caution! must be declared prior to m_classDir, m_rwLockDir etc to
+                                  // ensure correct sequence of destruction
+  OMS_StackAllocator    m_stackHeap;
 #endif
 
 public:
