@@ -35,6 +35,7 @@
  */
 #include "SAPDBCommon/ErrorsAndMessages/SAPDBErr_MessageEventConverter.hpp"
 #include "SAPDB/PacketInterface/PIn_SpecialParts.h"
+#include "SAPDB/Interfaces/Runtime/Util/IFRUtil_VDNNumber.h"
 #include "hsp40.h"
 #include "hsp77.h"
 
@@ -223,7 +224,6 @@ bool PIn_DataPart::GetValueAsChar
   const tsp00_Byte * pAddr    = this->GetValueAdress(pInfo);
   bool               bReturn  = true;
   tsp00_NumError     nError;
-  SAPDB_Int4         nValue;
   static char        szValue[1000];
   const char       * pChars = "0123456789ABCDEF";      
 
@@ -233,21 +233,25 @@ bool PIn_DataPart::GetValueAsChar
   if (pAddr != NULL) {
     switch (pInfo->sp1i_data_type) {
       case dfixed:
-      case dfloat:
-      case dvfloat:
       case dsmallint:
       case dinteger:
-//        s40glint ((tsp00_Number*)pAddr, 1, pInfo->sp1i_in_out_len,  nValue, nError);
-        s40glint ((tsp00_Number*)pAddr, 1, pInfo->sp1i_length,  nValue, nError);
-        sp77sprintf(szValue, 1000, "%d", nValue);
-        if (nError == num_ok) {
+      case dfloat:
+      case dvfloat:
+        if (IFRUtil_VDNNumber::numberToString((tsp00_Byte *) pAddr,
+                                              &szValue[0], 
+                                              sizeof(szValue),
+                                              IFR_StringEncodingAscii,
+                                              (pInfo->sp1i_data_type != dvfloat) && (pInfo->sp1i_data_type != dfloat),
+                                              pInfo->sp1i_length,
+                                              pInfo->sp1i_frac) != IFR_OK) {
+          bReturn = false;
+        } else {
           nLength = (tsp00_Int4) strlen(szValue);
           pValue  = &szValue[0];
           oConversion = ConvertNever;
-        } else {
-          bReturn = false;
         } // end if
         break;
+
       case dboolean:
         if (*pAddr == 0) {
           strcpy(szValue, "false");
