@@ -103,6 +103,17 @@ public:
     {
         return m_Value != 0;
     }
+    virtual bool CheckAlignment(SAPDB_Byte const * reference) const
+    {
+        SAPDB_UInt8 address =
+                        #ifdef BIT64
+                        reinterpret_cast<SAPDB_UInt8>(reference);
+                        #else
+                        reinterpret_cast<SAPDB_UInt4>(reference);
+                        #endif
+         
+        return address % LOG_PAGE_ALIGNMENT == 0;
+    }
     /*!
     @return false, if space begin is not properly aligned
     @brief  This checks if the split space begins at an aligned position
@@ -111,15 +122,7 @@ public:
     {
          if ( ! IsAssigned() )
              return true;
-             
-         SAPDB_UInt8 address =
-                         #ifdef BIT64
-                         reinterpret_cast<SAPDB_UInt8>(m_Value);
-                         #else
-                         reinterpret_cast<SAPDB_UInt4>(m_Value);
-                         #endif
-         
-         return address % LOG_PAGE_ALIGNMENT == 0;
+         return CheckAlignment(m_Value);             
     }
 
     /// default constructor
