@@ -533,18 +533,16 @@ static const SAPDB_Char *RTEDiag_AppldiagSimpleOutputLine(CycleBuffer::OutputTyp
 		}
 		break;
 	case CycleBuffer::OutputHeader:
-		outputLine = "--------------------------------------------------------------------------------\n"
-                     "Message-Text\n"
-					 "--------------------------------------------------------------------------------\n";
-		break;
-	case CycleBuffer::OutputCleanup:
-		outputLine = "                                                                                \n";
-		break;
+		outputLine = APPLDIAG_HEADER"\n";
+   		break;
+   	case CycleBuffer::OutputCleanup:
+   		outputLine = "                                                                                \n";
+   		break;
     case CycleBuffer::OutputEndOfStartup:
-		outputLine = "--------------------------------- end of startup -------------------------------\n";
-		break;
-	case CycleBuffer::OutputCurrentWrite:
-		outputLine = "------------------------------ current write position --------------------------";
+		outputLine = APPLDIAG_ENDOFSTARTUP"\n";
+   		break;
+   	case CycleBuffer::OutputCurrentWrite:
+		outputLine = APPLDIAG_WRITEPOSITION;
 		break;
 	default:
 		outputLine = "";
