@@ -179,7 +179,7 @@ RTEMem_Allocator::RTEMem_Allocator( SAPDB_ULong firstAlloc,
        RTEMem_BlockAllocator::Instance(), 
 	   firstAlloc,
        supplementAlloc,
-       SAPDBMem_SynchronizedRawAllocator::NOT_FREE_RAW_EXTENDS,
+       SAPDBMem_SynchronizedRawAllocator::FREE_RAW_EXTENDS,
 	   maxAlloc); 
 #endif
 }
@@ -207,7 +207,7 @@ RTEMem_Allocator::RTEMem_Allocator( SAPDB_ULong firstAlloc,
        RTEMem_BlockAllocator::Instance(), 
 	   firstAlloc,
        supplementAlloc,
-       SAPDBMem_SynchronizedRawAllocator::NOT_FREE_RAW_EXTENDS);
+       SAPDBMem_SynchronizedRawAllocator::FREE_RAW_EXTENDS);
 #endif
 }
 
