@@ -436,6 +436,28 @@ public:
        return Allocate((void *)0, BlockCount, true); // return commited memory at any address
    }
 
+   /*!
+      @brief          Allocates contiguous memory for 'count' blocks of
+                      memory.
+                      An implementation grants that a pointer returned will be an
+                      integral multiple of the alignment size. 
+                      The memory is not initialised.
+      @param          BlockCount [in] The number of blocks to be allocated. This argument must be greater zero.
+      @param          messageList [out] filled if memory not available   
+      @return         void*
+                      A pointer to the allocated raw memory block of &lt;BlockCount> 
+                      blocks. If exception handling is disabled, a NULL pointer will
+                      be returned in case of insufficient memory.
+      @exception      From 'SAPDBMem_IBlockAllocator' derived classes may 
+                      throw a 'SAPDBMem_BadAllocException' if the allocation fails.
+
+    */
+
+  virtual void * Allocate(SAPDB_ULong BlockCount, SAPDBErr_MessageList &messageList)
+  {
+      return Allocate((void *)0, BlockCount, true, messageList); // return commited memory at any address
+  }
+
    /*!----------------------------------------------------------------------
    @brief  Allocates contiguous memory for 'count' blocks of memory with commit specified
 
@@ -453,6 +475,24 @@ public:
    -----------------------------------------------------------------------*/
    void* Allocate(void *FixedAddress, SAPDB_ULong BlockCount, SAPDB_Bool DoCommit);
 
+   /*!----------------------------------------------------------------------
+   @brief  Allocates contiguous memory for 'count' blocks of memory with commit specified
+
+   The implementation grants that a pointer returned will be an
+   integral multiple of the alignment size.
+
+   The memory is not initialised and not commited, if DoCommit is false
+
+   @param FixedAddress [in] If not 0, only return memory at specifed address
+   @param BlockCount [in] The number of blocks to be allocated. This argument must be greater zero.
+   @param DoCommit [in] Flag to indicate memory must be committed
+   @param messageList [out] message if out of memory
+   @return [void*] A pointer to the allocated raw memory block of given number of
+                 blocks. If exception handling is disabled, a NULL pointer will
+                 be returned in case of insufficient memory.
+   -----------------------------------------------------------------------*/
+   void* Allocate(void *FixedAddress, SAPDB_ULong BlockCount, SAPDB_Bool DoCommit, SAPDBErr_MessageList &messageList);
+
    /*!----------------------------------------------------------------------
    @brief Frees the memory.
 
@@ -556,6 +596,14 @@ private:
     */
     RTEMem_BlockDescriptor * GetDescriptorFromPool();
 
+   /*!----------------------------------------------------------------------
+    @brief get a descriptor from the descriptor pool
+    If needed this call allocates memory for the pool
+    @param messageList [out] filled if out of memory
+    @return block descriptor returned or 0 if out of memory
+    */
+    RTEMem_BlockDescriptor * GetDescriptorFromPool(SAPDBErr_MessageList &messageList);
+
    /*!----------------------------------------------------------------------
     @brief return a chain head to the chain head pool
     Call uses m_chainHeadPoolLock to lock pool
