@@ -18,7 +18,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@
 
 
 
+
 *****************************************************************************/
 
 
@@ -573,8 +574,11 @@ PCHAR const RTEPPars_SAPDBProt::GetMessClassName ( SAPDB_UInt1   MessClass )
     pMessClass = "Control cancel request";
     break;
   case RSQL_NEW_USER_CONN_REQUEST_EO003:
-    pMessClass = "New user connect request";
-    break;
+      pMessClass = "New user connect request";
+      break;
+  case RSQL_REQUEST_UNKNOWN_REPLY_EO003:
+      pMessClass = "Request unknown reply";
+      break;
   default:
     pMessClass = NULL;
     break;
