@@ -163,7 +163,7 @@ APIRET RTE_ActiveDatabase::startService ( RTE_SpeedInfo &speed
     RTE_ClientDiagPipe diagPipe;
     diagPipe.create(m_dbName);
 
-    RTE_NTService service(m_dbName,m_dbRoot,NULL,NULL,speed);
+    RTE_NTService service(m_dbName,GetDBRoot(),NULL,NULL,speed);
     rc = service.Start(szOptions);
 
     if(NO_ERROR == rc)
@@ -253,7 +253,7 @@ RTE_ActiveDatabase::Start( RTE_SpeedInfo &speed
         break;
     case ERROR_FILE_NOT_FOUND:
         {
-            RTE_NTService service(m_dbName,m_dbRoot,NULL,NULL,speed);
+            RTE_NTService service(m_dbName,GetDBRoot(),NULL,NULL,speed);
             RTE_Path executableName;
             service.GetExecutableName(executableName);
             errList = SAPDBErr_MessageList ( RTE_CONTEXT, RTEERR_DBREG_KERNEL_EXE_MISSING,executableName );
@@ -301,7 +301,7 @@ APIRET RTE_ActiveDatabase::stopService ( void )
     Container_List<RTE_SpeedInfo>::Iterator speedIterator = GetDBSpeeds().Begin();
     while(!fFinish && speedIterator != 0)
     {
-        RTE_NTService service(m_dbName,m_dbRoot,NULL,NULL,*speedIterator);
+        RTE_NTService service(m_dbName,GetDBRoot(),NULL,NULL,*speedIterator);
         rc = service.Stop();
 
         if(NO_ERROR == rc)
@@ -550,7 +550,7 @@ SAPDB_Bool RTE_ActiveDatabase::OpenKernel
         DWORD dwCurrentState;
         while(speedIterator != 0)
         {
-            RTE_NTService service(m_dbName,m_dbRoot,NULL,NULL,*speedIterator);
+            RTE_NTService service(m_dbName,GetDBRoot(),NULL,NULL,*speedIterator);
             APIRET rc;
             SAPDB_Bool firstCall = true;
             do
@@ -1034,12 +1034,12 @@ SAPDB_Bool RTE_ActiveDatabase::updateEnvironment(
     /* Always set DBROOT    */
     /* PTS 1105164          */
     oldenvDBROOT = envDBROOT;
-    envDBROOT = (SAPDB_Char *)malloc(strlen("DBROOT=") + strlen(m_dbRoot) + 1);
+    envDBROOT = (SAPDB_Char *)malloc(strlen("DBROOT=") + strlen(GetDBRoot()) + 1);
 
     if ( envDBROOT != NULL )
     {
         strcpy(envDBROOT, "DBROOT=");
-        strcat(envDBROOT, m_dbRoot);
+        strcat(envDBROOT, GetDBRoot());
 
 
         if ( putenv(envDBROOT) < 0 )
@@ -1755,7 +1755,7 @@ RTE_ActiveDatabase::Start( RTE_SpeedInfo &speed
         return false;
     }
 
-    if ( !m_dbRoot || !m_dbRoot[0] )
+    if ( !GetDBRoot() || !GetDBRoot()[0] )
     {
         errList = SAPDBErr_MessageList (RTE_CONTEXT, RTEERR_DBREG_NO_DBROOT, m_dbName );
 
@@ -1845,19 +1845,6 @@ RTE_ActiveDatabase::Start( RTE_SpeedInfo &speed
     }
     while(returnedPid != serverpid);
 
-    /*
-        Now check if the kernel state is really admin or reached already online state -
-        To handle the case that the kernel crashed after closing the diag pipe correctly 
-        http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1122382    
-    */  
-    SAPDB_UInt4 dbState;
-    getDbPidStateFromShm(NULL,NULL,&dbState,0,0,NULL,errList);
-    if(SERVER_COLD != dbState && SERVER_WARM != dbState )
-    {
-        errList = SAPDBErr_MessageList (RTE_CONTEXT, RTEERR_DBREG_KERNEL_DIED_BEFORE_ADMIN);
-        return false;
-    }
-
     if ( returnedPid == ((pid_t)-1) )
     {
         errList = SAPDBErr_MessageList (RTE_CONTEXT, RTEERR_DBREG_CANNOT_WAIT_FOR_STARTER, sqlerrs() );
@@ -1871,6 +1858,18 @@ RTE_ActiveDatabase::Start( RTE_SpeedInfo &speed
         switch( WEXITSTATUS(startProcessStatus) )
         {
         case DO_START_SUCCEEDED:
+            /*
+                Now check if the kernel state is really admin or reached already online state -
+                To handle the case that the kernel crashed after closing the diag pipe correctly 
+                http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1122382    
+            */  
+            SAPDB_UInt4 dbState;
+            getDbPidStateFromShm(NULL,NULL,&dbState,0,0,NULL,errList);
+            if(SERVER_COLD != dbState && SERVER_WARM != dbState )
+            {
+                errList = SAPDBErr_MessageList (RTE_CONTEXT, RTEERR_DBREG_KERNEL_DIED_BEFORE_ADMIN);
+                return false;
+            }
             return true;
             break;
 
