@@ -102,6 +102,24 @@ struct RTE_pthread_tls_key
 } RTE_TLSKeys[THREAD_KEYS_FIRST_LEVEL*THREAD_KEYS_SECOND_LEVEL] = { 0 };
 #endif
 
+#if defined(ALPHA)
+/*! direct assembler code interfacing... sp and top are set in context, funcion is given */
+extern "C" 
+{
+    void	e71_initstack ( struct RTE_OwnCoroutineContext *context , void (*func)() );
+    void	e71_firststack ( struct RTE_OwnCoroutineContext * newContext );
+    void	e71_chgstack ( struct RTE_OwnCoroutineContext *newContext , struct RTE_OwnCoroutineContext *oldContext );
+
+    void e88_stack_overflow ( void * cont )
+    {
+        abort(); 
+    }
+};
+
+/*! direct assembler code interfacing (order reversed) */
+#define RTE_OwnSwapContext(old_,new_) e71_chgstack(new_,old_)
+
+#endif
 
 
 extern "C" void en88memcpy(void *a,void *b,SAPDB_UInt s);
@@ -129,36 +147,30 @@ SAPDB_sprintf(eBuffer, sizeof(eBuffer), "Switching from 0x%p to 0x%p\n",
 MSGD(( INFO_TEST_WILDCARD, eBuffer ));
 #endif
 
-    if ( XPARAM(fUseUcontext) )
-    {
-#ifdef HP_IA64
+#if defined(USE_UCONTEXT)
+#  ifdef HP_IA64
 /* This is a workaround for broken swapcontect() on HPUX IA64. During the swapcontext() call the page-fault- */
 /* handling is deactivated, so that ucontext structures that are paged out cannot be accessed. In such cases */
 /* the function fails and errno is EFAULT. if this is detected, the ucontext structures are copied (just to  */
 /* make sure they are paged into main memory) and swapcontext() is called again. This is done in a loop      */
 /* because the ucontexts may be paged out again just before the swapcontext() call. */
-/* HP has announced a patch for this problem for January 2005, this workaround code may be eliminated then...*/
-        int retval;
-        ucontext_t dummyContext;
-        while( ((retval = swapcontext(&oldContext.context.uC, &newContext.context.uC)) != 0) && (errno == EFAULT) )
-        {
-            en88memcpy(&dummyContext,&oldContext.context.uC,sizeof(ucontext_t));
-            en88memcpy(&dummyContext,&newContext.context.uC,sizeof(ucontext_t));
-        }
-        return ( 0 == retval );
-#else
-        return ( swapcontext(&oldContext.context.uC, &newContext.context.uC) == 0 );
-#endif
-    }
-    else
+    int retval;
+    ucontext_t dummyContext;
+    while( ((retval = swapcontext(&oldContext.context.uC, &newContext.context.uC)) != 0) && (errno == EFAULT) )
     {
-#if defined(USE_OWN_COROUTINE_CONTEXT)
-        RTE_OwnSwapContext(&oldContext.context.ownC, &newContext.context.ownC);
-        return true;
-#else
-        return false;
-#endif
+        en88memcpy(&dummyContext,&oldContext.context.uC,sizeof(ucontext_t));
+        en88memcpy(&dummyContext,&newContext.context.uC,sizeof(ucontext_t));
     }
+    return ( 0 == retval );
+#  else
+    return ( swapcontext(&oldContext.context.uC, &newContext.context.uC) == 0 );
+#  endif
+#elif defined(USE_OWN_COROUTINE_CONTEXT)
+    RTE_OwnSwapContext(&oldContext.context.ownC, &newContext.context.ownC);
+    return true;
+#else
+    return false;
+#endif
 }
 
 /*!--------------------------------------------------------------------
@@ -232,35 +244,34 @@ SAPDB_Bool RTE_ContextPrepare( RTE_CoroutineContext &    GivenContextPointer
 {
     callPointerConverter u;
     u.anyPointer = initialFunction; // C++ does not allow to cast from void * to void (*)() 
-    if ( XPARAM(fUseUcontext) )
+#if defined(USE_UCONTEXT)
+    int rc;
+    ucontext_t *pContext = &GivenContextPointer.context.uC;
+
+    /* on AIX we would otherwise get a floating point exception sometimes....*/
+    memset(pContext, 0, sizeof(ucontext_t));
+
+    rc = getcontext ( pContext );
+    if ( -1 == rc )
     {
-        int rc;
-        ucontext_t *pContext = &GivenContextPointer.context.uC;
+        return false;
+    }
 
-        /* on AIX we would otherwise get a floating point exception sometimes....*/
-        memset(pContext, 0, sizeof(ucontext_t));
+    if ( !stackPtr
+        || !stackSize
+        || !initialFunction )
+    {
+        return true; // just want to get own context
+    }
 
-        rc = getcontext ( pContext );
-        if ( -1 == rc )
-        {
-            return false;
-        }
-
-        if ( !stackPtr
-          || !stackSize
-          || !initialFunction )
-        {
-            return true; // just want to get own context
-        }
-
-        pContext->uc_link = 0;
+    pContext->uc_link = 0;
 #ifdef MAKECONTEXT_USES_STACK_BASE
-        pContext->uc_stack.ss_sp    = (stackPointerType)stackPtr;
+    pContext->uc_stack.ss_sp    = (stackPointerType)stackPtr;
 #else
         pContext->uc_stack.ss_sp    = (stackPointerType)(((char *)stackPtr) + stackSize); 
 #endif
-        pContext->uc_stack.ss_size  = stackSize;
-        pContext->uc_stack.ss_flags = 0;
+    pContext->uc_stack.ss_size  = stackSize;
+    pContext->uc_stack.ss_flags = 0;
 
 #if defined(SUN) && defined(SVR4)
         // Sparc needs 16 byte aligned stacks!
@@ -271,24 +282,21 @@ SAPDB_Bool RTE_ContextPrepare( RTE_CoroutineContext &    GivenContextPointer
         makecontext ( pContext, u.initialContextCall, MAKECONTEXT_ZERO_ARGUMENT_COUNT);
 
 #if defined(LINUX) && defined(X86_64)
-		// fix machine context stack pointer
-		// caused by broken makecontext ()
-		// according the x86-64 abi (%rsp - 8) must be a multiple of 16
+	// fix machine context stack pointer
+	// caused by broken makecontext ()
+	// according the x86-64 abi (%rsp - 8) must be a multiple of 16
 #ifndef REG_RSP
 #define REG_RSP 15
 #endif
-		unsigned long sp = pContext->uc_mcontext.gregs[REG_RSP];
-		if ((sp & (unsigned long) 15) != (unsigned long) 8) {
-			sp &= ~(unsigned long) 15;
-			sp -= 8;
-	        pContext->uc_mcontext.gregs[REG_RSP] = sp;
-		}
+	unsigned long sp = pContext->uc_mcontext.gregs[REG_RSP];
+	if ((sp & (unsigned long) 15) != (unsigned long) 8) {
+		sp &= ~(unsigned long) 15;
+		sp -= 8;
+	    pContext->uc_mcontext.gregs[REG_RSP] = sp;
+	}
 #endif
-        return true;
-    }
-    else
-    {
-#if defined(USE_OWN_COROUTINE_CONTEXT)
+    return true;
+#elif defined(USE_OWN_COROUTINE_CONTEXT)
         if ( !stackPtr
           || !stackSize
           || !initialFunction )
@@ -296,19 +304,23 @@ SAPDB_Bool RTE_ContextPrepare( RTE_CoroutineContext &    GivenContextPointer
             return true; // just want to get own context. Not needed with this implementation
         }
 
+#ifdef ALPHA
+        GivenContextPointer.context.ownC.top  = stackPtr;
+        GivenContextPointer.context.ownC.sp   = (((char *)stackPtr) + stackSize);
+        e71_initstack(&GivenContextPointer.context.ownC, u.initialContextCall);
+#else
 #ifdef PA20W
-        GivenContextPointer.context.ownC.sp   = stackPtr;
+    GivenContextPointer.context.ownC.sp   = stackPtr;
 #else
-        GivenContextPointer.context.ownC.sp   = (char*)stackPtr + stackSize;
+        GivenContextPointer.context.ownC.sp   = (((char *)stackPtr) + stackSize);
 #endif
-        GivenContextPointer.context.ownC.addr = u.initialContextCall;
-        RTE_OwnMakeContext( &GivenContextPointer.context.ownC );
-
-        return true;
+    GivenContextPointer.context.ownC.addr = u.initialContextCall;
+    RTE_OwnMakeContext( &GivenContextPointer.context.ownC );
+#endif
+    return true;
 #else
-        return false;
+    return false;
 #endif /* USE_UCONTEXT */
-    }
 }
 
 /*============================================*/
