@@ -83,15 +83,14 @@ extern "C" {
 #if (defined(LINUX)) && (defined (I386) || defined(IA64) || defined(S390X) || defined(X86_64) || defined(SDBonPPC64)) 
 #  include <ucontext.h>
 #  define USE_UCONTEXT LINUX
-#if defined (I386)
-#  include "RunTime/RTE_SystemLinux.h"
-#  define USE_OWN_COROUTINE_CONTEXT
-#endif
+#  if defined (I386)
+#    define USE_STACK_ON_STACK LINUX
+#  endif
 #endif /* LINUX && IA64 */
 
 #if defined(ALPHA)
-#  include <ucontext.h>
-#  define USE_UCONTEXT DEC
+/*#  include <ucontext.h>
+#  define USE_UCONTEXT DEC*/
 /*!
    Own coroutine context used only if a assembly coroutine switch code exists
  */
@@ -107,14 +106,14 @@ void e71_FirstChangeStack(struct RTE_OwnCoroutineContext *newContext, struct RTE
 #endif  /* ALPHA*/
 
 #if defined(PA20W) || defined (HP_IA64)
-#  include <ucontext.h>
-/*    USE_UCONTEXT failed completely..... bug in libc on HPUX? But it compiles and maybe some day... */
-#  define USE_UCONTEXT HPUX
 
-#  if !defined (HP_IA64)
-#  include "RunTime/RTE_SystemPA.h" /* nocheck */
-#  define USE_OWN_COROUTINE_CONTEXT
-#endif
+#  if defined (HP_IA64)
+#    include <ucontext.h>
+#    define USE_UCONTEXT HPUX
+#  else /* swapcontext() works on PA-RISC, but only with the newest compiler! */
+#    include "RunTime/RTE_SystemPA.h" /* nocheck */
+#    define USE_OWN_COROUTINE_CONTEXT
+#  endif
 #endif  /* PA20W || HP_IA64 */
 
 #if defined(_IBMR2)
