@@ -123,14 +123,11 @@ RTE_ActiveDatabase * RTE_DBRegister::GetActiveDatabase( const RTE_DBName dbName,
 {
     RTE_DBName name;
     strcpy(name,dbName);
-    RTE_ActiveInstallation * activeInstallation = GetActiveInstallationByDBName(name,errList);
-    if ( NULL == activeInstallation )
-    {
-        errList = SAPDBErr_MessageList(RTE_CONTEXT,RTEERR_DBSTATE_DATABASE_NOT_FOUND,dbName);
-        return NULL;
-    }
-    RTE_ActiveDatabase * activeDatabase = new RTE_ActiveDatabase(*activeInstallation,activeInstallation->GetDBRoot(),name);
-    delete activeInstallation;
+    // to avoid accessing registry (files), it is not checked if the database is actually registered. 
+    // We expect that this method is called when the existence has already been checked!
+    RTE_ActiveInstallation activeInstallation;  
+    RTE_ActiveDatabase * activeDatabase = new RTE_ActiveDatabase(activeInstallation,activeInstallation.GetDBRoot(),name);
+
     return activeDatabase;
 }
 
