@@ -72,7 +72,7 @@ int main(int argc, SAPDB_Char *argv[])
 
     if(SAPDB_INIFILE_RESULT_OK != ok)
     {
-        fprintf(stderr, "Failed to get root path for '%s'\n", dbname);
+        fprintf(stderr, "Failed to get root path for '%s': %s\n", dbname, &errtext[0]);
         exit(1);
     }
     else
