@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 ---------------------------------------------------------------------*/
 
@@ -58,6 +59,7 @@
 #endif
 
 
+#define SERVICE_DATABASE_LOCK_TIMEOUT_  60
 /*===========================================================================*
  *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
  *===========================================================================*/
@@ -416,11 +418,14 @@ APIRET RTE_NTService::updateParameters( SERVERDB_PARAM_REC *Params )
     RegistryEntries[values].ulValueType  = REG_SZ;
     values++;
 
-    RegistryEntries[values].pszValueName = REG_VN_DUMP_ENABLED;
-    RegistryEntries[values].pValue       = &Params->fDumpEnabled;
-    RegistryEntries[values].ulValueSize  = sizeof(DWORD);
-    RegistryEntries[values].ulValueType  = REG_DWORD;
-    values++;
+    if ( Params->fDumpEnabled )
+    {
+        RegistryEntries[values].pszValueName = REG_VN_DUMP_ENABLED;
+        RegistryEntries[values].pValue       = &Params->fDumpEnabled;
+        RegistryEntries[values].ulValueSize  = sizeof(DWORD);
+        RegistryEntries[values].ulValueType  = REG_DWORD;
+        values++;
+    }
 
     RegistryEntries[values].pszValueName = REG_VN_ALWAYS_CHECK_CONN;
     RegistryEntries[values].pValue       = &Params->fAlwaysCheckConn;
@@ -680,7 +685,7 @@ SAPDB_Bool RTE_NTService::UpdateServiceEntry (
 
                 if ( rc == NO_ERROR )
                 {
-                    if ((ScLock = LockServiceDatabase (hScM)) == NULL)
+                    if ((ScLock = LockServiceDatabaseWithTimeout (hScM,SERVICE_DATABASE_LOCK_TIMEOUT_)) == NULL)
                     {
                         rc = GetLastError();
                     }
@@ -772,7 +777,7 @@ SAPDB_Bool RTE_NTService::UpdateServiceEntry (
             {
                 serviceType = SERVICE_WIN32_OWN_PROCESS;
             }
-            if ((ScLock = LockServiceDatabase (hScM)) == NULL)
+            if ((ScLock = LockServiceDatabaseWithTimeout (hScM,SERVICE_DATABASE_LOCK_TIMEOUT_)) == NULL)
             {
                 rc = GetLastError();
             }
@@ -894,7 +899,7 @@ SAPDB_Bool RTE_NTService::RemoveServiceEntry (
         // ---- REMOVE SERVICE
         //
         //
-        if ((ScLock = LockServiceDatabase (hScM)) == NULL)
+        if ((ScLock = LockServiceDatabaseWithTimeout (hScM,SERVICE_DATABASE_LOCK_TIMEOUT_)) == NULL)
         {
             rc = GetLastError();
         }
@@ -1246,3 +1251,26 @@ APIRET RTE_NTService::GetStatus(DWORD &dwCurrentState)
     return rc;
 };
 
+SC_LOCK RTE_NTService::LockServiceDatabaseWithTimeout( SC_HANDLE hScM, SAPDB_Int4 timeoutToUse)
+{
+   	SC_LOCK lock;
+   	for(SAPDB_Int4 timeout=0 ; timeout < timeoutToUse ; timeout++)
+   	{
+   		if( lock = LockServiceDatabase( hScM ))
+   		{
+   			break;
+   		}
+   		else
+   		{
+   			if(ERROR_SERVICE_DATABASE_LOCKED == GetLastError())
+   			{
+   				SLEEP(1000);
+   			}
+   			else
+   			{
+   				break;
+   			}
+   		}
+   	}
+   	return lock;
+}
