@@ -1136,11 +1136,11 @@ RTE_VerifyUserPasswordCombination(
 
     close(pipeClientInput[0]);
     close(pipeClientOutput[1]);
-    char cryptBuffer[64];   /* Needed for MD5 and blowfish encrytped passwords */
-    memset(cryptBuffer, 0, 64);
+    char cryptBuffer[1024];   /* Needed for MD5 and blowfish encrytped passwords */
+    memset(cryptBuffer, 0, 1024);
     memset(cryptBuffer, ' ', 15);
 
-    if ( read(pipeClientOutput[0], cryptBuffer, 64) <= 1 )
+    if ( read(pipeClientOutput[0], cryptBuffer, 1024) <= 1 )
     {
         rc = RTESys_GetLastError();
         close(pipeClientInput[1]);
@@ -1166,7 +1166,7 @@ RTE_VerifyUserPasswordCombination(
     else
     {
         /* Empty password is not crypted... */
-        GeneratedPassword = passwd;
+        GeneratedPassword = "";
     }
 
     if ( write(pipeClientInput[1], GeneratedPassword, strlen(GeneratedPassword) + 1  ) != (strlen(GeneratedPassword) + 1) )
