@@ -71,7 +71,7 @@
 #  endif
 #endif
 
-#if defined(SUN)
+#if defined(SOLARIS) || defined(SVR4)
 #  if defined(BIT64)
 extern int RTESys_AtomicCmpxchgWithMembarInt4( SAPDB_Int4 *address,
                                                SAPDB_Int4 expectedValue,
@@ -92,86 +92,150 @@ int RTESys_AtomicCmpxchgWithMembarInt8( SAPDB_Int8 *address,
                                         SAPDB_Int8 newValuecmpxchg4b,
                                         SAPDB_Int8 *pOldValue);
 #  endif
-#endif /* SUN */
+#endif /* SOLARIS || SVR4 */
 
 /* #ifndef KERNEL_LZU */
 #include "RunTime/System/RTESys_SystemInfo.h" /* nocheck */
 #include "RunTime/System/RTESys_Spinlock.h" /* nocheck */
 
 static SAPDB_UInt4 AtomicLockPoolLock(void *memoryAddress);
+/*! define */
 #define RTESys_AtomicLockPoolLock AtomicLockPoolLock
 static void AtomicLockPoolUnlock(void *memoryAddress, SAPDB_UInt4 lockIndex);
+/*! define */
 #define RTESys_AtomicLockPoolUnlock AtomicLockPoolUnlock
 /* #endif */ /* KERNEL_LZU */
 
-/*=========================================================================================*/
-/*! Atomic read/write of 64Bit values */
-/*=========================================================================================*/
-
 #if !defined( InterlockedCompareExchange ) && ( ( _MSC_VER >= 1310 ) || defined( __INTEL_COMPILER ) )
 #pragma intrinsic( _InterlockedCompareExchange )
+/*! define */
 #define InterlockedCompareExchange _InterlockedCompareExchange
 #endif
 
 #if !defined( InterlockedCompareExchange ) && ( ( _MSC_VER >= 1310 ) || defined( __INTEL_COMPILER ) )
 #pragma intrinsic( _InterlockedCompareExchangePointer )
+/*! define */
 #define InterlockedCompareExchangePointer _InterlockedCompareExchangePointer
 #endif
 
-#if !defined(BIT64)
-/*!
-   @brief Atomic read operation on 8byte aligned signed value
+/*=========================================================================================*/
+/* Atomic read/write of values */
+/*=========================================================================================*/
+#if defined(PA20W)
 
-   On 32bit platform reading an 8Byte value is not atomic.
-
-   @param memoryPosition [inout] the memory position to exchange
-   @return [SAPDB_Int8] the value at the given position
+/*
+   On HPUX PA-RISC no memory barrier is needed to synchronize with other processors.
+   Therefore atomic operations are idnetical with 'normal' operations...
  */
+SAPDB_Int8  RTESys_AtomicReadInt8( SAPDB_Int8 * memoryPosition )   { return *memoryPosition; }
+/*---*/
+SAPDB_UInt8 RTESys_AtomicReadUInt8( SAPDB_UInt8 * memoryPosition ) { return *memoryPosition; }
+/*---*/
+SAPDB_Int4  RTESys_AtomicReadInt4( SAPDB_Int4 * memoryPosition )   { return *memoryPosition; }
+/*---*/
+SAPDB_UInt4 RTESys_AtomicReadUInt4( SAPDB_UInt4 * memoryPosition ) { return *memoryPosition; }
+/*---*/
+void *      RTESys_AtomicReadPointer( void ** memoryPosition )     { return *memoryPosition; }
+/*---*/
+void RTESys_AtomicWriteInt8( SAPDB_Int8 * memoryPosition, SAPDB_Int8 const newValue )    { *memoryPosition=newValue; }
+/*---*/
+void RTESys_AtomicWriteUInt8( SAPDB_UInt8 * memoryPosition, SAPDB_UInt8 const newValue ) { *memoryPosition=newValue; }
+/*---*/
+void RTESys_AtomicWriteInt4( SAPDB_Int4 * memoryPosition, SAPDB_Int4 const newValue )    { *memoryPosition=newValue; }
+/*---*/
+void RTESys_AtomicWriteUInt4( SAPDB_UInt4 * memoryPosition, SAPDB_UInt4 const newValue ) { *memoryPosition=newValue; }
+/*---*/
+void RTESys_AtomicWritePointer( void * * memoryPosition, void * const newValue )         { *memoryPosition=newValue; }
+
+#else
+/*
+  These functions have been introducded to allow consistent atomic access on various types
+
+  With more widespread use of CompareAndExchange and to prevent otherwise needed MemoryBarriers
+  the usage was extended to atomic access on shared data!
+ */
+
+/*=========================================================================================*/
+/* Atomic read values */
+/*=========================================================================================*/
 SAPDB_Int8 RTESys_AtomicReadInt8( SAPDB_Int8 * memoryPosition )
 {
-    SAPDB_Int8 result;
-    RTESys_CmpxchgInt8(memoryPosition, 4711, 4711, &result);
+    SAPDB_Int8 result = 0;
+    RTESys_CmpxchgInt8(memoryPosition, (SAPDB_Int8)4711, (SAPDB_Int8)4711, &result);
     return result;
 }
-
-/*!
-   @brief same of 8byte aligned unsigned value
-   @param memoryPosition [inout] the memory position to exchange
-   @return [SAPDB_Int8] the value at the given position
- */
+/*---*/
 SAPDB_UInt8 RTESys_AtomicReadUInt8( SAPDB_UInt8 * memoryPosition )
 {
-    SAPDB_UInt8 result;
-    RTESys_CmpxchgUInt8(memoryPosition, 4711U, 4711U, &result);
+    SAPDB_UInt8 result = 0;
+    RTESys_CmpxchgUInt8(memoryPosition, (SAPDB_UInt8)4711U, (SAPDB_UInt8)4711U, &result);
+    return result;
+}
+/*---*/
+SAPDB_Int4 RTESys_AtomicReadInt4( SAPDB_Int4 * memoryPosition )
+{
+    SAPDB_Int4 result = 0;
+    RTESys_CmpxchgInt4(memoryPosition, (SAPDB_Int4)4711, (SAPDB_Int4)4711, &result);
+    return result;
+}
+/*---*/
+SAPDB_UInt4 RTESys_AtomicReadUInt4( SAPDB_UInt4 * memoryPosition )
+{
+    SAPDB_UInt4 result = 0;
+    RTESys_CmpxchgUInt4(memoryPosition, (SAPDB_UInt4)4711, (SAPDB_UInt4)4711, &result);
+    return result;
+}
+/*---*/
+void * RTESys_AtomicReadPointer( void ** memoryPosition )
+{
+    void * result = 0;
+    RTESys_CmpxchgPointer(memoryPosition, (void *)(((char *)0) + 4711), (void *)(((char *)0) + 4711), &result);
     return result;
 }
 
-/*!
-   @brief Atomic write operation on 8byte aligned signed value
-
-   On 32bit platform writing an 8Byte value is not atomic.
-
-   @param memoryPosition [inout] the memory position to write to
-   @param newValue [in] the new value for the given position
- */
-void RTESys_AtomicWriteInt8( SAPDB_Int8 VAR_VALUE_REF memoryPosition, SAPDB_Int8 const newValue )
+/*=========================================================================================*/
+/* Atomic write values */
+/*=========================================================================================*/
+void RTESys_AtomicWriteInt8( SAPDB_Int8 * memoryPosition, SAPDB_Int8 const newValue )
 {
     SAPDB_Int8 expectedValue = *memoryPosition; /* dirty read */
-    while ( !RTESys_CmpxchgInt8(memoryPosition, expectedValue, newValue, &expectedValue) )
-        ; /* should not loop too often... */
+    SAPDB_Int8 foundValue = 0;
+    while ( !RTESys_CmpxchgInt8(memoryPosition, expectedValue, newValue, &foundValue) )
+        expectedValue = foundValue; /* should not loop too often... */
 }
-
-/*!
-   @brief same of 8byte aligned unsigned value
-   @param memoryPosition [inout] the memory position to read
-   @param newValue [in] the new value for the given position
- */
-void RTESys_AtomicWriteUInt8( SAPDB_UInt8 VAR_VALUE_REF memoryPosition, SAPDB_UInt8 const newValue )
+/*---*/
+void RTESys_AtomicWriteUInt8( SAPDB_UInt8 * memoryPosition, SAPDB_UInt8 const newValue )
 {
     SAPDB_UInt8 expectedValue = *memoryPosition; /* dirty read */
-    while ( !RTESys_CmpxchgUInt8(memoryPosition, expectedValue, newValue, &expectedValue) )
-        ; /* should not loop too often... */
+    SAPDB_UInt8 foundValue = 0;
+    while ( !RTESys_CmpxchgUInt8(memoryPosition, expectedValue, newValue, &foundValue) )
+        expectedValue = foundValue; /* should not loop too often... */
 }
+/*---*/
+void RTESys_AtomicWriteInt4( SAPDB_Int4 * memoryPosition, SAPDB_Int4 const newValue )
+{
+    SAPDB_Int4 expectedValue = *memoryPosition; /* dirty read */
+    SAPDB_Int4 foundValue = 0;
+    while ( !RTESys_CmpxchgInt4(memoryPosition, expectedValue, newValue, &foundValue) )
+        expectedValue = foundValue; /* should not loop too often... */
+}
+/*---*/
+void RTESys_AtomicWriteUInt4( SAPDB_UInt4 * memoryPosition, SAPDB_UInt4 const newValue )
+{
+    SAPDB_UInt4 expectedValue = *memoryPosition; /* dirty read */
+    SAPDB_UInt4 foundValue = 0;
+    while ( !RTESys_CmpxchgUInt4(memoryPosition, expectedValue, newValue, &foundValue) )
+        expectedValue = foundValue; /* should not loop too often... */
+}
+/*---*/
+void RTESys_AtomicWritePointer( void * * memoryPosition, void * const newValue )
+{
+    void * expectedValue = *memoryPosition; /* dirty read */
+    void * foundValue = 0;
+    while ( !RTESys_CmpxchgPointer(memoryPosition, expectedValue, newValue, &foundValue) )
+        expectedValue = foundValue; /* should not loop too often... */
+}
+
 #endif
 
 /*=========================================================================================*/
@@ -381,7 +445,7 @@ SAPDB_Bool RTESys_CmpxchgInt8( SAPDB_Int8 *memoryPosition,
     SAPDB_UInt4 resultLow = newValue >> 32;
     SAPDB_UInt4 resultHigh = expectedValue >> 32;
     __asm__ __volatile__ (
-		"push %%ebx\n\t"
+        "push %%ebx\n\t"
 		"movl %3, %%eax\n\t"
 		"movl %4, %%edx\n\t"
 		"movl %1, %%ebx\n\t"
@@ -389,7 +453,7 @@ SAPDB_Bool RTESys_CmpxchgInt8( SAPDB_Int8 *memoryPosition,
 		"lock; cmpxchg8b %0\n\t"
 		"movl %%edx, %6\n\t"
 		"movl %%eax, %5\n\t"
-		"pop %%ebx\n\t"
+        "pop %%ebx\n\t"
 		: 
 		: "m"(*memoryPosition), 
 		  "m"(newValue),
@@ -433,7 +497,7 @@ SAPDB_Bool RTESys_CmpxchgUInt8( SAPDB_UInt8 *memoryPosition,
     SAPDB_UInt4 resultLow = newValue >> 32;
     SAPDB_UInt4 resultHigh = expectedValue >> 32;
     __asm__ __volatile__ (
-		"push %%ebx\n\t"
+        "push %%ebx\n\t"
 		"movl %3, %%eax\n\t"
 		"movl %4, %%edx\n\t"
 		"movl %1, %%ebx\n\t"
@@ -441,7 +505,7 @@ SAPDB_Bool RTESys_CmpxchgUInt8( SAPDB_UInt8 *memoryPosition,
 		"lock; cmpxchg8b %0\n\t"
 		"movl %%edx, %6\n\t"
 		"movl %%eax, %5\n\t"
-		"pop %%ebx\n\t"
+        "pop %%ebx\n\t"
 		: 
 		: "m"(*memoryPosition), 
 		  "m"(newValue),
@@ -833,7 +897,7 @@ SAPDB_Bool RTESys_CmpxchgPointer( void * *memoryPosition,
     }
 }
 
-#elif defined(SUN)
+#elif defined(SOLARIS) || defined(SVR4)
 
 #if !defined(BIT64)
 /*SUN*/int RTESys_AtomicCmpxchgWithMembarInt4( SAPDB_Int4 *address,
@@ -937,120 +1001,121 @@ SAPDB_Bool RTESys_CmpxchgPointer( void * *memoryPosition,
 
 #include <machine/sys/inline.h>
 
-/*HP_IA64*/SAPDB_Bool RTESys_CmpxchgInt4( SAPDB_Int4 *memoryPosition,
-/*HP_IA64*/                               SAPDB_Int4 const expectedValue,
-/*HP_IA64*/                               SAPDB_Int4 const newValue,
-/*HP_IA64*/                               SAPDB_Int4 *pOldValue)
-/*HP_IA64*/{
-/*HP_IA64*/    _Asm_mov_to_ar
-/*HP_IA64*/    (
-/*HP_IA64*/        (_Asm_app_reg)_AREG_CCV,
-/*HP_IA64*/        (SAPDB_UInt8)((SAPDB_UInt4)expectedValue),
-/*HP_IA64*/        FENCE
-/*HP_IA64*/    );
-/*HP_IA64*/    *pOldValue = _Asm_cmpxchg
-/*HP_IA64*/    (
-/*HP_IA64*/        (_Asm_sz)_SZ_W,
-/*HP_IA64*/        (_Asm_sem)_SEM_ACQ,
-/*HP_IA64*/        (void *)memoryPosition,
-/*HP_IA64*/        (SAPDB_UInt8)newValue,
-/*HP_IA64*/        (_Asm_ldhint)_LDHINT_NONE
-/*HP_IA64*/    );
-/*HP_IA64*/    return (*pOldValue == expectedValue);
-/*HP_IA64*/}
+SAPDB_Bool RTESys_CmpxchgInt4( SAPDB_Int4 *memoryPosition,
+                               SAPDB_Int4 const expectedValue,
+                               SAPDB_Int4 const newValue,
+                               SAPDB_Int4 *pOldValue)
+{
+    _Asm_mov_to_ar
+    (
+        (_Asm_app_reg)_AREG_CCV,
+        (SAPDB_UInt8)((SAPDB_UInt4)expectedValue),
+        FENCE
+    );
+    *pOldValue = _Asm_cmpxchg
+    (
+        (_Asm_sz)_SZ_W,
+        (_Asm_sem)_SEM_ACQ,
+        (void *)memoryPosition,
+        (SAPDB_UInt8)newValue,
+        (_Asm_ldhint)_LDHINT_NONE
+    );
+    return (*pOldValue == expectedValue);
+}
 
-/*HP_IA64*/SAPDB_Bool RTESys_CmpxchgUInt4( SAPDB_UInt4 *memoryPosition,
-/*HP_IA64*/                                SAPDB_UInt4 const expectedValue,
-/*HP_IA64*/                                SAPDB_UInt4 const newValue,
-/*HP_IA64*/                                SAPDB_UInt4 *pOldValue)
-/*HP_IA64*/{
-/*HP_IA64*/    _Asm_mov_to_ar
-/*HP_IA64*/    (
-/*HP_IA64*/        (_Asm_app_reg)_AREG_CCV,
-/*HP_IA64*/        (SAPDB_UInt8)expectedValue,
-/*HP_IA64*/        FENCE
-/*HP_IA64*/    );
-/*HP_IA64*/    *pOldValue = _Asm_cmpxchg
-/*HP_IA64*/    (
-/*HP_IA64*/        (_Asm_sz)_SZ_W,
-/*HP_IA64*/        (_Asm_sem)_SEM_ACQ,
-/*HP_IA64*/        (void *)memoryPosition,
-/*HP_IA64*/        (SAPDB_UInt8)newValue,
-/*HP_IA64*/        (_Asm_ldhint)_LDHINT_NONE
-/*HP_IA64*/    );
-/*HP_IA64*/    return (*pOldValue == expectedValue);
-/*HP_IA64*/}
+SAPDB_Bool RTESys_CmpxchgUInt4( SAPDB_UInt4 *memoryPosition,
+                                SAPDB_UInt4 const expectedValue,
+                                SAPDB_UInt4 const newValue,
+                                SAPDB_UInt4 *pOldValue)
+{
+    _Asm_mov_to_ar
+    (
+        (_Asm_app_reg)_AREG_CCV,
+        (SAPDB_UInt8)expectedValue,
+        FENCE
+    );
+    *pOldValue = _Asm_cmpxchg
+    (
+        (_Asm_sz)_SZ_W,
+        (_Asm_sem)_SEM_ACQ,
+        (void *)memoryPosition,
+        (SAPDB_UInt8)newValue,
+        (_Asm_ldhint)_LDHINT_NONE
+    );
+    return (*pOldValue == expectedValue);
+}
 
-/*HP_IA64*/SAPDB_Bool RTESys_CmpxchgInt8( SAPDB_Int8 *memoryPosition,
-/*HP_IA64*/                               SAPDB_Int8 const expectedValue,
-/*HP_IA64*/                               SAPDB_Int8 const newValue,
-/*HP_IA64*/                               SAPDB_Int8 *pOldValue)
-/*HP_IA64*/{
-/*HP_IA64*/    _Asm_mov_to_ar
-/*HP_IA64*/    (
-/*HP_IA64*/        (_Asm_app_reg)_AREG_CCV,
-/*HP_IA64*/        (SAPDB_UInt8)expectedValue,
-/*HP_IA64*/        FENCE
-/*HP_IA64*/    );
-/*HP_IA64*/    *pOldValue = _Asm_cmpxchg
-/*HP_IA64*/    (
-/*HP_IA64*/        (_Asm_sz)_SZ_D,
-/*HP_IA64*/        (_Asm_sem)_SEM_ACQ,
-/*HP_IA64*/        (void *)memoryPosition,
-/*HP_IA64*/        (SAPDB_UInt8)newValue,
-/*HP_IA64*/        (_Asm_ldhint)_LDHINT_NONE
-/*HP_IA64*/    );
-/*HP_IA64*/    return (*pOldValue == expectedValue);
-/*HP_IA64*/}
+SAPDB_Bool RTESys_CmpxchgInt8( SAPDB_Int8 *memoryPosition,
+                               SAPDB_Int8 const expectedValue,
+                               SAPDB_Int8 const newValue,
+                               SAPDB_Int8 *pOldValue)
+{
+    _Asm_mov_to_ar
+    (
+        (_Asm_app_reg)_AREG_CCV,
+        (SAPDB_UInt8)expectedValue,
+        FENCE
+    );
+    *pOldValue = _Asm_cmpxchg
+    (
+        (_Asm_sz)_SZ_D,
+        (_Asm_sem)_SEM_ACQ,
+        (void *)memoryPosition,
+        (SAPDB_UInt8)newValue,
+        (_Asm_ldhint)_LDHINT_NONE
+    );
+    return (*pOldValue == expectedValue);
+}
 
-/*HP_IA64*/SAPDB_Bool RTESys_CmpxchgUInt8( SAPDB_UInt8 *memoryPosition,
-/*HP_IA64*/                                SAPDB_UInt8 const expectedValue,
-/*HP_IA64*/                                SAPDB_UInt8 const newValue,
-/*HP_IA64*/                                SAPDB_UInt8 *pOldValue)
-/*HP_IA64*/{
-/*HP_IA64*/    _Asm_mov_to_ar
-/*HP_IA64*/    (
-/*HP_IA64*/        (_Asm_app_reg)_AREG_CCV,
-/*HP_IA64*/        (SAPDB_UInt8)expectedValue,
-/*HP_IA64*/        FENCE
-/*HP_IA64*/    );
-/*HP_IA64*/    *pOldValue = _Asm_cmpxchg
-/*HP_IA64*/    (
-/*HP_IA64*/        (_Asm_sz)_SZ_D,
-/*HP_IA64*/        (_Asm_sem)_SEM_ACQ,
-/*HP_IA64*/        (void *)memoryPosition,
-/*HP_IA64*/        (SAPDB_UInt8)newValue,
-/*HP_IA64*/        (_Asm_ldhint)_LDHINT_NONE
-/*HP_IA64*/    );
-/*HP_IA64*/    return (*pOldValue == expectedValue);
-/*HP_IA64*/}
+SAPDB_Bool RTESys_CmpxchgUInt8( SAPDB_UInt8 *memoryPosition,
+                                SAPDB_UInt8 const expectedValue,
+                                SAPDB_UInt8 const newValue,
+                                SAPDB_UInt8 *pOldValue)
+{
+    _Asm_mov_to_ar
+    (
+        (_Asm_app_reg)_AREG_CCV,
+        (SAPDB_UInt8)expectedValue,
+        FENCE
+    );
+    *pOldValue = _Asm_cmpxchg
+    (
+        (_Asm_sz)_SZ_D,
+        (_Asm_sem)_SEM_ACQ,
+        (void *)memoryPosition,
+        (SAPDB_UInt8)newValue,
+        (_Asm_ldhint)_LDHINT_NONE
+    );
+    return (*pOldValue == expectedValue);
+}
 
-/*HP_IA64*/SAPDB_Bool RTESys_CmpxchgPointer( void * *memoryPosition,
-/*HP_IA64*/                                  void * const expectedValue,
-/*HP_IA64*/                                  void * const newValue,
-/*HP_IA64*/                                  void * *pOldValue)
-/*HP_IA64*/{
-/*HP_IA64*/    _Asm_mov_to_ar
-/*HP_IA64*/    (
-/*HP_IA64*/        (_Asm_app_reg)_AREG_CCV,
-/*HP_IA64*/        (SAPDB_UInt8)expectedValue,
-/*HP_IA64*/        FENCE
-/*HP_IA64*/    );
-/*HP_IA64*/    *pOldValue = (void *)_Asm_cmpxchg
-/*HP_IA64*/        (
-/*HP_IA64*/            (_Asm_sz)_SZ_D,
-/*HP_IA64*/            (_Asm_sem)_SEM_ACQ,
-/*HP_IA64*/            (void *)memoryPosition,
-/*HP_IA64*/            (SAPDB_UInt8)newValue,
-/*HP_IA64*/            (_Asm_ldhint)_LDHINT_NONE
-/*HP_IA64*/        );
-/*HP_IA64*/    return (*pOldValue == expectedValue);
-/*HP_IA64*/}
+SAPDB_Bool RTESys_CmpxchgPointer( void * *memoryPosition,
+                                  void * const expectedValue,
+                                  void * const newValue,
+                                  void * *pOldValue)
+{
+    _Asm_mov_to_ar
+    (
+        (_Asm_app_reg)_AREG_CCV,
+        (SAPDB_UInt8)expectedValue,
+        FENCE
+    );
+    *pOldValue = (void *)_Asm_cmpxchg
+        (
+            (_Asm_sz)_SZ_D,
+            (_Asm_sem)_SEM_ACQ,
+            (void *)memoryPosition,
+            (SAPDB_UInt8)newValue,
+            (_Asm_ldhint)_LDHINT_NONE
+        );
+    return (*pOldValue == expectedValue);
+}
 
 #endif
 
 #else
 
+/*! define */
 #define CompareAndExchange(funcName_, valueType_) \
     SAPDB_Bool funcName_ ( valueType_ *     memoryPosition, \
                            valueType_ const expectedValue, \
@@ -1069,10 +1134,45 @@ SAPDB_Bool RTESys_CmpxchgPointer( void * *memoryPosition,
         return ( expectedValue == currentValue ); \
     }
 
+/*! 
+  @brief CompareAndExchange for SAPDB_Int4 
+  @param memoryPosition [in]
+  @param expectedValue [in]
+  @param newValue [in]
+  @param oldValue [out]
+ */
 CompareAndExchange(RTESys_CmpxchgInt4,    SAPDB_Int4)
+/*! 
+  @brief CompareAndExchange for SAPDB_UInt4 
+  @param memoryPosition [in]
+  @param expectedValue [in]
+  @param newValue [in]
+  @param oldValue [out]
+ */
 CompareAndExchange(RTESys_CmpxchgUInt4,   SAPDB_UInt4)
+/*! 
+  @brief CompareAndExchange for SAPDB_Int8
+  @param memoryPosition [in]
+  @param expectedValue [in]
+  @param newValue [in]
+  @param oldValue [out]
+ */
 CompareAndExchange(RTESys_CmpxchgInt8,    SAPDB_Int8)
+/*! 
+  @brief CompareAndExchange for SAPDB_UInt8 
+  @param memoryPosition [in]
+  @param expectedValue [in]
+  @param newValue [in]
+  @param oldValue [out]
+ */
 CompareAndExchange(RTESys_CmpxchgUInt8,   SAPDB_UInt8)
+/*! 
+  @brief CompareAndExchange for void *
+  @param memoryPosition [in]
+  @param expectedValue [in]
+  @param newValue [in]
+  @param oldValue [out]
+ */
 CompareAndExchange(RTESys_CmpxchgPointer, void *)
 
 #endif /* RTESYS_HAS_NATIVE_ATOMIC_OPERATION */
@@ -1081,54 +1181,66 @@ CompareAndExchange(RTESys_CmpxchgPointer, void *)
 /*! Atomic modification (increment/decrement) */
 /*=========================================================================================*/
 
-#define AtomicModify(name_, deltaType_) \
-    SAPDB_##name_ RTESys_AtomicModify##name_ ( SAPDB_##name_ *     memoryPosition, \
+/*! define */
+#define AtomicModify(name_, deltaType_) SAPDB_##name_ RTESys_AtomicModify##name_ ( SAPDB_##name_ * memoryPosition, \
                                       deltaType_ const deltaValue ) \
     { \
-        SAPDB_##name_ oldValue = *memoryPosition; \
-        SAPDB_##name_ newValue; \
+        SAPDB_##name_ oldValue = 0; \
+        SAPDB_##name_ newValue = 0; \
+        SAPDB_##name_ foundValue = *memoryPosition; \
         do { \
+            oldValue = foundValue; \
             newValue = oldValue + deltaValue; \
-        } while( !RTESys_Cmpxchg##name_ (memoryPosition, oldValue, newValue, &oldValue) ); \
+        } while( !RTESys_Cmpxchg##name_ (memoryPosition, oldValue, newValue, &foundValue) ); \
         return newValue; \
     }
 
-AtomicModify(Int4,  SAPDB_Int4)
-AtomicModify(UInt4, SAPDB_Int4)
-
-#if defined(BIT64)
-
+/*! 
+  @brief Atomic modify for SAPDB_Int8
+  @param memoryPosition [in]
+  @param deltaValue [in]
+  @return newValue
+ */
 AtomicModify(Int8,  SAPDB_Int8)
+/*! 
+  @brief Atomic modify for SAPDB_UInt8
+  @param memoryPosition [in]
+  @param deltaValue [in]
+  @return newValue
+ */
 AtomicModify(UInt8, SAPDB_Int8)
-
-#else
-
-# define AtomicModifyAtomicRead(name_, deltaType_) \
-    SAPDB_##name_ RTESys_AtomicModify##name_ ( SAPDB_##name_ *     memoryPosition, \
-                                               deltaType_ const deltaValue ) \
-    { \
-        SAPDB_##name_ oldValue = RTESys_AtomicRead##name_ (memoryPosition); \
-        SAPDB_##name_ newValue; \
-        do { \
-            newValue = oldValue + deltaValue; \
-        } while( !RTESys_Cmpxchg##name_ (memoryPosition, oldValue, newValue, &oldValue) ); \
-        return newValue; \
-    }
-
-AtomicModifyAtomicRead(Int8,    SAPDB_Int8)
-AtomicModifyAtomicRead(UInt8,   SAPDB_Int8)
-
-#endif
-
+/*! 
+  @brief Atomic modify for SAPDB_Int4
+  @param memoryPosition [in]
+  @param deltaValue [in]
+  @return newValue
+ */
+AtomicModify(Int4,  SAPDB_Int4)
+/*! 
+  @brief Atomic modify for SAPDB_UInt4
+  @param memoryPosition [in]
+  @param deltaValue [in]
+  @return newValue
+ */
+AtomicModify(UInt4, SAPDB_Int4)
+/*! 
+  @brief Atomic modify for SAPDB_UInt8
+  @param memoryPosition [in]
+  @param scaling [in]
+  @param deltaValue [in]
+  @return newValue
+ */
 void * RTESys_AtomicModifyPointer( void * *          memoryPosition,
                                  SAPDB_ULong const scaling,
                                  SAPDB_Long const  deltaValue )
 {
-    void * oldValue = *memoryPosition;
-    void * newValue;
+    void * oldValue = 0;
+    void * newValue = 0;
+    void * foundValue = *memoryPosition;
     do {
+        oldValue = foundValue;
         newValue = (((SAPDB_Byte *)oldValue) + (scaling * deltaValue));
-    } while( !RTESys_CmpxchgPointer(memoryPosition, oldValue, newValue, &oldValue) );
+    } while( !RTESys_CmpxchgPointer(memoryPosition, oldValue, newValue, &foundValue) );
     return newValue;
 }
 
@@ -1136,80 +1248,103 @@ void * RTESys_AtomicModifyPointer( void * *          memoryPosition,
 /*! Atomic modification (generic function) */
 /*=========================================================================================*/
 
+/*! define */
 #define AtomicOperation(name_, valueType_) \
     void RTESys_AtomicOperation##name_ ( valueType_ *           memoryPosition, \
                                          RTESys_AtomicOp##name_ operationFunction, \
                                          void *                 operationContext ) \
     { \
-        valueType_ oldValue; \
-        valueType_ newValue; \
-        valueType_ expectedValue; \
+        valueType_ oldValue = 0; \
+        valueType_ newValue = 0; \
+        valueType_ foundValue = *memoryPosition; \
 \
-        oldValue = *memoryPosition; \
         do \
         { \
-           expectedValue = oldValue; \
+           oldValue = foundValue; \
            if ( !(*operationFunction)(oldValue, &newValue, operationContext) ) \
                break; \
-        } while ( !RTESys_Cmpxchg##name_ (memoryPosition, expectedValue, newValue, &oldValue) ); \
+        } while ( !RTESys_Cmpxchg##name_ (memoryPosition, oldValue, newValue, &foundValue) ); \
         return; \
     }
 
-AtomicOperation(Int4,    SAPDB_Int4)
-AtomicOperation(UInt4,   SAPDB_UInt4)
-
-#if defined(BIT64)
-
+/*! 
+  @brief Atomic operation for SAPDB_Int8
+  The operation given is executed atomically by calling function with given context until new value
+  can be stored atomically.
+  @param memoryPosition [in]
+  @param operationFunction [in] calculates new value
+  @param operationContext [in] context of this function
+  @return newValue
+ */
 AtomicOperation(Int8,    SAPDB_Int8)
+/*! 
+  @brief Atomic operation for SAPDB_UInt8
+  The operation given is executed atomically by calling function with given context until new value
+  can be stored atomically.
+  @param memoryPosition [in]
+  @param operationFunction [in] calculates new value
+  @param operationContext [in] context of this function
+  @return newValue
+ */
 AtomicOperation(UInt8,   SAPDB_UInt8)
-
-#else
-
-# define AtomicOperationAtomicRead(name_, valueType_) \
-    void RTESys_AtomicOperation##name_ ( valueType_ *           memoryPosition, \
-                                         RTESys_AtomicOp##name_ operationFunction, \
-                                         void *                 operationContext ) \
-    { \
-        valueType_ oldValue; \
-        valueType_ expectedValue; \
-        valueType_ newValue; \
-        oldValue = RTESys_AtomicRead##name_(memoryPosition); \
-        do \
-        { \
-           expectedValue = oldValue; \
-           if ( !(*operationFunction)(oldValue, &newValue, operationContext) ) \
-               break; \
-        } while ( !RTESys_Cmpxchg##name_ (memoryPosition, expectedValue, newValue, &oldValue) ); \
-        return; \
-    }
-
-AtomicOperationAtomicRead(Int8,    SAPDB_Int8)
-AtomicOperationAtomicRead(UInt8,   SAPDB_UInt8)
-
-#endif
-
+/*! 
+  @brief Atomic operation for SAPDB_Int4
+  The operation given is executed atomically by calling function with given context until new value
+  can be stored atomically.
+  @param memoryPosition [in]
+  @param operationFunction [in] calculates new value
+  @param operationContext [in] context of this function
+  @return newValue
+ */
+AtomicOperation(Int4,    SAPDB_Int4)
+/*! 
+  @brief Atomic operation for SAPDB_UInt4
+  The operation given is executed atomically by calling function with given context until new value
+  can be stored atomically.
+  @param memoryPosition [in]
+  @param operationFunction [in] calculates new value
+  @param operationContext [in] context of this function
+  @return newValue
+ */
+AtomicOperation(UInt4,   SAPDB_UInt4)
+/*! 
+  @brief Atomic operation for SAPDB_UInt8
+  The operation given is executed atomically by calling function with given context until new value
+  can be stored atomically.
+  @param memoryPosition [in]
+  @param operationFunction [in] calculates new value
+  @param operationContext [in] context of this function
+  @return newValue
+ */
 AtomicOperation(Pointer, void *)
 
 #ifndef KERNEL_LZU
 
 #ifndef RTESYS_ATOMIC_OPERATION_POOL_SIZE
+/*! define */
 #define RTESYS_ATOMIC_OPERATION_POOL_SIZE 256
 #endif /* RTESYS_ATOMIC_OPERATION_POOL_SIZE */
+/*! global pool initialized flag */
 static SAPDB_Bool  poolInitialized = 0;
+/*! global lock pool hook */
 static RTE_Lock  **poolLockArray = 0;
 
+/*!
+  @brief initialize pool
+
+  Called while still not multithreaded!!!!!
+ */
 static void AtomicLockPoolInitialize()
 {
-    SAPDB_Byte *pLock;
-    SAPDB_UInt4 lockSize;
-    SAPDB_UInt4 iLock;
+    SAPDB_Byte *pLock = 0;
+    SAPDB_UInt4 iLock = 0;
+#if defined(PA20W) || defined(PA11)
+    SAPDB_UInt4 lockSize = SAPDB_CACHELINE_SIZE;
+#else
+    SAPDB_UInt4 lockSize = sizeof(RTE_Lock);
+#endif
 
     poolLockArray = (RTE_Lock **)malloc(RTESYS_ATOMIC_OPERATION_POOL_SIZE * sizeof(RTE_Lock *));
-#if defined(PA20W) || defined(PA11)
-    lockSize = SAPDB_CACHELINE_SIZE;
-#else
-    lockSize = sizeof(RTE_Lock);
-#endif
 
 #if defined(WIN32)
     {
@@ -1222,9 +1357,8 @@ static void AtomicLockPoolInitialize()
 #else
     {
         SAPDB_Int4 systemPageMask = (RTESys_SystemPageSize() - 1);
-        SAPDB_Byte *lockPoolPtr;
-        lockPoolPtr = (SAPDB_Byte *)malloc( systemPageMask + (RTESYS_ATOMIC_OPERATION_POOL_SIZE * lockSize) );
-        pLock = (SAPDB_Byte *)0 + ( ((lockPoolPtr - (SAPDB_Byte *)0) + systemPageMask)&(~systemPageMask) );
+        SAPDB_Byte *lockPoolPtr = (SAPDB_Byte *)malloc( systemPageMask + (RTESYS_ATOMIC_OPERATION_POOL_SIZE * lockSize) );
+        pLock = (SAPDB_Byte *)0 + ( ((lockPoolPtr - (SAPDB_Byte *)0) + systemPageMask)&(~systemPageMask) ); 
     }
 #endif
     for ( iLock = 0; iLock < RTESYS_ATOMIC_OPERATION_POOL_SIZE; iLock++ )
@@ -1235,9 +1369,16 @@ static void AtomicLockPoolInitialize()
     }
 }
 
+/*!
+  @brief lock memory address access using lock pool
+  The locking uses a limited number of pool locks. The hashing of the address
+  returns an index which must be used to release the lock
+  @param memoryAddress [in] the memroy address to lock
+  @return pool index
+ */
 static SAPDB_UInt4 AtomicLockPoolLock(void *memoryAddress)
 {
-    SAPDB_UInt4 poolIndex;
+    SAPDB_UInt4 poolIndex = 0;
     SAPDB_ULong byteOffset = ((SAPDB_Byte *)memoryAddress) - (SAPDB_Byte *)0;
     while ( 0 == (byteOffset & 1) )
     {
@@ -1258,10 +1399,18 @@ static SAPDB_UInt4 AtomicLockPoolLock(void *memoryAddress)
     return poolIndex;
 }
 
+/*!
+  @brief unlock memory address access using lock pool
+  The locking uses a limited number of pool locks. The hashing of the address
+  returns an index which must be used to release the lock
+  @param memoryAddress [in] the memroy address to lock
+  @param poolIndex [in] index return by locking pool
+  @return pool index
+ */
 static void AtomicLockPoolUnlock(void *memoryAddress, SAPDB_UInt4 poolIndex)
 {
 #ifdef SAPDB_SLOW
-    SAPDB_UInt4 checkPoolIndex;
+    SAPDB_UInt4 checkPoolIndex = 0;
     SAPDB_ULong byteOffset = ((SAPDB_Byte *)memoryAddress) - (SAPDB_Byte *)0;
 
     if ( !poolInitialized )
