@@ -57,7 +57,7 @@
 #include "RunTime/RTE_CompilerFeatures.h"
 #include "SAPDBCommon/SAPDB_Types.h"
 
-#if defined(WIN32) || defined(AIX) || defined(OSF1) || (defined(LINUX) && (defined(I386) || defined(IA64) || defined(X86_64))) || defined(SUN) || defined(HP_IA64)
+#if defined(WIN32) || defined(AIX) || defined(OSF1) || (defined(LINUX) && (defined(I386) ||  defined(IA64) || defined(X86_64))) || defined(SUN) || defined(HP_IA64)
 
 /* The coding does not need to simulate compare and exchange with spinlock */
 #define RTESYS_HAS_NATIVE_ATOMIC_OPERATION
@@ -69,6 +69,25 @@
 
 #endif
 
+#if !defined(BIT64) && defined(RTESYS_HAS_NATIVE_ATOMIC_OPERATION)
+
+#define RTESYS_HAS_ATOMIC_CAS2_OPERATION
+
+#endif
+
+#if defined(RTESYS_HAS_ATOMIC_CAS2_OPERATION)
+/*!
+   @brief Atomic CompareAndExchange value for two consecutive SAPDB_ULong
+
+   This structure is used in RTESys_CompareAndExchangeTwoULong() function
+ */
+struct RTESys_DoubleULongValue
+{
+    SAPDB_ULong first;  ///< first value
+    SAPDB_ULong second; ///< second value
+};
+#endif
+
 #if defined(__cplusplus)
 extern "C" {
 #endif
@@ -104,100 +123,100 @@ typedef SAPDB_Bool (*RTESys_AtomicOpPointer)(void * const, void * VAR_VALUE_REF,
 /*! Atomic read values */
 /*=========================================================================================*/
 
-#if !defined(BIT64)
+/*
+  These functions have been introducded to allow consistent atomic access on various types
+
+  With more widespread use of CompareAndExchange and to prevent otherwise needed MemoryBarriers
+  the usage was extended to atomic access on shared data!
+ */
+
 /*!
    @brief Atomic read operation on 8byte aligned signed value
 
-   On 32bit platform reading an 8Byte value is not atomic.
-
    @param memoryPosition [inout] the memory position to read
    @return [SAPDB_Int8] the value at the given position
  */
 SAPDB_Int8 RTESys_AtomicReadInt8( SAPDB_Int8 VAR_VALUE_REF memoryPosition );
 /*!
    @brief same of 8byte aligned unsigned value
+
    @param memoryPosition [inout] the memory position to read
-   @return [SAPDB_Int8] the value at the given position
+   @return [SAPDB_UInt8] the value at the given position
  */
 SAPDB_UInt8 RTESys_AtomicReadUInt8( SAPDB_UInt8 VAR_VALUE_REF memoryPosition );
-#else
-#  if defined(__cplusplus)
-/*! Atomic read operation on 8byte aligned signed value (64BIT machine) */
-#    define RTESys_AtomicReadInt8(memoryPosition_) (memoryPosition_)
-/*! Atomic read operation on 8byte aligned unsigned value (64BIT machine) */
-#    define RTESys_AtomicReadUInt8(memoryPosition_) (memoryPosition_)
-#  else
-/*! Atomic read operation on 8byte aligned signed value (64BIT machine) */
-#    define RTESys_AtomicReadInt8(memoryPosition_) *(memoryPosition_)
-/*! Atomic read operation on 8byte aligned unsigned value (64BIT machine) */
-#    define RTESys_AtomicReadUInt8(memoryPosition_) *(memoryPosition_)
-#  endif
-#endif
+/*!
+   @brief Atomic read operation on 4byte aligned signed value
 
-#if defined(__cplusplus)
-/*! Atomic read operation on 4byte aligned signed value */
-#    define RTESys_AtomicReadInt4(memoryPosition_) (memoryPosition_)
-/*! Atomic read operation on 4byte aligned unsigned value */
-#    define RTESys_AtomicReadUInt4(memoryPosition_) (memoryPosition_)
-#else
-/*! Atomic read operation on 4byte aligned signed value */
-#    define RTESys_AtomicReadInt4(memoryPosition_) *(memoryPosition_)
-/*! Atomic read operation on 4byte aligned unsigned value */
-#    define RTESys_AtomicReadUInt4(memoryPosition_) *(memoryPosition_)
-#endif
+   @param memoryPosition [inout] the memory position to read
+   @return [SAPDB_Int4] the value at the given position
+ */
+SAPDB_Int4 RTESys_AtomicReadInt4( SAPDB_Int4 VAR_VALUE_REF memoryPosition );
+/*!
+   @brief same of 4byte aligned unsigned value
+
+   @param memoryPosition [inout] the memory position to read
+   @return [SAPDB_UInt4] the value at the given position
+ */
+SAPDB_UInt4 RTESys_AtomicReadUInt4( SAPDB_UInt4 VAR_VALUE_REF memoryPosition );
+/*!
+   @brief Atomic read operation of a pointer
+
+   @param memoryPosition [inout] the memory position to read
+   @return [void *] the pointer at the given position
+ */
+void * RTESys_AtomicReadPointer( void * VAR_VALUE_REF memoryPosition );
 
 /*=========================================================================================*/
 /*! Atomic write values */
 /*=========================================================================================*/
 
-#if !defined(BIT64)
+/*
+  These functions have been introducded to allow consistent atomic access on various types
+
+  With more widespread use of CompareAndExchange and to prevent otherwise needed MemoryBarriers
+  the usage was extended to atomic access on shared data!
+ */
+
 /*!
    @brief Atomic write operation on 8byte aligned signed value
 
-   On 32bit platform writing an 8Byte value is not atomic.
-
    @param memoryPosition [inout] the memory position to write to
    @param newValue [in] the new value for the given position
+   @return none
  */
 void RTESys_AtomicWriteInt8( SAPDB_Int8 VAR_VALUE_REF memoryPosition, SAPDB_Int8 const newValue );
 /*!
    @brief same of 8byte aligned unsigned value
+
    @param memoryPosition [inout] the memory position to read
    @param newValue [in] the new value for the given position
+   @return none
  */
 void RTESys_AtomicWriteUInt8( SAPDB_UInt8 VAR_VALUE_REF memoryPosition, SAPDB_UInt8 const newValue );
+/*!
+   @brief Atomic write operation on 4byte aligned signed value
 
-#else
+   @param memoryPosition [inout] the memory position to write to
+   @param newValue [in] the new value for the given position
+   @return none
+ */
+void RTESys_AtomicWriteInt4( SAPDB_Int4 VAR_VALUE_REF memoryPosition, SAPDB_Int4 const newValue );
+/*!
+   @brief same of 4byte aligned unsigned value
 
-#  if defined(__cplusplus)
-/*! Atomic write operation on 8byte aligned signed value (64BIT machine) */
-#    define RTESys_AtomicWriteInt8(memoryPosition_, newValue_) (memoryPosition_) = (newValue_)
-/*! Atomic write operation on 8byte aligned unsigned value (64BIT machine) */
-#    define RTESys_AtomicWriteUInt8(memoryPosition_, newValue_) (memoryPosition_) = (newValue_)
-#  else
-/*! Atomic write operation on 8byte aligned signed value (64BIT machine) */
-#    define RTESys_AtomicWriteInt8(memoryPosition_, newValue_) *(memoryPosition_) = (newValue_)
-/*! Atomic write operation on 8byte aligned unsigned value (64BIT machine) */
-#    define RTESys_AtomicWriteUInt8(memoryPosition_, newValue_) *(memoryPosition_) = (newValue_)
-#  endif
+   @param memoryPosition [inout] the memory position to read
+   @param newValue [in] the new value for the given position
+   @return none
+ */
+void RTESys_AtomicWriteUInt4( SAPDB_UInt4 VAR_VALUE_REF memoryPosition, SAPDB_UInt4 const newValue );
+/*!
+   @brief Atomic write operation of a pointer
 
-#endif
-
-#if defined(__cplusplus)
-
-/*! Atomic write operation on 4byte aligned signed value */
-#    define RTESys_AtomicWriteInt4(memoryPosition_, newValue_) (memoryPosition_) = (newValue_)
-/*! Atomic write operation on 4byte aligned unsigned value */
-#    define RTESys_AtomicWriteUInt4(memoryPosition_, newValue_) (memoryPosition_) = (newValue_)
-
-#else
-
-/*! Atomic write operation on 4byte aligned signed value */
-#    define RTESys_AtomicWriteInt4(memoryPosition_, newValue_) *(memoryPosition_) = (newValue_)
-/*! Atomic write operation on 4byte aligned unsigned value */
-#    define RTESys_AtomicWriteUInt4(memoryPosition_, newValue_) *(memoryPosition_) = (newValue_)
-
-#endif
+   @param memoryPosition [inout] the memory position to read
+   @param newPointer [in] the new pounter for the given position
+   @return none
+ */
+void RTESys_AtomicWritePointer( void * VAR_VALUE_REF memoryPosition, void * const newPointer );
 
 /*=========================================================================================*/
 /*! Compare and Exchange
