@@ -35,6 +35,10 @@
 /*===========================================================================*
  *  INCLUDES                                                                 *
  *===========================================================================*/
+#if defined(LINUX)
+#   define _GNU_SOURCE 1
+#   include <sched.h>
+#endif
 
 #include "RunTime/System/RTESys_MicroTime.h"
 
@@ -66,13 +70,12 @@
 
 #ifdef LINUX
 #   include     <sys/time.h>
-/*
-  In a single thread application librt must not be referenced. But clock_gettime()
-  is defined in librt, so we excluded this explicitly for single threaded (!_REENTRANT)....
- */
-#  if !defined(_REENTRANT) && defined(CLOCK_MONOTONIC)
-#    define HAS_CLOCK_MONOTONIC
-#  endif
+typedef SAPDB_UInt8 u64;
+#   include <asm/param.h>
+#   include <asm/types.h>
+#   include <asm/timex.h>
+#   include <sys/time.h>
+#   define HAS_GET_CYCLES
 #endif
 
 /*===========================================================================*
@@ -97,6 +100,11 @@
  */
 static SAPDB_UInt8 databaseStartTimeInMicroseconds = 0;
 
+#if defined(HAS_GET_CYCLES)
+static SAPDB_Bool RTESys_forceUseOfGettimeofday = true;
+static double RTESys_microsecond_per_cycle = 0.;
+#endif
+
 /*===========================================================================*
  *  STATIC/INLINE FUNCTION PROTOTYPES                                        *
  *===========================================================================*/
@@ -115,6 +123,72 @@ static SAPDB_UInt8 CurrentMicroSeconds();
  *  GLOBAL FUNCTIONS                                                         *
  *===========================================================================*/
 
+#if defined(HAS_GET_CYCLES)
+/*
+   Inspect all CPU timers to be monotonous...
+ */
+SAPDB_Bool RTESys_LinuxTimerLeapCheck(SAPDB_Bool forceUseOfGettimeofday)
+{
+    if ( forceUseOfGettimeofday )
+    {
+        RTESys_forceUseOfGettimeofday = true;
+        return false;
+    }
+    else
+    {
+#if defined(HAS_NPTL)
+        int iRun;
+        int iCpu;
+        cycles_t firstCycles;
+        cycles_t lastTick;
+        cycles_t currentTick;
+        cpu_set_t cpuset;
+        cpu_set_t testset;
+
+		RTESys_forceUseOfGettimeofday = false;
+        if ( 0 == sched_getaffinity( 0, sizeof(cpu_set_t), &cpuset) )
+        {
+            firstCycles = lastTick = get_cycles();
+            for ( iRun = 0; iRun < 2; iRun++ ) /* two runs are needed to check last CPU against first CPU */
+            {
+                for ( iCpu = 0; iCpu < (sizeof(cpu_set_t)*8); ++iCpu )
+                {
+                    if ( CPU_ISSET(iCpu, &cpuset) )
+                    {
+                        CPU_ZERO(&testset);
+                        CPU_SET(iCpu, &testset);
+                        if ( 0 == sched_setaffinity( 0, sizeof(cpu_set_t), &testset) )
+                        {
+                            currentTick = get_cycles();
+                            /* using cycles difference prevents 'overflow' problem in tick registers... */
+                            /* without this the very unlikely case of on register overflow could produce */
+                            /* a 'false' being returned with a working synchronized timer set */
+                            if ( (currentTick - firstCycles) < (lastTick - firstCycles) )
+                            {
+                                RTESys_forceUseOfGettimeofday = true;
+                                break;
+                            }
+                            else
+                            {
+                                lastTick = get_cycles();
+                            }
+						} else {
+							RTESys_forceUseOfGettimeofday = true;
+							break;
+						}
+                    }
+                }
+            }
+            sched_setaffinity( 0, sizeof(cpu_set_t), &cpuset);
+		} else {
+			RTESys_forceUseOfGettimeofday = true;
+		}
+#endif
+        return !RTESys_forceUseOfGettimeofday;
+    }
+}
+#endif
+
 /*!--------------------------------------------------------------------
    @description    Initialize timer for microseconds since start of database
 
@@ -122,6 +196,25 @@ static SAPDB_UInt8 CurrentMicroSeconds();
 
 void RTESys_InitMicroSecTimer()
 {
+#if defined(HAS_GET_CYCLES)
+    if ( !RTESys_forceUseOfGettimeofday )
+    {
+        struct timeval start_time;
+        struct timeval end_time;
+        SAPDB_UInt8 start_ticks;
+        SAPDB_UInt8 end_ticks;
+
+        (void) gettimeofday ( &start_time , (void *)0 );
+        start_ticks = get_cycles();
+        sleep(5);
+        end_ticks   = get_cycles();
+        (void) gettimeofday ( &end_time , (void *)0 );
+
+        RTESys_microsecond_per_cycle = ( ( end_time.tv_sec  - start_time.tv_sec  ) * 1000000 )
+                                    + end_time.tv_usec - start_time.tv_usec;
+        RTESys_microsecond_per_cycle /= (end_ticks - start_ticks);
+    }
+#endif
     databaseStartTimeInMicroseconds = CurrentMicroSeconds();
 }
 
@@ -169,13 +262,12 @@ static SAPDB_UInt8 CurrentMicroSeconds()
 
     return resultTime;
 
-#elif defined(HAS_CLOCK_MONOTONIC)
+#elif defined(HAS_GET_CYCLES)
 
-    struct timespec monotonTime;
-    if ( 0 == clock_gettime(CLOCK_REALTIME, &monotonTime) )
+    if ( !RTESys_forceUseOfGettimeofday 
+      && (RTESys_microsecond_per_cycle != 0) )
     {
-        return ( RTESYS_SECONDS_TO_MICROSECONDS(monotonTime.tv_sec)
-               + RTESYS_NANOSECONDS_TO_MICROSECONDS(monotonTime.tv_nsec) );
+        return (SAPDB_UInt8)(get_cycles() * RTESys_microsecond_per_cycle);
     }
     else
     {
