@@ -1,3 +1,24 @@
+/*
+
+    ========== licence begin  GPL
+    Copyright (c) 2005 SAP AG
+
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
+
+*/
 #ifndef RTE_TASK_TCB_HPP
 #define RTE_TASK_TCB_HPP
 
@@ -95,6 +116,11 @@ public:
         return m_pTaskCtrlRec->RWRegion;
     }
 
+    RTE_TaskId &waitingForTask(void)
+    {
+        return (RTE_TaskId &)m_pTaskCtrlRec->lWaitForTask;
+    }
+
     RTE_TCB(PTASK_CTRL_REC pTaskCtrlRec = NULL)
         : m_pTaskCtrlRec(pTaskCtrlRec)
     {
@@ -233,6 +259,11 @@ public:
         return m_pTaskCtrlRec->RWRegion;
     }
 
+    RTE_TaskId &waitingForTask(void)
+    {
+        return (RTE_TaskId &)m_pTaskCtrlRec->lWaitForTask;
+    }
+
     operator TASK_TYPE *()
     {
         return m_pTaskCtrlRec;
