@@ -173,6 +173,10 @@ public:
       @brief exception handler
       */
       virtual void Exception(const char*) = 0;
+      /*!
+      @brief dumps a memory chunk into file
+      */
+      virtual void Dump     (void* p, int size){/*default nop*/;}
   };
 
   /*!
@@ -282,7 +286,7 @@ public:
     SAPDB_ULong                FirstBlockSize,
     SAPDB_ULong                SupplementBlockSize,
     FreeRawExtendsEnum         FreeRawExtends,
-    SAPDB_ULong                MaxSize = SAPDBMEM_ALLOCATOR_UNLIMITED
+    SAPDB_ULong                MaxSize  = SAPDBMEM_ALLOCATOR_UNLIMITED
     ); 
 
    /*!
@@ -487,6 +491,13 @@ public:
 
   static void SetAllocator(void* p, SAPDBMem_IRawAllocator* pAllocator);
 
+  /*!
+     @brief sets a threshold in bytes where a allocate writes a call stack into knldiag.
+     @param NewThreshold the new threshold in bytes
+  */
+
+  void SetAllocThreshold (SAPDB_ULong NewTreshold);
+
   /*!
      @brief enables the handler to be used when no more memory is available
      @param handler identifies the handler to be used 
@@ -558,6 +569,11 @@ public:
 
   void SetCheckLevel();
 
+  /*!
+     @brief enables all check levels of the allocator according to parameter checkLevel.
+  */
+  void SetCheckLevel(SAPDB_UInt4 checkLevel);
+
   /*!
      @brief yields an iterator over all memory chunks of the allocator.
   */
@@ -702,6 +718,7 @@ private:
          void             Destructor();                                              //!< destructs the allocator
          void             Dump();                                                    //!< dumps the allocator using m_tracer
          void             DumpChunk(void* p, int length);                            //!< dumps a chunk using m_tracer
+         void             DumpRawChunk(void* p);                                     //!< dumps a raw chunk using m_tracer
 #if defined(WIN32) || defined(OSF1)
          void             ExceptionDeallocate(void* p);                              //!< exception handler
          void             ExceptionAllocate();                                       //!< exception handler
@@ -742,6 +759,9 @@ private:
   void CheckFreeChunkDbg(CChunkPtr);
 #endif
 
+  SAPDB_ULong                 m_AllocThreshold;          //!< if ByteCount at Allocate call strikes this value a call stack is written to knldiag
+
+
   SAPDBMem_IBlockAllocator*   m_BlockAllocator;          //!< underlying block allocator, may be NULL
   SAPDBMem_IRawAllocator*     m_RawAllocator;            //!< underlying raw allocator, may be NULL
   ITracerAndExceptionHandler* m_tracer;                  //!< pointer to an instance providing tracer inderface
@@ -754,6 +774,7 @@ private:
   bool                        m_checkHeap;               //!< check heap if true 
   FreeRawExtendsEnum          m_freeRawExtends;          //!< return free base chunks to base allocator ?
   bool                        m_opMessages;              //!< if true, op messages are written to the knldiag in error conditions
+  bool                        m_writeAllocateFailedOpMsg;//!< if true, the allocate failed op message is written to the knldiag
   bool                        m_writeProtected;          //!< true if allocator is write protected
   bool                        m_doUnregister;            //!< true, if allocator has to be unregistered at destruction
   int                         m_monitorCallStackLevel;   //!< depth of back trace
