@@ -3,10 +3,10 @@
    responsible:    DanielD
    description:    Interface to DB Manager
    target:         Python
-   last changed:   18.05.2004
+   last changed:   06.09.2006
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2005 SAP AG
+    Copyright (c) 2000-2006 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -20,24 +20,31 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
     ========== licence end
-
 ===========================================*/
 
 
 #include <stddef.h>
 
-#if defined (HPUX) || defined (AIX) || defined (SUN) || defined (OSF1) || defined (LINUX) || defined (FREEBSD)
+#if defined (HPUX) || defined (AIX) || defined (SUN) || defined (SOLARIS) || defined (OSF1) || defined (LINUX) || defined (FREEBSD)
 #define BAD_STATIC_FORWARD
 #endif
 
 #include "Python.h"/* no check */
 
-#if defined (HPUX) || defined (AIX) || defined (SUN) || defined (OSF1)
+#if PY_MAJOR_VERSION >= 2 && PY_MINOR_VERSION >= 4
+#else
+#if defined (HPUX) || defined (AIX) || defined (SUN) || defined (SOLARIS) || defined (OSF1)
 #undef statichere
 #define statichere
 #endif
+#endif
+
+#if defined HP_IA64
+#undef statichere
+#define statichere static
+#endif
 
 #define MF__
 #if defined (__cplusplus)
@@ -570,6 +577,7 @@ cmd_DBM (PyObject *pyself, PyObject* args, PyObject* keywds)
     tsp00_ErrTextc msg;
     tsp00_Int4 result;
 
+    memset (&output, '\0', sizeof (ReadResultT));
     if (!PyArg_ParseTupleAndKeywords (args, keywds, LIT("s:DBM.cmd"), (char **) kwlist, &cmd)) {
         ok = 0;
         goto cleanup_label;
@@ -587,7 +595,6 @@ cmd_DBM (PyObject *pyself, PyObject* args, PyObject* keywds)
     }
   cleanup_label:
     if (!ok) {
-        /* Cleanup */
         return NULL;
     }
     return outputObj;
@@ -611,6 +618,7 @@ rawCmd_DBM (PyObject *pyself, PyObject* args, PyObject* keywds)
     tsp00_ErrTextc msg;
     tsp00_Int4 result;
 
+    memset (&output, '\0', sizeof (ReadResultT));
     if (!PyArg_ParseTupleAndKeywords (args, keywds, LIT("s:DBM.rawCmd"), (char **) kwlist, &cmd)) {
         ok = 0;
         goto cleanup_label;
@@ -628,7 +636,6 @@ rawCmd_DBM (PyObject *pyself, PyObject* args, PyObject* keywds)
     }
   cleanup_label:
     if (!ok) {
-        /* Cleanup */
         return NULL;
     }
     return outputObj;
@@ -754,7 +761,6 @@ DBM_dbm (PyObject *pyself, PyObject* args, PyObject* keywds)
     /* outargs */
   cleanup_label:
     if (!ok) {
-        /* Cleanup */
         if (newObj != NULL) {
             Py_DECREF (newObj);
         };
@@ -786,7 +792,6 @@ saveUser_dbm (PyObject *pyself, PyObject* args, PyObject* keywds)
     /* outargs */
   cleanup_label:
     if (!ok) {
-        /* Cleanup */
         return NULL;
     }
     Py_INCREF(Py_None);
@@ -817,7 +822,6 @@ checkUser_dbm (PyObject *pyself, PyObject* args, PyObject* keywds)
     /* outargs */
   cleanup_label:
     if (!ok) {
-        /* Cleanup */
         return NULL;
     }
     return Py_BuildValue (LIT("i"), result);
@@ -863,7 +867,6 @@ deleteUser_dbm (PyObject *pyself, PyObject* args, PyObject* keywds)
     /* outargs */
   cleanup_label:
     if (!ok) {
-        /* Cleanup */
         return NULL;
     }
     Py_INCREF(Py_None);
