@@ -3,10 +3,10 @@
    responsible:    DanielD
    description:    Interface to the SAP DB Loader
    target:         Python
-   last changed:   27.07.2004
+   last changed:   06.09.2006
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2005 SAP AG
+    Copyright (c) 2000-2006 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -20,15 +20,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
     ========== licence end
-
 ===========================================*/
 
 
 #include <stddef.h>
 
-#if defined (HPUX) || defined (AIX) || defined (SUN) || defined (OSF1) || defined (LINUX) || defined (FREEBSD)
+#if defined (HPUX) || defined (AIX) || defined (SUN) || defined (SOLARIS) || defined (OSF1) || defined (LINUX) || defined (FREEBSD)
 #define BAD_STATIC_FORWARD
 #endif
 
@@ -36,12 +35,17 @@
 
 #if PY_MAJOR_VERSION >= 2 && PY_MINOR_VERSION >= 4
 #else
-#if defined (HPUX) || defined (AIX) || defined (SUN) || defined (OSF1)
+#if defined (HPUX) || defined (AIX) || defined (SUN) || defined (SOLARIS) || defined (OSF1)
 #undef statichere
 #define statichere
 #endif
 #endif
 
+#if defined HP_IA64
+#undef statichere
+#define statichere static
+#endif
+
 #define MF__
 #if defined (__cplusplus)
 #define externC extern "C"
@@ -102,13 +106,13 @@ createExceptionKind (
 }
 
 static PyObject *CommunicationErrorType;
-static const char * CommunicationErrorCodeC =
+static const char * CommunicationErrorCodeC = 
     "\n"
     "def __str__ (self):\n"
     "    return \"loader.CommunicationError: [%d] %s\" % (self.errorCode, self.message)\n"
     "\n";
 static PyObject *LoaderErrorType;
-static const char * LoaderErrorCodeC =
+static const char * LoaderErrorCodeC = 
     "\n"
     "def __str__ (self):\n"
     "    if self.sqlCode:\n"
@@ -537,6 +541,7 @@ cmd_Loader (PyObject *pyself, PyObject* args, PyObject* keywds)
     tsp00_ErrTextc msg;
     tsp00_Int4 result;
 
+    memset (&output, '\0', sizeof (ReadResultT));
     if (!PyArg_ParseTupleAndKeywords (args, keywds, LIT("s:Loader.cmd"), (char **) kwlist, &cmd)) {
         ok = 0;
         goto cleanup_label;
@@ -554,7 +559,6 @@ cmd_Loader (PyObject *pyself, PyObject* args, PyObject* keywds)
     }
   cleanup_label:
     if (!ok) {
-        /* Cleanup */
         return NULL;
     }
     return outputObj;
@@ -578,6 +582,7 @@ rawCmd_Loader (PyObject *pyself, PyObject* args, PyObject* keywds)
     tsp00_ErrTextc msg;
     tsp00_Int4 result;
 
+    memset (&output, '\0', sizeof (ReadResultT));
     if (!PyArg_ParseTupleAndKeywords (args, keywds, LIT("s:Loader.rawCmd"), (char **) kwlist, &cmd)) {
         ok = 0;
         goto cleanup_label;
@@ -595,7 +600,6 @@ rawCmd_Loader (PyObject *pyself, PyObject* args, PyObject* keywds)
     }
   cleanup_label:
     if (!ok) {
-        /* Cleanup */
         return NULL;
     }
     return outputObj;
@@ -630,7 +634,6 @@ sql_Loader (PyObject *pyself, PyObject* args, PyObject* keywds)
     /* outargs */
   cleanup_label:
     if (!ok) {
-        /* Cleanup */
         return NULL;
     }
     return Py_BuildValue (LIT("i"), result);
@@ -677,15 +680,15 @@ release_Loader (PyObject *pyself, PyObject* args, PyObject* keywds)
 }
 
 static PyMethodDef LoaderClassMethods [] = {
-    {LIT("cmd"), (PyCFunction)cmd_Loader, METH_VARARGS|METH_KEYWORDS,
+    {LIT("cmd"), (PyCFunction)cmd_Loader, METH_VARARGS|METH_KEYWORDS, 
         "exeute a command and return resulting buffer as string"},
-    {LIT("rawCmd"), (PyCFunction)rawCmd_Loader, METH_VARARGS|METH_KEYWORDS,
+    {LIT("rawCmd"), (PyCFunction)rawCmd_Loader, METH_VARARGS|METH_KEYWORDS, 
         "exeute a command and return resulting buffer as string\n\n            This doesn't scan the buffer for error information."},
-    {LIT("sql"), (PyCFunction)sql_Loader, METH_VARARGS|METH_KEYWORDS,
+    {LIT("sql"), (PyCFunction)sql_Loader, METH_VARARGS|METH_KEYWORDS, 
         "exeute a sql command and return the error code\n\n                This method doesn't raise an exception unless an error\n                unreleated to the SQL command occurs.\n                "},
-    {LIT("cancelCmd"), (PyCFunction)cancelCmd_Loader, METH_VARARGS|METH_KEYWORDS,
+    {LIT("cancelCmd"), (PyCFunction)cancelCmd_Loader, METH_VARARGS|METH_KEYWORDS, 
         "cancels a pending request"},
-    {LIT("release"), (PyCFunction)release_Loader, METH_VARARGS|METH_KEYWORDS,
+    {LIT("release"), (PyCFunction)release_Loader, METH_VARARGS|METH_KEYWORDS, 
         "closes the connection"},
     {NULL, NULL}
 };
@@ -760,7 +763,6 @@ Loader_loader (PyObject *pyself, PyObject* args, PyObject* keywds)
     /* outargs */
   cleanup_label:
     if (!ok) {
-        /* Cleanup */
         if (newObj != NULL) {
             Py_DECREF (newObj);
         };
@@ -788,9 +790,9 @@ _buildInfo_loader (PyObject *pyself, PyObject* args, PyObject* keywds)
 }
 
 static PyMethodDef loaderModuleMethods [] = {
-    {LIT("Loader"), (PyCFunction)Loader_loader, METH_VARARGS|METH_KEYWORDS,
+    {LIT("Loader"), (PyCFunction)Loader_loader, METH_VARARGS|METH_KEYWORDS, 
         "open a connection\n\n                An empty servernode will search for a loader server on\n                the local machine."},
-    {LIT("_buildInfo"), (PyCFunction)_buildInfo_loader, METH_VARARGS|METH_KEYWORDS,
+    {LIT("_buildInfo"), (PyCFunction)_buildInfo_loader, METH_VARARGS|METH_KEYWORDS, 
         "returns a string containing the release and build number"},
     {NULL, NULL}
 };
