@@ -8,7 +8,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 */
 
 
@@ -72,7 +73,6 @@
  *===========================================================================*/
 
 
-
 /*===========================================================================*
  *  METHODS                                                                  *
  *===========================================================================*/
@@ -132,24 +132,25 @@ void SysView_DataStatistics::Execute()
 
     // USABLE_SIZE
 
-    SAPDB_UInt usableSize = IOMan_IDataInfo::GetInstance().TotalUsableDataPages() * pageSize;
+    const SAPDB_Real8 usableSize = IOMan_IDataInfo::GetInstance().TotalUsableDataPages() * pageSize;
 
-    m_Table->MoveToCol( ITOVT_UINT4, &usableSize, 0 );
+    m_Table->MoveToCol( ITOVT_DOUBLE, &usableSize, 0 );
 
     // USED_SIZE:
     // determine the number of changed permanent data and converter pages. No temp pages!
 
-    SAPDB_UInt changedPages = (bd20GetNumberOfChangedPages() +
+    const SAPDB_Real8 changedPages = (bd20GetNumberOfChangedPages() +
                                iConvCom.GetNumberOfChangedConvPages()) * pageSize;
-    SAPDB_UInt usedPages    = iConvCom.GetNumberOfUsedPages() * pageSize;
-    SAPDB_UInt usedBlocks   = FBM_IManager::Instance().GetNumberOfUsedBlocks() * pageSize;
-    SAPDB_UInt usedSize     = SAPDB_MAX( usedPages, usedBlocks );
+    const SAPDB_Real8 usedPages    = iConvCom.GetNumberOfUsedPages() * pageSize;
+    const SAPDB_Real8 usedBlocks   = FBM_IManager::Instance().GetNumberOfUsedBlocks() * pageSize;
+    const SAPDB_Real8 usedSize     = SAPDB_MAX( usedPages, usedBlocks );
 
-    m_Table->MoveToCol( ITOVT_UINT4, &usedSize, 0 );
+    m_Table->MoveToCol( ITOVT_DOUBLE, &usedSize, 0 );
 
     // USED_SIZE_PERCENTAGE
 
-    SAPDB_UInt usedSizePercent = ( 0 >= usableSize ) ? 0 : ((usedSize * 100) / usableSize );
+	const SAPDB_UInt4 usedSizePercent = ( 0 >= usableSize ) ? 
+            0 : static_cast<SAPDB_UInt4>((usedSize * 100) / usableSize );
 
     m_Table->MoveToCol( ITOVT_UINT4, &usedSizePercent, 0 );
 
@@ -161,46 +162,46 @@ void SysView_DataStatistics::Execute()
 
     // USED_SIZE_ON_VOLUMES
 
-    m_Table->MoveToCol( ITOVT_UINT4, &usedBlocks, 0 );
+    m_Table->MoveToCol( ITOVT_DOUBLE, &usedBlocks, 0 );
 
     // USED_SIZE_NOT_ON_VOLUMES
 
-    m_Table->MoveToCol( ITOVT_UINT4, &changedPages, 0 );
+    m_Table->MoveToCol( ITOVT_DOUBLE, &changedPages, 0 );
 
     // USED_PERMANENT_SIZE
 
-    SAPDB_UInt permPages = iConvCom.GetNumberOfPermPages() * pageSize;
+    const SAPDB_Real8 permPages = iConvCom.GetNumberOfPermPages() * pageSize;
 
-    m_Table->MoveToCol( ITOVT_UINT4, &permPages, 0 );
+    m_Table->MoveToCol( ITOVT_DOUBLE, &permPages, 0 );
 
     // USED_TEMPORARY_SIZE
 
-    SAPDB_UInt tempPages = iConvCom.GetNumberOfTempPages() * pageSize;
+    const SAPDB_Real8 tempPages = iConvCom.GetNumberOfTempPages() * pageSize;
 
-    m_Table->MoveToCol( ITOVT_UINT4, &tempPages, 0 );
+    m_Table->MoveToCol( ITOVT_DOUBLE, &tempPages, 0 );
 
     // MAX_USED_SIZE
 
-    SAPDB_UInt permPeak     = iConvCom.GetPeakForPermPages() * pageSize;
-    SAPDB_UInt tempPeak     = iConvCom.GetPeakForTempPages() * pageSize;
-    SAPDB_UInt maxPagesUsed = SAPDB_MAX( permPeak, tempPeak );
+    const SAPDB_Real8 permPeak     = iConvCom.GetPeakForPermPages() * pageSize;
+    const SAPDB_Real8 tempPeak     = iConvCom.GetPeakForTempPages() * pageSize;
+    const SAPDB_Real8 maxPagesUsed = SAPDB_MAX( permPeak, tempPeak );
 
-    m_Table->MoveToCol( ITOVT_UINT4, &maxPagesUsed, 0 );
+    m_Table->MoveToCol( ITOVT_DOUBLE, &maxPagesUsed, 0 );
 
     // MAX_USED_PERMANENT_SIZE
 
-    m_Table->MoveToCol( ITOVT_UINT4, &permPeak, 0 );
+    m_Table->MoveToCol( ITOVT_DOUBLE, &permPeak, 0 );
 
 
     // MAX_USED_TEMPORARY_SIZE
 
-    m_Table->MoveToCol( ITOVT_UINT4, &tempPeak, 0 );
+    m_Table->MoveToCol( ITOVT_DOUBLE, &tempPeak, 0 );
 
     // INCREMENTAL_BACKUP_SIZE
 
-    SAPDB_UInt updatedPages = iConvCom.UpdatedPagesSinceLastSaveData( taskId ) * pageSize;
+    const SAPDB_Real8 updatedPages = iConvCom.UpdatedPagesSinceLastSaveData( taskId ) * pageSize;
 
-    m_Table->MoveToCol( ITOVT_UINT4, &updatedPages, 0 );
+    m_Table->MoveToCol( ITOVT_DOUBLE, &updatedPages, 0 );
 
     // LAST_EMERGENCY_HISTORY_CLEANUP
 
