@@ -59,6 +59,7 @@
 void SysView_MachineConfiguration::Create()
 {
 	m_Table->AppendCol (ITOCT_FIXED,  SV_CPUNUMBER, 5);
+	m_Table->AppendCol (ITOCT_FIXED,  SV_PHYSICALCPUNUMBER, 5);
 	m_Table->AppendCol (ITOCT_FIXED,  SV_PHYSICALMEMORYSIZE, 10);
 	m_Table->AppendCol (ITOCT_FIXED,  SV_VIRTUALMEMORYSIZE, 10);
 }
@@ -84,7 +85,13 @@ void SysView_MachineConfiguration::Execute()
     m_Table->GetCatalogTable();
     if (m_Context.IsOk())
     {
-        AddColumn( RTESys_NumberOfCPU() );
+		SAPDB_Int4 NumberOfCPUs = RTESys_NumberOfCPU();
+		SAPDB_Int4 NumberOfPhysicalCPUs = RTESys_NumberOfPhysicalCPUs();
+		AddColumn( NumberOfCPUs );
+		if( NumberOfCPUs == NumberOfPhysicalCPUs )
+        	AddColumn();
+		else
+			AddColumn( NumberOfPhysicalCPUs );
 
         // the RTESys_MemoryInfo methods are called without calling update() before,
         // because update() would take a significant amount of time.
