@@ -451,8 +451,10 @@ public:
                 if ( !(Iter = new(mSessionAllocator) Data_TempFile::RecordIterator(mTempFileContainer[i].mFile->PageAccessManager())) )
                 {
                     mTransContext.trError_gg00 = 0;
+	                ErrorList = ErrorList + Table_Exception(__CONTEXT__, TABLE_TEMPHASH_FIRSTFAILED);
                     return 0;
                 }
+				mTempFileContainer[i].mIter = Iter;
             }
             if(!mTempFileContainer[i].mFile->GetFirst(*Iter))
             {
@@ -837,7 +839,8 @@ private:
         TempFileContainerEntry CE;
         if ( CE.mFile = new(mSessionAllocator) Data_TempFile(mTransContext, mRecordLength) )
         {
-            CE.mFile->Create();
+            if ( !CE.mFile->Create() )
+				return false;
             CE.mIter = 0;
             CE.mData = 0;
             if ( mTempFileContainer.InsertEnd(CE) )
