@@ -4,8 +4,9 @@
     \ingroup backup tool simulators for tests
     \brief   implementation of a parser for parameters
 
+\if EMIT_LICENCE
     ========== licence begin  GPL
-    Copyright (c) 1998-2005 SAP AG
+    Copyright (c) 1998-2006 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -21,7 +22,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
-
+\endif
 */
 
 #include "ToolsCommon/Parsers/ToolsParsers_ProgramParameterParser.hpp"
@@ -30,14 +31,19 @@
 ToolsParsers_ProgramParameterParser::ToolsParsers_ProgramParameterParser(
     int                  argc,
     const char * const * argv,
-    const char *         syntax)
+    const char *         syntax,
+    bool                 ignoreFirstArgument)
   : m_Syntax(syntax),
-    m_ArgCount((0<argc && 0!=argv)?argc:1),
+    m_ArgCount((0<argc && 0!=argv)?argc:(ignoreFirstArgument?1:0)),
     m_ArgVector((0<argc && 0!=argv)?argv:m_DummyVector),
+    m_IgnoreCount(ignoreFirstArgument?1:0),
     m_notParsed(true)
 {
     m_DummyVector[0]=""; //simulate the program name
     m_DummyVector[1]=0;  //last array element in argv is always a 0 pointer
+
+    if(!ignoreFirstArgument && m_ArgVector==m_DummyVector) //do not simulate program name, if program name is nt present
+        m_DummyVector[0]=0;
 }
 
 const ToolsParsers_ParseResult & ToolsParsers_ProgramParameterParser::parse()
@@ -51,10 +57,10 @@ const ToolsParsers_ParseResult & ToolsParsers_ProgramParameterParser::parse()
             int  argsParsed=0;
             bool syntaxErrorFound=false;
 
-            m_Syntax.getSyntax()->parse(m_ArgVector+1, m_ArgCount-1, argsParsed, syntaxErrorFound); // +1 -> do not parse the program name
+            m_Syntax.getSyntax()->parse(m_ArgVector+m_IgnoreCount, m_ArgCount-m_IgnoreCount, argsParsed, syntaxErrorFound); // +m_IgnoreCount -> do not parse the program name
 
             if(syntaxErrorFound ||          //no syntax error must be found during parsing
-               argsParsed+1 < m_ArgCount)   //all arguments except the program name (m_ArgVector[0]) must be parsed
+               argsParsed+m_IgnoreCount < m_ArgCount)   //all arguments except the program name (m_ArgVector[0]) must be parsed
             {
                 m_Syntax.getResult().setErrorSyntax();
             }
