@@ -14,14 +14,14 @@
   version:      7.4.4 and higher 
   -----------------------------------------------------------------------------
  
-                          Copyright (c) 2002-2004 SAP AG
+                          Copyright (c) 2002-2005 SAP AG
  
   -----------------------------------------------------------------------------
 
 
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -40,6 +40,7 @@
 
 
 
+
 */
 
 #if !defined(Tools_List_HPP)
@@ -242,6 +243,7 @@ template<class T> class Tools_ListIterator
     Tools_ListIterator<T> & operator=(const Tools_ListReverseIterator<T> &);
 
     friend class Tools_List<T>;
+    friend class Tools_ListConstIterator<T>;
     friend class Tools_ListReverseIterator<T>;
 
   private:
@@ -253,6 +255,7 @@ template<class T> class Tools_ListConstIterator
   public:
     Tools_ListConstIterator();
     Tools_ListConstIterator(const Tools_ListNode<T> *o);
+    Tools_ListConstIterator(const Tools_ListIterator<T> &li);
 
     Tools_ListConstIterator<T> & operator ++ ();
     Tools_ListConstIterator<T>   operator ++ (int);
@@ -657,6 +660,11 @@ template<class T> inline Tools_ListConstIterator<T>::Tools_ListConstIterator(con
 {
 }
 
+template<class T> inline Tools_ListConstIterator<T>::Tools_ListConstIterator(const Tools_ListIterator<T>& li)
+:NodePointer(li.NodePointer)
+{
+}
+
 template<class T> inline Tools_ListConstIterator<T> & Tools_ListConstIterator<T>::operator ++ ()
 {
     NodePointer=NodePointer->next;
