@@ -536,11 +536,14 @@ WDV_Bool Copy_CopyResource( WDVCAPI_WDV                  wdv,
 
     /* If source is not a collection copy container */
     if (strcmp(propertyShortValue, PROPERTY_VALUE_COLLECTION) != 0) {
-        /* Copy container */
-        if (!Resource_CopyContainer(wdv, resource, newDestinationResource)) {
-            Resource_DestroyHandle(wdv, newDestinationResource);
+        /* If source is not a collection copy container */
+        if (strcmp(propertyShortValue, PROPERTY_VALUE_NULL_RESOURCE) != 0) {
+            /* Copy container */
+            if (!Resource_CopyContainer(wdv, resource, newDestinationResource)) {
+                Resource_DestroyHandle(wdv, newDestinationResource);
 
-            return WDV_False;
+                return WDV_False;
+            }
         }
     }
 
