@@ -464,7 +464,7 @@
 					strncpy(temp4,temp3+strlen("saplocktoken:"),length-strlen("saplocktoken:"));
 					temp4[length-strlen("saplocktoken:")] = '\0';
 					strncpy(sIf,temp4,len);
-					sIf[length-1]='\0';
+					sIf[len-1]='\0';
 				}
 				return WDVH_True;
 			} else {
@@ -1819,7 +1819,7 @@
 		return WDVH_True;
 	}
 
-	void WDVH_sendBodyChunk(sapdbwa_HttpReplyP reply, WDVH_Char *data)
+	void WDVH_sendBodyChunk(sapdbwa_HttpReplyP reply, const WDVH_Char *data)
 	{
 		WDVH_Char	chunk[101];
 
@@ -1941,7 +1941,11 @@
 		const SAPDB_Char	*requestUser;
 		const SAPDB_Char	*requestPassword;
 		WDVH_Bool			authenticationOK;
+		WDVH_Char			message[WDVH_MAX_URI_LEN+50];
 
+/*		sp77sprintf(message,WDVH_MAX_URI_LEN+1,"Check Authentication required (isRequired='%s')\n",isRequired);
+		sapdbwa_WriteLogMsg(wa,message);
+*/
 		if (strcmp(isRequired,"1")==0) {
 			/* authentication required -> check user and password */
 			/* check the user and password delivered with the request */
