@@ -16,23 +16,24 @@
   -------------------------------------------------------------------------
 
 
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 
 *****************************************************************************/
 
@@ -511,7 +512,7 @@
 	{
 
 	    WDVH_Int2					done;
-		WDVH_Int2					pos;
+		WDVH_Int2					pos = 0;
 		WDVH_XmlLockParserState		parserState;
 		WDVH_XmlUserData			newUserData;
 		WDVH_Error					error = ERROR_200;
@@ -911,7 +912,7 @@
 			if (parserState->depth == 1 &&
 				parserState->state == WDVH_LOCK_DFA_STATE_5) {
 				if (strcmp(tag,WDVH_XML_LOCKINFO_CLOSE)==0 &&
-					parserState->lockscope && parserState->locktype && parserState->owner) {
+					parserState->lockscope && parserState->locktype) { /* && parserState->owner) {*/
 					parserState->depth--;
 					/* Correction Begin http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1122129 */
 					/*parserState->state = WDVH_LOCK_DFA_STATE_13;*/
