@@ -268,7 +268,7 @@ HRESULT LVC_DispatcherParams::GetInterface (
   if (parms->use_libname)		
   {
     tsp00_C32   MD5Mark;
-    hr = LVC_LoadComponentLibrary(parms->library_name, (HANDLE*)&hInstance, MD5Mark);
+    hr = LVC_LoadComponentLibrary(parms->library_name, parms->package_id, (HANDLE*)&hInstance, MD5Mark);
     if ( S_OK == hr.hresult() )
     {
       if (dbo_package == parms->db_obj_type) 
