@@ -47,11 +47,14 @@
 #include "liveCache/MemoryManagement/LVCMem_Allocator.hpp"
 #include "liveCache/MemoryManagement/LVCMem_Wrapper.hpp"
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_NewDestroy.hpp"
+#include "SAPDBCommon/MemoryManagement/SAPDBMem_Exceptions.hpp"
 #include "KernelCommon/Kernel_OpMsg.hpp"
 #include "Oms/OMS_StackTraceCallbackInterface.hpp"
 #include "Oms/OMS_DbpError.hpp"
 #include "RunTime/System/RTESys_MicroTime.h"
-#include "RunTime/MemoryManagement/RTEMem_RteAllocator.hpp"
+#include "RunTime/RTE_IInterface.hpp"
+#include "RunTime/Configuration/RTEConf_ParameterAccessKernelInterface.hpp"
+#include "RunTime/RTE_Crash.hpp"
 
 #include "vak001.h"
 #include "hgg01.h"
@@ -60,6 +63,7 @@
 #include "heo56.h"  // vsignal
 #include "heo58.h"  // vGetAcvPtrFromCurrentTask
 #include "geo573.h" // bad alloc
+#include "heo66.h"  // vfopen etc
 #include "hgg11.h"
 #include "heo670.h"
 #include "hsp77.h"
@@ -92,7 +96,7 @@ LVC_KernelInterface& LVC_KernelInterfaceInstance::Instance()
 
 LVC_KernelInterfaceInstance::LVC_KernelInterfaceInstance()
   : m_spinlock_pool((const SAPDB_UTF8 *) "OMS R/W locks", LVC_LockRequest::MAX_RW_SPINLOCKS),
-    m_rw_locks(RTEMem_RteAllocator::Instance(), m_spinlock_pool)
+    m_rw_locks(RTE_IInterface::Instance().Allocator(), m_spinlock_pool)
 {
 }
 
@@ -245,6 +249,25 @@ bool LVC_KernelInterfaceInstance::IsUnicodeInstance()
 
 /*-----------------------------------------------------*/
 
+bool LVC_KernelInterfaceInstance::IsOneDBSystem()
+{   
+    RTEConf_Parameter::String value;
+    SAPDBErr_MessageList       errorList;
+    if (RTEConf_ParameterAccess::Instance()->GetString((unsigned char*) "MCOD", value, errorList)){
+      if( STRCMP_UTF8((const SAPDB_UTF8 *)"YES",value) == 0) {  
+            return true;
+        }
+        else {
+            return false;
+        }
+    }
+    // there's any problem reading parameter
+    RTE_Crash( errorList );    
+    return false;
+}
+
+/*-----------------------------------------------------*/
+
 void* LVC_KernelInterfaceInstance::OmsAllocate(SAPDB_ULong count)
 {
     return TheLiveCacheAllocator.OmsAllocate (count);
@@ -308,6 +331,7 @@ void LVC_KernelInterfaceInstance::ConsoleMessage(const char *msg)
   	Kernel_OpInfo(csp3_n_obj) << msg;
 }
 
+
 /*-----------------------------------------------------*/
 
 void LVC_KernelInterfaceInstance::DumpStackTrace()
@@ -537,7 +561,91 @@ bool LVC_KernelInterfaceInstance::UseReaderWriterLocks(){
 
 /*-----------------------------------------------------*/
 
+void LVC_KernelInterfaceInstance::Crash(const char* msg)
+{
+    SAPDBMem_ConsistencyException message(__CONTEXT__, msg); 
+    RTE_Crash(message); 
+}
+
+/*-----------------------------------------------------*/
+
+void LVC_KernelInterfaceInstance::DumpChunk (void* p, int size)
+{
+    tsp00_VFilename fn;
+    memset (&fn[0], ' ', sizeof(fn));
+    memcpy (&fn[0], "Heap                    .dmp", 28);
+    tsp00_Timestamp ts;
+    vtimestamp (ts);
+    memcpy (&fn[4], &ts[0], sizeof(ts));
+    tsp00_Int4    fileNo;
+    tsp00_VfReturn e;
+    tsp00_ErrText   errText;
+    vfopen (fn, &fileNo, e, errText);
+    fn[28] = 0;
+    Kernel_OpError (csp3_no_more_memory, csp3_n_memory) << "dumping chunk "
+        << ToStr(p) << ", size is " << size  << " into " << (char*) &fn[0];
+    if (vf_ok == e)
+    {
+        unsigned char* iter = REINTERPRET_CAST(unsigned char*, p);
+        tsp00_Buf Buf;
+        while ((size > 0) && (vf_ok == e))
+        {
+            int cpySize = (size > sizeof(Buf)) ? sizeof(Buf) : size;
+            memset (&Buf[0], 0, sizeof(Buf));
+            memcpy (&Buf[0], iter, cpySize);
+            vfwrite (fileNo, Buf, e, errText);
+            size -= sizeof(Buf);
+            iter += sizeof(Buf);
+        }
+        if (vf_ok != e)
+        {
+            Kernel_OpError (csp3_no_more_memory, csp3_n_memory) << "couldn't write to dump file";
+        }
+        vfclose(fileNo, e, errText);
+    }
+    else
+    {
+        Kernel_OpError (csp3_no_more_memory, csp3_n_memory) << "could not open dump file " << (char*) &fn[0];
+    }
+}
+
+/*-----------------------------------------------------*/
+
+tsp00_Int4 LVC_KernelInterfaceInstance::GetHeapCheckLevel()
+{
+	  if (RTEConf_ParameterAccess::InstanceExists())
+    {
+        RTEConf_Parameter::Integer value;
+        SAPDBErr_MessageList       errorList;
+        if (RTEConf_ParameterAccess::Instance()->GetInteger((unsigned char*) "HEAP_CHECK_LEVEL", value, errorList))
+        {
+            return (tsp00_Int4) value;
+        }
+        else
+        {
+            // there's any problem reading parameter, run without any checks
+            return 0;
+        }
+    }
+    return 0;
+}
+
+/*-----------------------------------------------------*/
+
+void LVC_KernelInterfaceInstance::Trace(const char* msg)
+{
+	Kernel_OpError (csp3_no_more_memory, csp3_n_memory) << msg;
+}
+
+/*-----------------------------------------------------*/
+
 void LVC_KernelInterfaceInstance::SetErrorCallback(DbpErrorCallbackInterface *cb){
   // Set the static ErrorCallbackInterface pointer in the kernel. PTS 1133630
   DbpError::dbpSetCallback(cb);
 }
+
+/*-----------------------------------------------------*/
+
+RTE_IInterface &LVC_KernelInterfaceInstance::GetKernelRunTimeInterface() {
+    return RTE_IInterface::Instance();
+}
