@@ -90,6 +90,15 @@ public :
 
   virtual void DeregisterAllocator(RTEMem_AllocatorInfo& allocatorInfo);
 
+  /*!
+   * \brief check if OneDB system
+   *
+   * Tells whether liveCache is a OneDB system.
+   *
+   * \return true, if liveCache is a OneDB system, false otherwise
+   */
+  virtual bool IsOneDBSystem();
+
   /*!-------------------------------------------------------------------------
   function:     GetOmsAllocator
   description:  returns a pointer to the global liveCache oms allocator 
@@ -357,6 +366,43 @@ public :
   --------------------------------------------------------------------------*/
   virtual bool UseReaderWriterLocks();
 
+  /*!-------------------------------------------------------------------------
+	function:     Crash
+	description:  writes msg into knldiag and crashes the kernel.  
+  		  
+	arguments:    msg [in] msg to write into knldiag
+	return value: none
+  --------------------------------------------------------------------------*/
+  virtual void Crash(const char* msg);
+
+  /*!-------------------------------------------------------------------------
+	function:     DumpChunk
+	description:  dumps a memory chunk.  
+  		  
+	arguments:    p [in] address of the chunk
+                size [in] size of the chunk
+	return value: none
+  --------------------------------------------------------------------------*/
+  virtual void DumpChunk (void* p, int size);
+
+  /*!-------------------------------------------------------------------------
+	function:     GetHeapCheckLevel
+	description:  returns the value of the parameter HEAP_CHECK_LEVEL.  
+  		  
+	arguments:    none
+	return value: the value of the parameter HEAP_CHECK_LEVEL
+  --------------------------------------------------------------------------*/
+  virtual tsp00_Int4 GetHeapCheckLevel();
+
+  /*!-------------------------------------------------------------------------
+	function:     Trace
+	description:  writes msg into knldiag.  
+  		  
+	arguments:    msg [in] msg to write into knldiag
+	return value: none
+  --------------------------------------------------------------------------*/
+  virtual void Trace(const char* msg);
+
   /*!
    * \brief Set error callback interface
    *
@@ -366,6 +412,15 @@ public :
    */
   virtual void SetErrorCallback(DbpErrorCallbackInterface *cb);
 
+  /*!
+   * \brief Get kernel runtime interface
+   *
+   * Returns a pointer to the liveCache kernel runtime interface
+   *
+   * \return pointer to the liveCache kernel runtime interface
+   */
+  virtual RTE_IInterface &GetKernelRunTimeInterface();
+
 private :
   /// Lock manager for R/W locks
   LVC_RWLockManager     m_rw_locks;
