@@ -435,7 +435,7 @@ inline void* LVCMem_Allocator::AllocateImplementation(SAPDB_ULong count,  bool i
 
   void* p;
   void* pContext  = (m_askForClient) ? LVCMem_Wrapper::GetContext() : NULL;
-  int AllocatorId = LVCMem_Wrapper::GetUktId(pContext) % m_SubAllocatorCount;
+  int AllocatorId = (unsigned int)LVCMem_Wrapper::GetUktId(pContext) % m_SubAllocatorCount;
   
 #if defined (OMSTST)
   p = (void*) 0;
