@@ -17,6 +17,7 @@
 
   -------------------------------------------------------------------------
 
+  copyright:    Copyright (c) 2000-2005 SAP AG
 
 
 
@@ -57,6 +58,7 @@
 #include "RunTime/MemoryManagement/RTEMem_BlockAllocator.hpp"
 #include "RunTime/MemoryManagement/RTEMem_AllocatorRegister.hpp"
 
+
 LVCMem_BlockAllocator* LVCMem_BlockAllocator::m_Instance = 0;
 
 /*===========================================================================*
@@ -68,6 +70,8 @@ LVCMem_BlockAllocator::LVCMem_BlockAllocator()
 , m_defaultBlockCount(0)
 , m_limit(0xFFFFFFFF)
 , m_allocated(0)
+, m_maxAllocated(0)
+, m_controlled(0)
 , m_CountAlloc(0)
 , m_CountDealloc(0)
 , m_CountBaseAlloc(0)
@@ -91,35 +95,62 @@ void* LVCMem_BlockAllocator::Allocate(SAPDB_ULong BlockCount)
 #else
   RTESync_LockedScope lockedScope(m_spinlock);
   ++m_CountAlloc;
-  if ((BlockCount == m_defaultBlockCount) && (0 != m_firstFree))
+  do
   {
-    void* p = m_firstFree;
-    m_firstFree = m_firstFree->m_next;
-    return p;
-  }
-  if (m_allocated + BlockCount <= m_limit)
-  {
-    void* p = m_allocator.Allocate(BlockCount);
-    if (0 != p)
-    {
-	  ++m_CountBaseAlloc;
-      m_writeHeapLimitOpMsg = true;
-      m_allocated += BlockCount;
-    }
-    return p;
-  }
-  else
-  {
-    if (m_writeHeapLimitOpMsg)
-    {
-      Kernel_OpError errorMsg(csp3_no_more_memory, csp3_n_memory);
-      errorMsg << "OMS_HEAP_LIMIT reached" << FlushLine;
-      errorMsg << "Allocated : " << (m_allocated * GetBlockSize()) << FlushLine;
-      errorMsg << "Required  : " << (BlockCount  * GetBlockSize()) << FlushLine;
-      m_writeHeapLimitOpMsg = false;
-    }
-    return 0;
+      if ((BlockCount == m_defaultBlockCount) && (0 != m_firstFree))
+      {
+          void* p = m_firstFree;
+          m_firstFree = m_firstFree->m_next;
+          m_allocated += BlockCount;
+          if (m_allocated > m_maxAllocated)
+          {
+              m_maxAllocated = m_allocated;
+          }
+          return p;
+      }
+      if (m_controlled + BlockCount <= m_limit)
+      {
+          void* p = m_allocator.Allocate(BlockCount);
+          if (0 != p)
+          {
+              ++m_CountBaseAlloc;
+              m_writeHeapLimitOpMsg = true;
+              m_allocated += BlockCount;
+              if (m_allocated > m_maxAllocated)
+              {
+                  m_maxAllocated = m_allocated;
+              }
+              m_controlled += BlockCount;
+          }
+          else
+          {
+              if (0 != m_firstFree)
+              {
+                  this->ReleaseFreeList();
+                  continue;
+              }
+          }
+          return p;
+      }
+      else
+      {
+          if (0 != m_firstFree)
+          {
+              this->ReleaseFreeList();
+              continue;
+          }
+          if (m_writeHeapLimitOpMsg)
+          {
+              Kernel_OpError errorMsg(csp3_no_more_memory, csp3_n_memory);
+              errorMsg << "OMS_HEAP_LIMIT reached" << FlushLine;
+              errorMsg << "Allocated : " << (m_allocated * GetBlockSize()) << FlushLine;
+              errorMsg << "Required  : " << (BlockCount  * GetBlockSize()) << FlushLine;
+              m_writeHeapLimitOpMsg = false;
+          }
+          return 0;
+      }
   }
+  while (true);
 #endif
 }
 
@@ -137,8 +168,8 @@ void LVCMem_BlockAllocator::CalcStatistics( SAPDB_ULong &BytesUsed,
                                             SAPDB_ULong &BytesControlled)
 {
   BytesUsed       = m_allocated * m_allocator.GetBlockSize();
-  MaxBytesUsed    =
-  BytesControlled = BytesUsed;
+  MaxBytesUsed    = m_maxAllocated * m_allocator.GetBlockSize();
+  BytesControlled = m_controlled * m_allocator.GetBlockSize(); 
 }
 
 /*-----------------------------------------------------*/
@@ -150,7 +181,8 @@ void LVCMem_BlockAllocator::Deallocate(void* p, SAPDB_ULong BlockCount)
 #else
   RTESync_LockedScope lockedScope(m_spinlock);
   ++m_CountDealloc;
-  if ((BlockCount == m_defaultBlockCount) && (m_allocated <= m_limit))
+  m_allocated -= BlockCount;
+  if ((BlockCount == m_defaultBlockCount) && (m_controlled <= m_limit))
   {
     NextPointer* pBlock = REINTERPRET_CAST(NextPointer*, p);
     pBlock->m_next = m_firstFree;
@@ -160,7 +192,7 @@ void LVCMem_BlockAllocator::Deallocate(void* p, SAPDB_ULong BlockCount)
   {
     m_allocator.Deallocate(p, BlockCount);
 	++m_CountBaseDealloc;
-    m_allocated -= BlockCount;
+    m_controlled -= BlockCount;
   }
 #endif
 }
@@ -225,7 +257,7 @@ void LVCMem_BlockAllocator::ReleaseFreeList()
     void* pCurr = m_firstFree;
     m_firstFree = m_firstFree->m_next;
     m_allocator.Deallocate(pCurr, m_defaultBlockCount);
-    m_allocated -= m_defaultBlockCount;
+    m_controlled -= m_defaultBlockCount;
   }
 }
 
@@ -237,7 +269,7 @@ void LVCMem_BlockAllocator::SetLimit(SAPDB_ULong limit)
 	{
 		RTESync_LockedScope lockedScope(m_spinlock);
 		m_limit = this->CalcBlockCount(limit);
-		if (m_allocated > m_limit)
+		if (m_controlled > m_limit)
 		{
 			this->ReleaseFreeList();
 		}
