@@ -826,8 +826,11 @@ ak341NextObjFromKeyIterator (tak_all_command_glob& acv,
             for (i=0,j=0; i<noOfOid; ++i){
               // unloaded version, look if already updated/deleted 
               tsp00_Int4 ObjBodyLen;
-              if (ak341UpdatedInVersion (acv, VersionContext->ovc_tree, ObjFile, pResultOId[i], 
-                                         0, ObjBodyLen, NULL, e, false)) {
+              if (ak341UpdatedInVersion (acv, VersionContext->ovc_tree, ObjFile, pResultOId[i], 0, ObjBodyLen, NULL, e, false)) {
+                if (e==e_object_not_found){
+                  // Object is marked as deleted in the version, so reset error and ignore it.
+                  e = e_ok;
+                }
                 // Ignore entry, as entry is delivered by unloaded-version-iterator
                 //pResultOId[i].gg92SetNil();
               }
@@ -901,8 +904,11 @@ ak341PrevObjFromKeyIterator (tak_all_command_glob& acv,
             for (i=0,j=0; i<noOfOid; ++i){
               // unloaded version, look if already updated/deleted 
               tsp00_Int4 ObjBodyLen;
-              if (ak341UpdatedInVersion (acv, VersionContext->ovc_tree, ObjFile, pResultOId[i], 
-                                         0, ObjBodyLen, NULL, e, false)) {
+              if (ak341UpdatedInVersion (acv, VersionContext->ovc_tree, ObjFile, pResultOId[i], 0, ObjBodyLen, NULL, e, false)) {
+                if (e==e_object_not_found){
+                  // Object is marked as deleted in the version, so reset error and ignore it.
+                  e = e_ok;
+                }
                 // Ignore entry, as entry is delivered by unloaded-version-iterator
                 //pResultOId[i].gg92SetNil();
               }
