@@ -184,6 +184,11 @@ cbd550_FieldQueue::cbd550_FieldQueue (tbd_current_tree & Current)
 inline
 cbd550_FieldQueue::~cbd550_FieldQueue()
 {
+    const bool isCancelled = e_cancelled == m_TrError; 
+
+    if ( isCancelled )
+        m_TrError = e_ok;
+
 	tsp00_PageNo RightNeighbourPageNo;
 	b13w_release_node (m_LastNptrs,  m_Current);	
 	
@@ -211,6 +216,9 @@ cbd550_FieldQueue::~cbd550_FieldQueue()
 			"BD550FieldQueue:PageLeak", m_AllocPageCnt);
 #     endif
 	}
+
+    if ( isCancelled )
+        m_TrError = e_cancelled;
 }
 
 /*---------------------------------------------------------------------------*/
