@@ -301,6 +301,15 @@ bd90RemoveObjFile (tgg00_TransContext &Trans,
 
 /*----------------------------------------------------------------------------*/
 
+externCpp void
+bd90ResetObjLock (tbd_current_tree   &Current,
+                  tgg92_KernelOid    &OId,
+                  tgg91_TransNo       LockTransId,
+                  tgg00_TransIndex    LockTransIndex,
+				  tgg00_ObjFileNo     ObjFileNo);         
+                 
+/*----------------------------------------------------------------------------*/
+
 externCpp void
 bd90MakeObjCountPersistent (tgg00_TransContext &Trans);
 
