@@ -419,7 +419,7 @@ cbd300_InvCurrent::bd300SetFileNotAccessible( bool bSetErrorToNotAccessible )
             if( e_ok != originalError ) // write reason for corruption into knldiag.err
             {
                 char msgText[40]       = "Reason \"";
-                const int remainingLen = sizeof( msgText ) - strlen( msgText ) -1;
+                const int remainingLen = sizeof( msgText ) - strlen( msgText ) -2; //  -2 => for \" and '\0' AT THE END
 
                 const char*   errCodeText    = Kernel_BasisErrorToResultString( originalError );
                 int           errCodeTextLen = strlen( errCodeText );
