@@ -1231,7 +1231,8 @@ bd91InitObjFileDir (tgg00_TransContext &Trans)
                         cbd910_RootNode  NptrsContRoot (Current, ContFileRoot, nr_for_read);
                         if (e_ok != TrError)
                         {
-                            if (((e_page_in_wrong_tree == TrError || e_no_converter_entry == TrError)) &&
+                            if ((e_page_in_wrong_tree == TrError || e_no_converter_entry == TrError ||
+								e_old_fileversion == TrError ) &&   // PTS 1141372 ff
                                 pObjFileInfo->ofiRelFileIsReq_bd900)
                             {
                                 TrError = e_ok;
@@ -1868,7 +1869,8 @@ bd91RemoveObjFromFile (tbd_current_tree        &Current,
         }
 
 #       if COMPILEMODE_MEO00 >= QUICK_MEO00 
-        if (NptrsPage.np_ptr()->nd_in_free_chain() != (NptrsPage.np_ptr()->nd_free_obj_cnt() > 0))
+        if ((NptrsPage.np_ptr()->nd_in_free_chain() != (NptrsPage.np_ptr()->nd_free_obj_cnt() > 0)) &&
+			!NptrsPage.np_ptr()->nd_assigned_to_spec_trans())
         {
             Kernel_OpError( csp3_bd_msg, csp3_n_obj ) << __FILE__ << ":" << __LINE__
                 << " root:" << NptrsPage.np_ptr()->nd_root()
