@@ -870,7 +870,9 @@ bd92_VerifyObjPageChain (tbd_current_tree        &Current,
         /* update page and object counter */
         ++ChainStat.AllPageCnt;        
         
-        if (NptrsPage.np_ptr()->nd_free_obj_cnt() > 0)      
+        if ((NptrsPage.np_ptr()->nd_free_obj_cnt() > 0) 
+			&& /* 1140942 calculate counter as is done by new object optimization */
+			!(NptrsPage.np_ptr()->nd_assigned_to_spec_trans() && (0 == NptrsPage.np_ptr()->nd_in_free_chain())))
             ++ChainStat.FreePageCnt;
         if (NptrsPage.np_ptr()->nd_free_eot_obj_cnt() > 0)      
             ++ChainStat.FeotPageCnt;
