@@ -1,20 +1,14 @@
-/*!*****************************************************************************
-  module:       hcn353.h
-  ------------------------------------------------------------------------------
-  responsible:  TiloH
-  special area: cn layer
-  description:  connection between dbmsrv and Backint for MaxDB conforming
-                backup tools
-  last change:  2000-11-29 10:37
-  version:      7.2.5
-  see also:     
-  ------------------------------------------------------------------------------
-                         Copyright (c) 2000-2005 SAP AG
-
+/*!
+    \file    hcn353.h
+    \author  TiloH
+    \ingroup cn layer
+    \brief   connection between dbmsrv and Backint for MaxDB conforming
+             backup tools
 
+\if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2005 SAP AG
+    Copyright (c) 2000-2006 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -31,10 +25,8 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
-
-
-
-*******************************************************************************/
+\endif
+*/
 
 #if !defined (_HCN353_H_)
 #define _HCN353_H_
@@ -46,6 +38,7 @@
 
 #include "hni31.h"
 #include "hcn35.h"
+#include "hcn36.h"
 
 
 // -----------------------------------------------------------------------------
@@ -163,6 +156,18 @@ class tcn353_Backint2Connector:public tcn35_BackupToolConnector
     char * SourceDBName;
 
     int SecondBackupCall;
+
+    enum CheckAvailabilityEnum
+    {
+        check,
+        checkReducedByTime,
+        checkReducedByNumber,
+        dontCheck
+    };
+
+    CheckAvailabilityEnum checkBackupAvailability;
+    int                   m_CheckAvailabilityNumber;
+    tcn36_DateTimeString  m_CheckAvailabilityTimeLimit;
 };
 
 #endif
