@@ -1,19 +1,13 @@
-/*******************************************************************************
-  module:       hcn36.h
-  ------------------------------------------------------------------------------
-  responsible:  TiloH
-  special area: cn layer
-  description:  basic functions used in vcn35.cpp, ..., vcn355.cpp
-  last change:  2000-11-29 10:50
-  version:      7.2.5
-  see also:     
-  ------------------------------------------------------------------------------
-                         Copyright (c) 1999-2005 SAP AG
-
+/*!
+    \file    hcn36.h
+    \author  TiloH
+    \ingroup cn layer
+    \brief   basic functions used in vcn35.cpp, ..., vcn355.cpp
 
+\if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 1999-2005 SAP AG
+    Copyright (c) 1999-2006 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -30,10 +24,8 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
-
-
-
-*******************************************************************************/
+\endif
+*/
 
 #if !defined(_HCN36_H_)
 #define _HCN36_H_
@@ -93,7 +85,8 @@ int cn36_UInt8ToStrN(char *Buf, size_t Size, teo00_Uint8 i);
 int cn36_StrNConsistsOfDigits(const char *String, size_t Length);
 int cn36_StrConsistsOfDigits(const char *String);
 
-const char * cn36_FirstNonDigitOf(const char * string, size_t stringLength);
+const char * cn36_FirstNonDigitOf(const char * string);
+const char * cn36_FirstNonDigitOfStrN(const char * string, size_t stringLength);
 
 #if defined (WIN32)
 const teo00_Int8    MAX_INT8_CN36=teo00_Int8(9223372036854775807);      //==2^63-1
@@ -129,14 +122,20 @@ const char * cn36_StartOfTrailingWhiteSpaces(const char * s);
    \return pointer to the resulting string (same as argument s)*/
    
 char * cn36_RemoveOuterDoubleQuotes(char * s);
+char * cn36_RemoveSpaces(char * string);
 void cn36_GetStringBetweenDoubleQuotesOrWhiteSpaces(const char * & Start, const char * & End);
 
 const char * cn36_StrChr(const char *String, const char Character);
       char * cn36_StrChr(      char *String, const char Character);
 const char * cn36_StrNChr(const char *String, const char Character, size_t Length);
       char * cn36_StrNChr(      char *String, const char Character, size_t Length);
+const char * cn36_StrNRChr(const char *string, size_t length, const char character);
 const char * cn36_LoopedStrChr(const char *String, char Character, int Number);
       char * cn36_LoopedStrChr(      char *String, char Character, int Number);
+const char * cn36_LoopedStrNChr(const char * string, size_t length, char character, int number);
+
+const char * cn36_StrNStr(const char *string1, size_t lengthString1, const char * string2);
+      char * cn36_StrNStr(      char *string1, size_t lengthString1, const char * string2);
 
 int cn36_StrStrNCmp(const char * String1, const char *String2, size_t Length2);
 int cn36_StrNUprCmp(const char *String1, const char *String2, size_t Length);
@@ -182,6 +181,7 @@ int cn36_CompareEnvVarNames(const char * EnvironmentVariable1, const char * Envi
 const char * cn36_GetEnv(const char * EnvironmentVariable);
 int          cn36_PutEnv(const char * VariableName,
                          const char * VariableValue);
+void         cn36_UnsetEnv(const char * VariableName);
 
 class tcn36_DateTimeFormat
 {
@@ -244,12 +244,19 @@ class tcn36_DateTimeString
     int    operator==(const tcn36_DateTimeString & OtherDateTime) const;
     int    operator!=(const tcn36_DateTimeString & OtherDateTime) const;
     int    operator>(const tcn36_DateTimeString & OtherDateTime) const;
+    int    operator<(const tcn36_DateTimeString & otherDateTime) const;
+
+    void reduceDaysBy(int days);
 
   private:
     void SetMonthDaySecondsTo(int TheYear, int TheMonth, int TheDay, int TheHour, int TheMinute, int TheSecond);
     void MonthDaySecondsToInts(int & TheMonth, int & TheDay, int & TheHour, int & TheMinute, int & TheSecond) const;
     void IntNCpy(char * DestString, int TheInt, size_t Chars) const;
 
+    bool isLeapYear(int year) const;
+    int  calculateDayOfYear(int year, int month, int day) const;
+    void calculateYearMonthAndDay(int dayOfYear, int & year, int & month, int & day) const;
+
     int Year;
     int MonthDaySecond;
 
