@@ -1,9 +1,6 @@
 /*
-
-
-
     ========== licence begin  GPL
-    Copyright (c) 1998-2005 SAP AG
+    Copyright (c) 1998-2007 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -19,11 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
-
-
-
-
-
 */
 /* @lastChanged: "1998-06-16  9:50"
  *
@@ -32,7 +24,7 @@
  * @release:     7.1.0.0
  * @see:         "-.-"
  *
- * @copyright:   (c) 1998-2004 SAP AG-2004"
+ * @copyright:   Copyright (c) 1998-2007 SAP AG
  *
  * ==================================================================
  *
@@ -54,12 +46,17 @@
 
 #include "hcn20.h"
 #include "hcn30.h"
+#include "hcn36.h"
 #include "hcn42.h"
 #include "hcn50.h"
 #include "hcn51.h"
 #include "hcn80.h"
 #include "hcn90.h"
 
+#include "DBM/Srv/DBMSrv_Reply.hpp"
+#include "DBM/Srv/Message/DBMSrvMsg_Error.hpp"
+
+
 /* ------------------------------------------------------------------
  * PRIVATE FUNCTION cn30_SaveMediaToDB
  * ------------------------------------------------------------------
@@ -284,7 +281,8 @@ static tcn00_Error cn30_OpenMediaFile (
       char                * replyData,
       int                 * replyLen,
       bool                  bForWrite, 
-      tsp00_Int4            * hMediaFile )
+      tsp00_Int4            * hMediaFile,
+      char                *& mediaFileName)
 {
   tcn00_Error          nFuncStatus  = OK_CN00;
   tsp05_RteFileError   rteFileError;
@@ -323,13 +321,19 @@ static tcn00_Error cn30_OpenMediaFile (
         } else {
           sqlfopenc (szBackupFile, sp5vf_text, sp5vf_read, sp5bk_buffered, hMediaFile, &rteFileError);
         } // end if
-      } // end if
+
+        cn36_StrAllocCpy(mediaFileName, szBackupFile.asCharp());
+      }
+      else
+        cn36_StrAllocCpy(mediaFileName, szMediaFile.asCharp());
 
       if (rteFileError.sp5fe_result != vf_ok) {
         nFuncStatus = ERR_RTE_CN00;
         cn90AnswerRTEError (replyData, replyLen, nFuncStatus, rteFileError.sp5fe_text, rteFileError.sp5fe_text.length(), rteFileError.sp5fe_result);
       } // end if
-    } // end if
+    }
+    else
+        cn36_StrAllocCpy(mediaFileName, szMediaFile.asCharp());
   } // end if
 
   return nFuncStatus;
@@ -429,6 +433,7 @@ void cn30_InitMedium(
   SAPDB_strcpy(pMedium->szCreated, ME_DEFAULT_DATE_CN003);
   SAPDB_strcpy(pMedium->szModified, ME_DEFAULT_DATE_CN003);
   SAPDB_strcpy(pMedium->szExtern, ME_DEFAULT_EXTERN_CN003);
+  pMedium->m_Interval=0;
   pMedium->bOld = false;
   pMedium->pNext = NULL;
   pMedium->pPrev = NULL;
@@ -468,8 +473,6 @@ static tcn00_Error cn30_CheckMedium (
   long                lSize = 0;
   long                lBlocksize = 0;
 
-  /**/
-
   // NAME
   
   if (nFuncStatus == OK_CN00) {
@@ -651,6 +654,17 @@ static tcn00_Error cn30_CheckMedium (
     }
   }
 
+    //max interval
+    if(OK_CN00==nFuncStatus && 0!=pMedium->m_Interval)
+    {
+        if((0==strcmp(pMedium->szSaveType, ME_SAVETYPE_DAT_CN003) ||
+            0==strcmp(pMedium->szSaveType, ME_SAVETYPE_PAG_CN003)   ))
+        {
+            nFuncStatus=ERR_MENOVALID_CN00;
+            cn90AnswerIError(replyData, replyLen, nFuncStatus);
+        }
+    }
+
   return nFuncStatus;
 } /* end cn30_CheckMedium */
 
@@ -729,7 +743,10 @@ static tcn00_Error cn30_ReadMediumProperties (
       tcn003_Medium  * pMedium,
       char           * replyData,
       int            * replyLen,
-      tsp00_Int4       hMediaFile )
+      int              replyLenMax,
+      tsp00_Int4       hMediaFile,
+      int            & line,
+      const char     * mediaFileName)
 {
   tcn00_Error          nFuncStatus  = OK_CN00;
   tsp05_RteFileError   rteFileError;
@@ -759,56 +776,101 @@ static tcn00_Error cn30_ReadMediumProperties (
       sqlfreadc (hMediaFile, szBuffer, ME_LINE_LENGTH_MXCN003, &nRead, &rteFileError);
       if (rteFileError.sp5fe_result == vf_ok) {
 
+        line++;
         SAPDB_strcpy(szLine, szBuffer);
         cn90Strip(szLine);
         nLen = (long)strlen(szLine);
 
-        if (nLen > 0) {
-  		    if (szLine[0] != ME_COMMENT_CN003) {
-            if ( (szLine[0] == ME_NAME_BEGIN_CN003) && 
-                 (szLine[nLen -1] == ME_NAME_END_CN003) ) {
+        if (nLen > 0 && szLine[0] != ME_COMMENT_CN003)
+        {
+            if ( (szLine[0] == ME_NAME_BEGIN_CN003) )
+            {
+                if(szLine[nLen -1] == ME_NAME_END_CN003)
+                {
+                    bNext = true;
+                    sqlfseekc (hMediaFile, nFilePos, sp5vf_seek_begin, &rteFileError);
+                    line--;
+                }
+                else
+                {
+                    char lineAsString[50];
+                    char nameEndAsString[2]={ME_NAME_END_CN003,'\0'};
 
-              bNext = true;
-              sqlfseekc (hMediaFile, nFilePos, sp5vf_seek_begin, &rteFileError);
+                    sprintf(lineAsString, "%d", (int)line);
 
+                    DBMSrvMsg_Error error(
+                                        DBMSrvMsg_Error::MEFDIRTY,
+                                        mediaFileName?mediaFileName:"unknown",
+                                        lineAsString);
+
+                    error.AppendNewMessage(
+                        DBMSrvMsg_Error(
+                            DBMSrvMsg_Error::FORMAT_DELIMISS,
+                            nameEndAsString,
+                            szLine));
+
+                    nFuncStatus=DBMSrv_Reply(replyData, replyLen, replyLenMax).startWithMessageList(error);
+                }
             }
             else {
-
               szEqual = strchr(szLine, ME_PROP_EQUAL_CN003);
-              nEqualPos = (long) (szEqual - szLine);
 
-              strncpy(szProperty, szLine, nEqualPos);
-              szProperty[nEqualPos] = '\0';
-              cn90Strip(szProperty);
+              if(0==szEqual)
+              {
+                char lineAsString[50];
+                char eqalAsString[2]={ME_PROP_EQUAL_CN003,'\0'};
 
-              SAPDB_strcpy(szValue, szEqual + 1);
-              cn90Strip(szValue);
+                sprintf(lineAsString, "%d", (int)line);
+
+                DBMSrvMsg_Error error(
+                                    DBMSrvMsg_Error::MEFDIRTY,
+                                    mediaFileName?mediaFileName:"unknown",
+                                    lineAsString);
+
+                error.AppendNewMessage(
+                        DBMSrvMsg_Error(
+                            DBMSrvMsg_Error::FORMAT_SEPARATORMISSING,
+                            szLine,
+                            eqalAsString));
+
+                nFuncStatus=DBMSrv_Reply(replyData, replyLen, replyLenMax).startWithMessageList(error);
+              }
+              else
+              {
+                nEqualPos = (long) (szEqual - szLine);
+
+                strncpy(szProperty, szLine, nEqualPos);
+                szProperty[nEqualPos] = '\0';
+                cn90Strip(szProperty);
+
+                SAPDB_strcpy(szValue, szEqual + 1);
+                cn90Strip(szValue);
               
-              if ( strcmp(szProperty, ME_KEY_LOCATION_CN003) == 0 ) {
-                SAPDB_strcpy(pMedium->szLocation, szValue);
-              } else if ( strcmp(szProperty, ME_KEY_TYPE_CN003) == 0 ) {
-                SAPDB_strcpy(pMedium->szType, szValue);
-              } else if ( strcmp(szProperty, ME_KEY_SAVETYPE_CN003) == 0 ) {
-                SAPDB_strcpy(pMedium->szSaveType, szValue);
-              } else if ( strcmp(szProperty, ME_KEY_SIZE_CN003) == 0 ) {
-                SAPDB_strcpy(pMedium->szSize, szValue);
-              } else if ( strcmp(szProperty, ME_KEY_BLOCKSIZE_CN003) == 0 ) {
-                SAPDB_strcpy(pMedium->szBlocksize, szValue);
-              } else if ( strcmp(szProperty, ME_KEY_OVERWRITE_CN003) == 0 ) {
-                SAPDB_strcpy(pMedium->szOverwrite, szValue);
-              } else if ( strcmp(szProperty, ME_KEY_AUTOLOADER_CN003) == 0 ) {
-                SAPDB_strcpy(pMedium->szAutoLoader, szValue);
-              } else if ( strcmp(szProperty, ME_KEY_OSCOMMAND_CN003) == 0 ) {
-                SAPDB_strcpy(pMedium->szOSCommand, szValue);
-              } else if ( strcmp(szProperty, ME_KEY_EXTERN_CN003) == 0 ) {
-                SAPDB_strcpy(pMedium->szExtern, szValue);
-              } else if ( strcmp(szProperty, ME_KEY_CREATED_CN003) == 0 ) {
-                SAPDB_strcpy(pMedium->szCreated, szValue);
-              } else if ( strcmp(szProperty, ME_KEY_MODIFIED_CN003) == 0 ) {
-                SAPDB_strcpy(pMedium->szModified, szValue);
+                if ( strcmp(szProperty, ME_KEY_LOCATION_CN003) == 0 ) {
+                    SAPDB_strcpy(pMedium->szLocation, szValue);
+                } else if ( strcmp(szProperty, ME_KEY_TYPE_CN003) == 0 ) {
+                    SAPDB_strcpy(pMedium->szType, szValue);
+                } else if ( strcmp(szProperty, ME_KEY_SAVETYPE_CN003) == 0 ) {
+                    SAPDB_strcpy(pMedium->szSaveType, szValue);
+                } else if ( strcmp(szProperty, ME_KEY_SIZE_CN003) == 0 ) {
+                    SAPDB_strcpy(pMedium->szSize, szValue);
+                } else if ( strcmp(szProperty, ME_KEY_BLOCKSIZE_CN003) == 0 ) {
+                    SAPDB_strcpy(pMedium->szBlocksize, szValue);
+                } else if ( strcmp(szProperty, ME_KEY_OVERWRITE_CN003) == 0 ) {
+                    SAPDB_strcpy(pMedium->szOverwrite, szValue);
+                } else if ( strcmp(szProperty, ME_KEY_AUTOLOADER_CN003) == 0 ) {
+                    SAPDB_strcpy(pMedium->szAutoLoader, szValue);
+                } else if ( strcmp(szProperty, ME_KEY_OSCOMMAND_CN003) == 0 ) {
+                    SAPDB_strcpy(pMedium->szOSCommand, szValue);
+                } else if ( strcmp(szProperty, ME_KEY_EXTERN_CN003) == 0 ) {
+                    SAPDB_strcpy(pMedium->szExtern, szValue);
+                } else if ( strcmp(szProperty, ME_KEY_CREATED_CN003) == 0 ) {
+                    SAPDB_strcpy(pMedium->szCreated, szValue);
+                } else if ( strcmp(szProperty, ME_KEY_MODIFIED_CN003) == 0 ) {
+                    SAPDB_strcpy(pMedium->szModified, szValue);
+                }
               }
             }
-          }
         }
       }
     }
@@ -837,9 +899,12 @@ static tcn00_Error cn30_ReadNextMedium (
       tcn003_Medium  * pMedium,
       char           * replyData,
       int            * replyLen,
+      int              replyLenMax,
       tsp00_Int4       hMediaFile,
       bool           bProperties,
-      bool           * bFound )
+      bool           * bFound,
+      int            & line,
+      const char     * mediaFileName)
 {
   tcn00_Error          nFuncStatus  = OK_CN00;
   tsp05_RteFileError   rteFileError;
@@ -857,13 +922,14 @@ static tcn00_Error cn30_ReadNextMedium (
   do {
     sqlfreadc(hMediaFile, szBuffer, ME_LINE_LENGTH_MXCN003, &nRead, &rteFileError);
     if (rteFileError.sp5fe_result == vf_ok) {
+      line++;
 
       SAPDB_strcpy(szLine, szBuffer);
       cn90Strip(szLine);
       nLen = (long)strlen(szLine);
 
       if (nLen > 0) {
-  		  if (szLine[0] != ME_COMMENT_CN003) {
+        if (szLine[0] != ME_COMMENT_CN003) {
           if ( (szLine[0] == ME_NAME_BEGIN_CN003) && 
                (szLine[nLen -1] == ME_NAME_END_CN003) ) {
         
@@ -871,12 +937,12 @@ static tcn00_Error cn30_ReadNextMedium (
             pMedium->szName[nLen-2] = '\0';
 
             if (bProperties) {
-              nFuncStatus = cn30_ReadMediumProperties(pMedium, replyData, replyLen, hMediaFile);
+              nFuncStatus = cn30_ReadMediumProperties(pMedium, replyData, replyLen, replyLenMax, hMediaFile, line, mediaFileName);
             }
 
             *bFound = true;
           }
-		    }
+            }
       }
     }
   } while ( ( rteFileError.sp5fe_result  == vf_ok             ) &&
@@ -939,7 +1005,7 @@ static tcn00_Error cn30_ReadParallelIDFromOldMediaFile (
         nLen = (long)strlen(szLine);
 
         if (nLen > 0) {
-  		    if (szLine[0] != ME_OLDCOMMENT_CN003) {
+              if (szLine[0] != ME_OLDCOMMENT_CN003) {
 
             szPos1 = strchr(szLine, ME_PROP_EQUAL_CN003);
 
@@ -1036,7 +1102,7 @@ static tcn00_Error cn30_ReadNextOldMedium (
       nLen = (long)strlen(szLine);
 
       if (nLen > 0) {
-  		  if (szLine[0] != ME_OLDCOMMENT_CN003) {
+            if (szLine[0] != ME_OLDCOMMENT_CN003) {
 
           szPos1 = strchr(szLine, ME_PROP_EQUAL_CN003);
 
@@ -1153,7 +1219,7 @@ static tcn00_Error cn30_ReadNextOldMedium (
               bIgnore = false;
             }
           }
-		    }
+            }
       }
     }
   } while ( ( rteFileError.sp5fe_result  == vf_ok             ) &&
@@ -1220,7 +1286,7 @@ static tcn00_Error cn30_FindMediumByName (
       tcn003_MediaGroup   ** pMediaGroupFound,
       tcn003_Medium       ** pMediumFound )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error            nFuncStatus = OK_CN00;
 
   tcn003_MediaGroup   * pMediaGroup = NULL;
   tcn003_Medium       * pMedium = NULL;
@@ -1279,7 +1345,7 @@ static tcn00_Error cn30_FindMediumInGroupByName (
       char                * szMediumName,
       tcn003_Medium       ** pMediumFound )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error            nFuncStatus = OK_CN00;
 
   tcn003_Medium       * pMedium = NULL;
   
@@ -1327,7 +1393,7 @@ static tcn00_Error cn30_FindMediaGroupByName (
       const char          * szGroupName,
       tcn003_MediaGroup   ** pMediaGroupFound )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error            nFuncStatus = OK_CN00;
 
   tcn003_MediaGroup   * pMediaGroup = NULL;
   
@@ -1370,38 +1436,62 @@ static tcn00_Error cn30_FindMediaGroupByName (
  * purpose: split full medium name in to portions
  *
  */
-void cn30_SplitName (
-      char  * szFullName,
-      char  * szGroupName,
-      char  * szMediumName )
+bool cn30_SplitName (
+      char     * szFullName,
+      char     * szGroupName,
+      size_t     maxGroupNameLength,
+      char     * szMediumName,
+      size_t     maxMediumNameLength)
 {
-  char * pSep = NULL;
+    char * pSep = NULL;
 
-  /**/
+    if(0==maxGroupNameLength || 0==maxMediumNameLength)
+    {
+        return false;
+    }
+    else
+    {
+        szGroupName[0] = '\0';
+        szMediumName[0] = '\0';
 
-  szGroupName[0] = '\0';
-  szMediumName[0] = '\0';
+        pSep = strchr(szFullName, ME_GROUP_NAME_SEP1_CN003);
+
+        if (pSep == NULL)
+        {
+            pSep = strchr(szFullName, ME_GROUP_NAME_SEP2_CN003);
+
+            if(pSep)
+                *pSep = ME_GROUP_NAME_SEP1_CN003;
+        }
+
+        if (pSep)
+        {
+            if((size_t)(pSep-szFullName)>maxGroupNameLength)
+            {
+                return false;
+            }
+
+            if(strlen(pSep+1)>maxMediumNameLength)
+            {
+                return false;
+            }
+
+            strncpy(szGroupName, szFullName, pSep - szFullName);
+            szGroupName[pSep - szFullName] = '\0';
+            SAPDB_strcpy(szMediumName, pSep + 1);
+        }
+        else
+        {
+            if(strlen(szFullName)>maxMediumNameLength)
+            {
+                return false;
+            }
+
+            SAPDB_strcpy(szMediumName, szFullName);
+        }
   
-  pSep = strchr(szFullName, ME_GROUP_NAME_SEP1_CN003);
-  if (pSep == NULL) {
-    pSep = strchr(szFullName, ME_GROUP_NAME_SEP2_CN003);
-    if (pSep) {
-      *pSep = ME_GROUP_NAME_SEP1_CN003;
+        return true;
     }
-  }
-  if (pSep) {
-    strncpy(szGroupName, szFullName, pSep - szFullName);
-    szGroupName[pSep - szFullName] = '\0';
-    SAPDB_memmove(
-        szMediumName,
-        pSep + 1,
-        strlen(pSep + 1)+1);
-  } else {
-    SAPDB_memmove(
-        szMediumName,
-        szFullName,
-        strlen(szFullName)+1);
-  }
 } /* end cn30_SplitName */
 
 /* PRIVATE FUNCTION cn30_AddMedium
@@ -1412,10 +1502,11 @@ void cn30_SplitName (
 static tcn00_Error cn30_AddMedium (
       char           * replyData,
       int            * replyLen,
+      int              replyLengthMax,
       tcn003_Media   * pMedia,
       tcn003_Medium  * pMedium )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error            nFuncStatus = OK_CN00;
 
   tcn003_MediaGroup   * pMediaGroup = NULL;
 
@@ -1423,14 +1514,17 @@ static tcn00_Error cn30_AddMedium (
 
   bool                bOK = false;
 
-  char                szGroupName[ME_NAME_LENGTH_MXCN003];
-  char                szMediumName[ME_NAME_LENGTH_MXCN003];
+  char                szGroupName[ME_NAME_LENGTH_MXCN003+1];
+  char                szMediumName[ME_NAME_LENGTH_MXCN003+1];
 
-  /**/
+    if(!cn30_SplitName(pMedium->szName, szGroupName, ME_NAME_LENGTH_MXCN003, szMediumName, ME_NAME_LENGTH_MXCN003))
+    {
+        nFuncStatus=cn90AnswerIError(replyData, replyLen, ERR_MENOVALID_CN00);
 
-  cn30_SplitName(pMedium->szName, szGroupName, szMediumName);
+    }
 
-  nFuncStatus= cn30_FindMediaGroupByName(replyData, replyLen, pMedia, szGroupName, &pMediaGroup);
+    if(OK_CN00==nFuncStatus)
+        nFuncStatus= cn30_FindMediaGroupByName(replyData, replyLen, pMedia, szGroupName, &pMediaGroup);
 
   if ((nFuncStatus == ERR_MENOTFOUND_CN00) && 
      (pMediaGroup == NULL)                    ) {
@@ -1479,11 +1573,12 @@ static tcn00_Error cn30_ReadMedia (
       const tsp00_DbNamec & szDbName,
       char                * replyData,
       int                 * replyLen,
+      int                   replyLenMax,
       tcn003_Media        * pMedia,
       bool                  bNewMedia,
       bool                  bOldMedia )
 {
-  tcn00_Error	          nFuncStatus       = OK_CN00;
+  tcn00_Error              nFuncStatus       = OK_CN00;
   tsp00_Int4              hMediaFile        = 0;
   tcn003_Medium       * pMedium           = NULL;
   tcn003_Medium       * pMediumExists     = NULL;
@@ -1497,22 +1592,24 @@ static tcn00_Error cn30_ReadMedia (
   cn30_InitMedia(pMedia);
 
   if (bNewMedia) {
+    char * mediaFileName=0;
 
     /* read new media file */
-    nFuncStatus = cn30_OpenMediaFile(szDbName, replyData, replyLen, false, &hMediaFile);
+    nFuncStatus = cn30_OpenMediaFile(szDbName, replyData, replyLen, false, &hMediaFile, mediaFileName);
 
     if (nFuncStatus == OK_CN00) {
+        int line=0;
 
       do {
         nFuncStatus = cn30_NewMedium(replyData, replyLen, &pMedium);
 
         if (nFuncStatus == OK_CN00) {
-          nFuncStatus = cn30_ReadNextMedium(pMedium, replyData, replyLen, hMediaFile, true, &bOK);
+          nFuncStatus = cn30_ReadNextMedium(pMedium, replyData, replyLen, replyLenMax, hMediaFile, true, &bOK, line, mediaFileName);
         
           if ( (nFuncStatus == OK_CN00) && 
                (bOK)                ) {
 
-            nFuncStatus = cn30_AddMedium(replyData, replyLen, pMedia, pMedium);
+            nFuncStatus = cn30_AddMedium(replyData, replyLen, replyLenMax, pMedia, pMedium);
 
           } else {
             if (pMedium != NULL) {
@@ -1522,20 +1619,26 @@ static tcn00_Error cn30_ReadMedia (
         }
       } while ( (nFuncStatus == OK_CN00) &&
                 (bOK)               );
+
+      if (nFuncStatus == OK_CN00)
+         nFuncStatus = cn30_CloseMediaFile(replyData, replyLen, hMediaFile);
+      else
+         cn30_CloseMediaFile(replyData, replyLen, hMediaFile);
     }
 
-    if (nFuncStatus == OK_CN00) {
-      nFuncStatus = cn30_CloseMediaFile(replyData, replyLen, hMediaFile);
-    }
-
+    cn36_StrDealloc(mediaFileName);
   }
 
   /* read old media file */
   if ( (nFuncStatus == OK_CN00) && 
-       (bOldMedia)                 ) {
+       (bOldMedia)                 )
+  {
+      bool mediaFileIsOpen=false;
 
     nFuncStatus = cn30_OpenOldMediaFile(szDbName, replyData, replyLen, false, &hMediaFile);
 
+    mediaFileIsOpen=(nFuncStatus==OK_CN00);
+
     if (nFuncStatus == OK_CN00) {
       nFuncStatus = cn30_ReadParallelIDFromOldMediaFile(replyData, replyLen, hMediaFile, szParallelID);
       if (nFuncStatus == OK_CN00) {
@@ -1560,7 +1663,7 @@ static tcn00_Error cn30_ReadMedia (
             nFuncStatus = cn30_FindMediumByName(replyData, replyLen, pMedia, pMedium->szName, &pMediaGroupExists, &pMediumExists);
 
             if (nFuncStatus == ERR_MENOTFOUND_CN00) {
-              nFuncStatus = cn30_AddMedium(replyData, replyLen, pMedia, pMedium);
+              nFuncStatus = cn30_AddMedium(replyData, replyLen, replyLenMax, pMedia, pMedium);
             }
           }
 
@@ -1575,8 +1678,12 @@ static tcn00_Error cn30_ReadMedia (
                 (bOK)               );
     }
 
-    if (nFuncStatus == OK_CN00) {
-      nFuncStatus = cn30_CloseMediaFile(replyData, replyLen, hMediaFile);
+    if(mediaFileIsOpen)
+    {
+        if (nFuncStatus == OK_CN00)
+            nFuncStatus = cn30_CloseMediaFile(replyData, replyLen, hMediaFile);
+        else
+            cn30_CloseMediaFile(replyData, replyLen, hMediaFile);
     }
   }
   
@@ -1688,6 +1795,7 @@ static tcn00_Error cn30_WriteMedium (
     strcat(szLine, "\0");
     sqlfwritec(hMediaFile, szLine, -1, &rteFileError);
   }
+
   /* MODIFIED */
   if (rteFileError.sp5fe_result == vf_ok) {
     SAPDB_strcpy(szLine, ME_KEY_MODIFIED_CN003);
@@ -1721,7 +1829,7 @@ static tcn00_Error cn30_WriteMediaGroup (
       tcn003_MediaGroup   * pMediaGroup,
       bool                bMigrate)
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error            nFuncStatus = OK_CN00;
 
   tcn003_Medium       * pMedium = NULL;
 
@@ -1764,14 +1872,16 @@ static tcn00_Error cn30_WriteMedia (
       tcn003_Media         * pMedia,
       bool                 bMigrate)
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error            nFuncStatus = OK_CN00;
 
   tsp00_Int4            hMediaFile;
   tcn003_MediaGroup   * pMediaGroup = NULL;
-
+  char                * mediaFileName=0;
   /**/
 
-  nFuncStatus = cn30_OpenMediaFile(szDbName, replyData, replyLen, true, &hMediaFile);
+  nFuncStatus = cn30_OpenMediaFile(szDbName, replyData, replyLen, true, &hMediaFile, mediaFileName);
+
+  cn36_StrDealloc(mediaFileName);
 
   if (nFuncStatus == OK_CN00) {
 
@@ -1876,7 +1986,7 @@ void cn30_GetDateString(
       char * szDateTime)
 {
   tsp00_Date date;
-	tsp00_Time time;
+    tsp00_Time time;
 
   sqldattime(date, time);
 
@@ -1901,13 +2011,11 @@ tcn00_Error cn30BackupMediaGet (
       int           * replyLen,
       int             replyLenMax )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error	      nFuncStatus = OK_CN00;
 
   char                * pCurrPos;
 
-  char                szFullName[ME_NAME_LENGTH_MXCN003];
-  char                szGroupName[ME_NAME_LENGTH_MXCN003];
-  char                szMediumName[ME_NAME_LENGTH_MXCN003];
+  char                szFullName[ME_NAME_LENGTH_MXCN003+1];
 
   bool                bExists;
   bool                bOldExists;
@@ -1922,12 +2030,10 @@ tcn00_Error cn30BackupMediaGet (
 
   char                szOld[4];
   
-  /**/
-
   cn30_InitMedia(&tMedia);
 
   if (nFuncStatus == OK_CN00) {
-    if (cn90GetToken(command->args, szFullName, 1, ME_NAME_LENGTH_MXCN003)) {
+    if (cn90GetToken(command->args, szFullName, 1, ME_NAME_LENGTH_MXCN003+1)) {
       cn30_RemoveDoublequotes(szFullName);
     } else {
       nFuncStatus = ERR_PARAM_CN00;
@@ -1944,14 +2050,22 @@ tcn00_Error cn30BackupMediaGet (
       nFuncStatus = ERR_NOMEDIA_CN00;
       cn90AnswerIError(replyData, replyLen, nFuncStatus);
     } else {
-      nFuncStatus = cn30_ReadMedia(vcontrol->dbname, replyData, replyLen, &tMedia, bExists, bOldExists);
+      nFuncStatus = cn30_ReadMedia(vcontrol->dbname, replyData, replyLen, replyLenMax, &tMedia, bExists, bOldExists);
     }
   }
 
-  if (nFuncStatus == OK_CN00) {
+    if(OK_CN00==nFuncStatus)
+    {
+        char szGroupName[ME_NAME_LENGTH_MXCN003+1]="";
+        char szMediumName[ME_NAME_LENGTH_MXCN003+1]="";
   
-    cn30_SplitName(szFullName, szGroupName, szMediumName);
+        if(!cn30_SplitName(szFullName, szGroupName, ME_NAME_LENGTH_MXCN003, szMediumName, ME_NAME_LENGTH_MXCN003))  //substitute first / to "\\"
+        {
+			nFuncStatus=cn90AnswerIError(replyData, replyLen, ERR_CN00);
+        }
+    }
     
+  if (nFuncStatus == OK_CN00) {
     sprintf(replyData, "%s%s", ANSWER_OK_CN00, LINE_SEPSTRING_CN00);
     pCurrPos = replyData + strlen(replyData);
     
@@ -2044,7 +2158,7 @@ tcn00_Error cn30BackupMediaGetAll (
       int           * replyLen,
       int             replyLenMax )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error           nFuncStatus = OK_CN00;
 
   char                * pCurrPos;
 
@@ -2072,7 +2186,7 @@ tcn00_Error cn30BackupMediaGetAll (
       nFuncStatus = ERR_NOMEDIA_CN00;
       cn90AnswerIError(replyData, replyLen, nFuncStatus);
     } else {
-      nFuncStatus = cn30_ReadMedia(vcontrol->dbname, replyData, replyLen, &tMedia, bExists, bOldExists);
+      nFuncStatus = cn30_ReadMedia(vcontrol->dbname, replyData, replyLen, replyLenMax, &tMedia, bExists, bOldExists);
     }
   }
 
@@ -2171,7 +2285,7 @@ tcn00_Error cn30BackupMediaMigrate (
       int           * replyLen,
       int             replyLenMax )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error           nFuncStatus = OK_CN00;
 
   bool                bExists;
   bool                bOldExists;
@@ -2195,7 +2309,7 @@ tcn00_Error cn30BackupMediaMigrate (
       nFuncStatus = ERR_NOMEDIA_CN00;
       cn90AnswerIError(replyData, replyLen, nFuncStatus);
     } else {
-      nFuncStatus = cn30_ReadMedia(vcontrol->dbname, replyData, replyLen, &tMedia, bExists, bOldExists);
+      nFuncStatus = cn30_ReadMedia(vcontrol->dbname, replyData, replyLen, replyLenMax, &tMedia, bExists, bOldExists);
     }
   }
 
@@ -2231,11 +2345,11 @@ tcn00_Error cn30BackupMediaPut (
       int           * replyLen,
       int             replyLenMax )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error           nFuncStatus = OK_CN00;
 
   bool                bExists;
   bool                bOldExists;
-  char                szDate[64];
+  char                szDate[64]="";
 
   tcn003_Medium       * pMediumPut = NULL;
   tcn003_MediaGroup   * pMediaGroup = NULL;
@@ -2244,8 +2358,8 @@ tcn00_Error cn30BackupMediaPut (
 
   tcn003_Media        tMedia;
 
-  char                szGroupName[ME_NAME_LENGTH_MXCN003];
-  char                szMediumName[ME_NAME_LENGTH_MXCN003];
+  char                szGroupName[ME_NAME_LENGTH_MXCN003+1]="";
+  char                szMediumName[ME_NAME_LENGTH_MXCN003+1]="";
   
   bool                bFound = false;
 
@@ -2285,21 +2399,17 @@ tcn00_Error cn30BackupMediaPut (
     cn90GetToken(command->args, pMediumPut->szExtern, 10, ME_EXTERNAL_LENGTH_MXCN003 + 1);
   }
 
-  /**/
-
   if (nFuncStatus == OK_CN00) {
     nFuncStatus = cn30_CheckMedium(pMediumPut, replyData, replyLen);
   }
 
-  /**/
-
   if (nFuncStatus == OK_CN00) {
     nFuncStatus = cn30_CheckMediaFile(vcontrol->dbname, replyData, replyLen, &bExists, &bOldExists, szDate);
   }
 
   if (nFuncStatus == OK_CN00) {
     if ( (bExists) || (bOldExists) ) {
-      nFuncStatus = cn30_ReadMedia(vcontrol->dbname, replyData, replyLen, &tMedia, bExists, bOldExists);
+      nFuncStatus = cn30_ReadMedia(vcontrol->dbname, replyData, replyLen, replyLenMax, &tMedia, bExists, bOldExists);
     }
   }
 
@@ -2307,10 +2417,16 @@ tcn00_Error cn30BackupMediaPut (
     nFuncStatus = cn30_CheckAutosave(pMediumPut, &tMedia);
   }
 
+    if(OK_CN00==nFuncStatus)
+    {
+
+        if(!cn30_SplitName(pMediumPut->szName, szGroupName, ME_NAME_LENGTH_MXCN003, szMediumName, ME_NAME_LENGTH_MXCN003))
+        {
+            nFuncStatus=cn90AnswerIError(replyData, replyLen, ERR_PARAM_CN00);
+        }
+    }
+
   if (nFuncStatus == OK_CN00) {
-
-    cn30_SplitName(pMediumPut->szName, szGroupName, szMediumName);
-
     if('\0'==szGroupName[0]) //if new medium is not part of a group
     {
         //check if medium name is already used for a group
@@ -2450,7 +2566,7 @@ tcn00_Error cn30BackupMediaDelete (
       int           * replyLen,
       int             replyLenMax )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error           nFuncStatus = OK_CN00;
 
   char                * pCurrPos;
 
@@ -2458,9 +2574,7 @@ tcn00_Error cn30BackupMediaDelete (
   bool                bOldExists;
   char                szDate[64];
 
-  char                szFullName[ME_NAME_LENGTH_MXCN003];
-  char                szGroupName[ME_NAME_LENGTH_MXCN003];
-  char                szMediumName[ME_NAME_LENGTH_MXCN003];
+  char                szFullName[ME_NAME_LENGTH_MXCN003+1];
 
   tcn003_MediaGroup   * pMediaGroup = NULL;
   tcn003_Medium       * pMedium = NULL;
@@ -2470,12 +2584,10 @@ tcn00_Error cn30BackupMediaDelete (
 
   bool                bFound = false;
 
-  /**/
-
   cn30_InitMedia(&tMedia);
 
   if (nFuncStatus == OK_CN00) {
-    if (cn90GetToken(command->args, szFullName, 1, ME_NAME_LENGTH_MXCN003)) {
+    if (cn90GetToken(command->args, szFullName, 1, ME_NAME_LENGTH_MXCN003+1)) {
       cn30_RemoveDoublequotes(szFullName);
     } else {
       nFuncStatus = ERR_PARAM_CN00;
@@ -2492,14 +2604,22 @@ tcn00_Error cn30BackupMediaDelete (
       nFuncStatus = ERR_NOMEDIA_CN00;
       cn90AnswerIError(replyData, replyLen, nFuncStatus);
     } else {
-      nFuncStatus = cn30_ReadMedia(vcontrol->dbname, replyData, replyLen, &tMedia, bExists, bOldExists);
+      nFuncStatus = cn30_ReadMedia(vcontrol->dbname, replyData, replyLen, replyLenMax, &tMedia, bExists, bOldExists);
     }
   }
 
-  if (nFuncStatus == OK_CN00) {
+    if(OK_CN00==nFuncStatus)
+    {
+        char szGroupName[ME_NAME_LENGTH_MXCN003+1]="";
+        char szMediumName[ME_NAME_LENGTH_MXCN003+1]="";
     
-    cn30_SplitName(szFullName, szGroupName, szMediumName);
+        if(!cn30_SplitName(szFullName, szGroupName, ME_NAME_LENGTH_MXCN003, szMediumName, ME_NAME_LENGTH_MXCN003)) //substitute first / to "\\"
+        {
+            nFuncStatus=cn90AnswerIError(replyData, replyLen, ERR_PARAM_CN00);
+        }
+    }
 
+  if (nFuncStatus == OK_CN00) {
     nFuncStatus = cn30_FindMediumByName(replyData, replyLen, &tMedia, szFullName, &pMediaGroup, &pMedium);
 
     if (nFuncStatus == OK_CN00) {
@@ -2549,7 +2669,7 @@ tcn00_Error cn30BackupMediaDate (
       int           * replyLen,
       int             replyLenMax )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error           nFuncStatus = OK_CN00;
 
   char                * pCurrPos;
 
@@ -2616,7 +2736,7 @@ tcn00_Error cn30NewMedium(tcn003_Medium *& pMedium)
 
 tcn00_Error cn30NewMediaGroup(tcn003_MediaGroup *& pMediaGroup)
 {
-    tcn00_Error	rc       =OK_CN00;
+    tcn00_Error rc       =OK_CN00;
     bool        bMallocOK=true;
 
     cn00MyMalloc(sizeof(tcn003_MediaGroup), &pMediaGroup, &bMallocOK);
@@ -2649,10 +2769,11 @@ void cn30InitMedia(tcn003_Media * pMedia)
 tcn00_Error cn30AddMedium(
       char           * replyData,
       int            * replyLen,
+      int              replyLenMax,
       tcn003_Media   * pMedia,
       tcn003_Medium  * pMedium)
 {
-    return cn30_AddMedium(replyData, replyLen, pMedia, pMedium);
+    return cn30_AddMedium(replyData, replyLen, replyLenMax, pMedia, pMedium);
 } // end cn30AddMedium
  
 /* INTERN FUNCTION cn30ReadMedia
@@ -2664,9 +2785,10 @@ tcn00_Error cn30ReadMedia (
       const tsp00_DbNamec   szDbName,
       char                * replyData,
       int                 * replyLen,
+      int                   replyLenMax,
       tcn003_Media        * pMedia )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error           nFuncStatus = OK_CN00;
 
   bool                bExists;
   bool                bOldExists;
@@ -2688,7 +2810,7 @@ tcn00_Error cn30ReadMedia (
       nFuncStatus = ERR_NOMEDIA_CN00;
       cn90AnswerIError(replyData, replyLen, nFuncStatus);
     } else {
-      nFuncStatus = cn30_ReadMedia(szDbName, replyData, replyLen, pMedia, bExists, bOldExists);
+      nFuncStatus = cn30_ReadMedia(szDbName, replyData, replyLen, replyLenMax, pMedia, bExists, bOldExists);
     }
   }
 
@@ -2708,7 +2830,7 @@ tcn00_Error cn30WriteMedia (
       int                 * replyLen,
       tcn003_Media        * pMedia )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error           nFuncStatus = OK_CN00;
 
   /**/
 
@@ -2742,20 +2864,24 @@ tcn00_Error cn30FindMediumByName (
       const char        * szMediumName,
       bool                CheckMediaGroups,
       tcn003_MediaGroup ** pMediaGroupFound,
-      tcn003_Medium     ** pMediumFound )
+      tcn003_Medium     ** pMediumFound,
+      bool                 forbidMatchingGroups )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error           nFuncStatus = OK_CN00;
 
   tcn00_Error           FindMediaGroupResult=ERR_MENOTFOUND_CN00;
   tcn003_MediaGroup    *AMediaGroupWithSameName=0;
 
-  if(CheckMediaGroups)
+  if(CheckMediaGroups || forbidMatchingGroups)
       FindMediaGroupResult=cn30_FindMediaGroupByName(replyData, replyLen, pMedia, szMediumName, &AMediaGroupWithSameName);
 
   nFuncStatus = cn30_FindMediumByName(replyData, replyLen, pMedia, szMediumName, pMediaGroupFound, pMediumFound);
 
-  if(nFuncStatus==OK_CN00 && FindMediaGroupResult==OK_CN00) 
-      nFuncStatus=cn90AnswerIError(replyData, replyLen, ERR_MEAMBIGUOUS_CN00); //we have found a group and a medium with the name szMediumName!
+  if(nFuncStatus==OK_CN00 && CheckMediaGroups && FindMediaGroupResult==OK_CN00)
+      nFuncStatus=cn90AnswerIError(replyData, replyLen, ERR_MEAMBIGUOUS_CN00); //we have found a group and a medium with the name szMediumName, but we should not!
+
+  if(ERR_MENOTFOUND_CN00==nFuncStatus && forbidMatchingGroups && OK_CN00==FindMediaGroupResult)
+      nFuncStatus=cn90AnswerIError(replyData, replyLen, ERR_BAWRONGMEDIUM_CN00);
 
   return nFuncStatus;
 } /* cn30FindMediumByName */
@@ -2772,7 +2898,7 @@ tcn00_Error cn30FindMediaGroupByName (
       const char          * szGroupName,
       tcn003_MediaGroup   ** pMediaGroupFound )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error           nFuncStatus = OK_CN00;
 
   /**/
 
@@ -2796,7 +2922,7 @@ tcn00_Error cn30FindMediumInGroupByLocation (
       tcn003_MediaGroup  ** pMediaGroupFound,
       tcn003_Medium      ** pMediumFound )
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error           nFuncStatus = OK_CN00;
 
   // find media group
   nFuncStatus = cn30_FindMediaGroupByName(replyData, replyLen, pMedia, szGroupName, pMediaGroupFound);
@@ -2829,7 +2955,7 @@ tcn00_Error cn30FindMediumInGroupByLocation (
 tcn00_Error cn30RefreshMediaInDB (
     const tsp00_DbNamec & szDbName)
 {
-  tcn00_Error	        nFuncStatus = OK_CN00;
+  tcn00_Error           nFuncStatus = OK_CN00;
   bool                bExists;
   bool                bOldExists;
   char                szDate[64];
@@ -2859,7 +2985,7 @@ tcn00_Error cn30RefreshMediaInDB (
       if ( (!bExists) && (!bOldExists) ) {
         nFuncStatus = cn30_SaveMediaToDB(szDbName, NULL);
       } else {
-        nFuncStatus = cn30_ReadMedia(szDbName, szAnswer, &nAnswer, &tMedia, bExists, bOldExists);
+        nFuncStatus = cn30_ReadMedia(szDbName, szAnswer, &nAnswer, PARAMETER_MAXLEN_CN90-1, &tMedia, bExists, bOldExists);
       } // end if
     } // end if
 
