@@ -1,19 +1,13 @@
-/*******************************************************************************
-  module:       vcn36.cpp
-  ------------------------------------------------------------------------------
-  responsible:  TiloH
-  special area: cn layer
-  description:  implementing basic functions used in vcn35.cpp, ..., vcn355.cpp
-  last change:  2000-11-29 15:03
-  version:      7.2.5
-  see also:
-  ------------------------------------------------------------------------------
-                         Copyright (c) 1999-2005 SAP AG
-
+/*!
+    \file    vcn36.cpp
+    \author  TiloH
+    \ingroup cn layer
+    \brief   implementing basic functions used in vcn35.cpp, ..., vcn355.cpp
 
+\if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 1999-2005 SAP AG
+    Copyright (c) 1999-2006 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -30,10 +24,8 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
-
-
-
-*******************************************************************************/
+\endif
+*/
 
 #include "hni31.h"
 #include "hcn36.h"
@@ -671,7 +663,15 @@ int  cn36_StrConsistsOfDigits(const char *String)
     return rc;
 }
 
-const char * cn36_FirstNonDigitOf(const char * string, size_t stringLength)
+const char * cn36_FirstNonDigitOf(const char * string)
+{
+    while('\0'!=(*string) && isdigit(*string))
+        ++string;
+
+    return string;
+}
+
+const char * cn36_FirstNonDigitOfStrN(const char * string, size_t stringLength)
 {
     size_t i=0;
 
@@ -781,6 +781,24 @@ char * cn36_RemoveOuterDoubleQuotes(char * s) // same as private function cn31_R
     return s;
 }
 
+char * cn36_RemoveSpaces(char * string)
+{
+    size_t pos=0;
+    size_t copyPos=0;
+
+    while('\0'!=string[pos])
+    {
+        if(!isspace(string[pos]))
+            string[copyPos++]=string[pos];
+
+        pos++;
+    }
+
+    string[copyPos]='\0';
+
+    return string;
+}
+
 void cn36_GetStringBetweenDoubleQuotesOrWhiteSpaces(const char * & Start, const char * & End)
 {
     End=Start;
@@ -848,6 +866,17 @@ char * cn36_StrNChr(char *String, const char Character, size_t Length)
         return String+Pos;
 }
 
+const char * cn36_StrNRChr(const char *string, size_t length, const char character)
+{
+    while(0<length && string[length-1]!=character)
+        length--;
+    
+    if(0<length)
+        return string+(length-1);
+    else
+        return 0;
+}
+
 const char * cn36_LoopedStrChr(const char *String, char Character, int Number)
 {
     if(0!=String && 0<Number)
@@ -882,6 +911,71 @@ char * cn36_LoopedStrChr(char *String, char Character, int Number)
     return String;
 }
 
+const char * cn36_LoopedStrNChr(const char * string, size_t length, char character, int number)
+{
+    size_t remainingLength=length;
+    const char * pos=string;
+
+    if(0==remainingLength || 0>=number)
+        pos=0;
+
+    if(0!=pos)
+    {
+        pos=cn36_StrNChr(pos, character, remainingLength);
+        number--;
+
+        if(0!=pos)
+            remainingLength=length-(pos-string);
+    }
+
+    while(0!=pos && 0<number && 0<remainingLength)
+    {
+        pos=cn36_StrNChr(pos+1, character, remainingLength-1); // pos+1, because pos points already to 'character' from the previous strchr
+        number--;
+
+        if(0!=pos)
+            remainingLength=length-(pos-string);
+    }
+
+    return pos;
+}
+
+const char * cn36_StrNStr(const char *string1, size_t lengthString1, const char * string2)
+{
+    const char * rc=0;
+    size_t posS1=0;
+    size_t posS2=0;
+    size_t lengthString2=strlen(string2);
+
+    while(0==rc && posS1<lengthString1 && '\0'!=string1[posS1])
+    {
+        if((lengthString1-posS1)>=lengthString2 && 0==strncmp(string1+posS1, string2, lengthString2))
+            rc=string1+posS1;
+
+        posS1++;
+    }
+
+    return rc;
+}
+
+char * cn36_StrNStr(char *string1, size_t lengthString1, const char * string2)
+{
+    char * rc=0;
+    size_t posS1=0;
+    size_t posS2=0;
+    size_t lengthString2=strlen(string2);
+
+    while(0==rc && posS1<lengthString1 && '\0'!=string1[posS1])
+    {
+        if((lengthString1-posS1)>=lengthString2 && 0==strncmp(string1+posS1, string2, lengthString2))
+            rc=string1+posS1;
+
+        posS1++;
+    }
+
+    return rc;
+}
+
 int cn36_StrStrNCmp(const char * String1, const char *String2, size_t Length2)
 {
     int rc=strncmp(String1, String2, Length2);
@@ -1358,6 +1452,51 @@ int cn36_PutEnv(const char * VariableName,
     return rc;
 }
 
+// global pointer to the process environment
+extern char **environ;
+
+void cn36_UnsetEnv(const char * VariableName)
+{
+    char * OldEnvString=0;
+
+    // remove pointer from process environment   
+    int nSource = 0;
+    int nTarget = 0;
+    if (0!=environ) 
+    {
+        while (0!=environ[nSource]) 
+        {
+            environ[nTarget] = environ[nSource];
+            if(0==strncmp(environ[nTarget], VariableName, strlen(VariableName)) && //the environment allready contained a string for that variable
+              '='==environ[nTarget][strlen(VariableName)])
+                OldEnvString=environ[nTarget]; // store old pointer for deletion
+            else
+                ++nTarget; // increment target only if is not the element to remove
+            ++nSource;
+        } // end while
+        environ[nTarget]=0;
+    } // end if
+
+    // remove from our environment string list
+    ni31_ListElem<char *> *Element=ListOfUsedEnvironmentStrings_cn36.First();
+    ni31_ListElem<char *> *Successor=NULL;
+    int FoundInList=0;
+    while(0!=Element && !FoundInList) //look through the list of former parts of the environment (put by this function)
+    {
+        if(Element->GiveInfo() == OldEnvString) // is it from us?
+        {
+          if (NULL!=Successor)
+            ListOfUsedEnvironmentStrings_cn36.Del(*Successor); // remove element from list
+          else
+            ListOfUsedEnvironmentStrings_cn36.Del();           // remove element from list
+          cn36_StrDealloc(OldEnvString);             //free the memory of the old string (as it is not longer used by the environment)
+          FoundInList=1;
+        }
+        Successor=Element;
+        Element=Element->Next();
+    }
+
+} // end cn36_UnsetEnv
 
 tcn36_DateTimeFormat::tcn36_DateTimeFormat()
     :FormatString(0)
@@ -1962,6 +2101,106 @@ int tcn36_DateTimeString::operator>(const tcn36_DateTimeString & OtherDateTime)
     return (Year>OtherDateTime.Year || (Year==OtherDateTime.Year && MonthDaySecond>OtherDateTime.MonthDaySecond));
 }
 
+int tcn36_DateTimeString::operator<(const tcn36_DateTimeString & otherDateTime) const
+{
+    return (Year<otherDateTime.Year || (Year==otherDateTime.Year && MonthDaySecond<otherDateTime.MonthDaySecond));
+}
+
+void tcn36_DateTimeString::reduceDaysBy(int days)
+{
+    int parts[1+(tcn36_DateTimeFormat::Second)]={0,1,1,0,0,0};   //set month and day to 1
+
+    parts[tcn36_DateTimeFormat::Year]=Year;
+    MonthDaySecondsToInts(
+        parts[tcn36_DateTimeFormat::Month],
+        parts[tcn36_DateTimeFormat::Day],
+        parts[tcn36_DateTimeFormat::Hour],
+        parts[tcn36_DateTimeFormat::Minute],
+        parts[tcn36_DateTimeFormat::Second]);
+
+    int completedDaysOfYear=-1+calculateDayOfYear(parts[tcn36_DateTimeFormat::Year], parts[tcn36_DateTimeFormat::Month], parts[tcn36_DateTimeFormat::Day]);
+
+    while(completedDaysOfYear<days)
+    {
+        parts[tcn36_DateTimeFormat::Year]--;
+        completedDaysOfYear+=isLeapYear(parts[tcn36_DateTimeFormat::Year])?366:365;
+    }
+
+    completedDaysOfYear-=days;
+
+    calculateYearMonthAndDay(1+completedDaysOfYear, parts[tcn36_DateTimeFormat::Year], parts[tcn36_DateTimeFormat::Month], parts[tcn36_DateTimeFormat::Day]);
+
+    SetMonthDaySecondsTo(
+        parts[tcn36_DateTimeFormat::Year],
+        parts[tcn36_DateTimeFormat::Month],
+        parts[tcn36_DateTimeFormat::Day],
+        parts[tcn36_DateTimeFormat::Hour],
+        parts[tcn36_DateTimeFormat::Minute],
+        parts[tcn36_DateTimeFormat::Second]);
+}
+
+bool tcn36_DateTimeString::isLeapYear(int year) const
+{
+    if(0==year%400)
+        return true;
+    else
+        if(0==year%100)
+            return false;
+        else
+            if(0==year%4)
+                return true;
+            else
+                return false;
+}
+
+int tcn36_DateTimeString::calculateDayOfYear(int year, int month, int day) const
+{
+    static const int daysBeforeMonth[12]=
+        {0,                                     //0   days before January
+         31,                                    //31  days before February
+         31+28,                                 //59  days before March
+         31+28+31,                              //90  days before April
+         31+28+31+30,                           //120 days before May
+         31+28+31+30+31,                        //151 days before June
+         31+28+31+30+31+30,                     //181 days before Juli
+         31+28+31+30+31+30+31,                  //212 days before August                
+         31+28+31+30+31+30+31+31,               //243 days before September
+         31+28+31+30+31+30+31+31+30,            //273 days before October
+         31+28+31+30+31+30+31+31+30+31,         //304 days before November
+         31+28+31+30+31+30+31+31+30+31+30,      //334 days before December
+        };
+
+    if(2<month && isLeapYear(year))
+        return daysBeforeMonth[month-1]+1+day;
+    else
+        return daysBeforeMonth[month-1]+day;
+}
+
+void tcn36_DateTimeString::calculateYearMonthAndDay(int dayOfYear, int & year, int & month, int & day) const
+{
+    static int daysInMonthNormalYear[12]={31,28,31,30,31,30,31,31,30,31,30,31};
+    static int daysInMonthLeapYear[12]  ={31,29,31,30,31,30,31,31,30,31,30,31};
+
+    int i=0;
+    
+    while(dayOfYear>(isLeapYear(year)?366:365))
+    {
+        year++;
+        dayOfYear-=(isLeapYear(year)?366:365);
+    }
+
+    int * daysInMonth=isLeapYear(year)?daysInMonthLeapYear:daysInMonthNormalYear;
+
+    while(i<12 && dayOfYear>daysInMonth[i])
+    {
+        dayOfYear-=daysInMonth[i];
+        i++;
+    }
+
+    month=1+i;
+    day=dayOfYear;
+}
+
 int tcn36_DateTimeString::MonthConversionFactor=10000000;
 int tcn36_DateTimeString::DayConversionFactor=100000;
 int tcn36_DateTimeString::SecondsPerHour=3600;
