@@ -1,20 +1,14 @@
-/*******************************************************************************
-  module:       vcn383.cpp
-  ------------------------------------------------------------------------------
-  responsible:  TiloH
-  special area: cn layer
-  description:  implementation of functions for handling history file of
-                Backint for SAP DB
-  last change:  2000-08-24 11:47
-  version:      7.2
-  see also:     
-  ------------------------------------------------------------------------------
-                         Copyright (c) 2000-2005 SAP AG-2004
-
+/*!
+    \file    vcn383.cpp
+    \author  TiloH
+    \ingroup cn layer
+    \brief   implementation of functions for handling history file of
+             Backint for MaxDB
 
+\if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2005 SAP AG
+    Copyright (c) 2000-2006 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -31,10 +25,8 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
-
-
-
-*******************************************************************************/
+\endif
+*/
 
 #include "hcn36.h"
 #include "hcn383.h"
