@@ -419,24 +419,31 @@ tcn00_Error cn41UserSap
     cn90Uncrypt(pPassword, false);
     szUser.rawAssign(szToken);
     szPassword.rawAssign(pPassword);
-    
-    cn50DBMUser oldSapUser(vcontrol->dbname, cn50DBMUser::getSAPUser(vcontrol->dbname));
-    oldSapUser.deleteUsr();
 
-    cn50DBMUser newSapUser( vcontrol->dbname );
-    newSapUser.setUserName  ( szUser )
-              .setMasterPwd ( szPassword )
-              .setSAPUser   ( true );
+    // check new sap user
+    cn50DBMUser checkNewSapUser( vcontrol->dbname, szUser);
+    if (checkNewSapUser.existsOnDisk() && !checkNewSapUser.isSAPUser()) {
+      nFuncReturn = cn90AnswerIError(replyData, replyLen, ERR_USREXISTS_CN00);
+    } else {
+      // delete old user
+      cn50DBMUser oldSapUser(vcontrol->dbname, cn50DBMUser::getSAPUser(vcontrol->dbname));
+      oldSapUser.deleteUsr();
+
+      // create new user
+      cn50DBMUser newSapUser( vcontrol->dbname );
+      newSapUser.setUserName  ( szUser )
+                .setMasterPwd ( szPassword )
+                .setSAPUser   ( true );
     
-    nFuncReturn = newSapUser.save();
-    if (nFuncReturn != OK_CN00) {
-      if (newSapUser.lastEvent()) {
-         nFuncReturn = cn90AnswerEvent(replyData, replyLen, newSapUser.lastEvent());
-      } else {
-        cn90AnswerIError(replyData, replyLen, nFuncReturn);
+      nFuncReturn = newSapUser.save();
+      if (nFuncReturn != OK_CN00) {
+        if (newSapUser.lastEvent()) {
+           nFuncReturn = cn90AnswerEvent(replyData, replyLen, newSapUser.lastEvent());
+        } else {
+          cn90AnswerIError(replyData, replyLen, nFuncReturn);
+        } // end if
       } // end if
     } // end if
-      
   } else {
     nFuncReturn = cn90AnswerIError(replyData, replyLen, ERR_PARAM_CN00);
   } // end if
