@@ -516,6 +516,7 @@ struct TASK_TYPE
     SAPDB_Bool                      TimeCollectionEnabled;     /* actual time enabled flag (copy of kgs->fTimeMeasure)*/
     SAPDB_Bool                      MoveTimeCollectionEnabled; /* actual move time enabled flag (copy of   XPARAM(uLoadBalancingCheck))*/
     SAPDB_Bool                      YieldTask;                 /* flag to use task yield (reschedule) to disable time collection */
+    SAPDB_Int4                      yieldRequestAtPos;
 
     teo00_Longint                   cputim ;
     teo00_Longint                   dirio ;
@@ -583,6 +584,10 @@ struct TASK_TYPE
 
     /* PTS 1110953 */
     SAPDB_UInt4 *                   maxStackPointer;    /* deepest stack position of all dispatcher calls */
+#if  defined(IA64) || defined(HP_IA64) || defined(_M_IA64)
+    SAPDB_Byte *                    pCurrBackingStorePointer;  /* last stack pointer value on entry in dispatcher */
+    SAPDB_Byte *                    maxBackingStorePointer;    /* deepest stack position of all dispatcher calls */
+#endif
     SAPDB_UInt4                     commandMaxStack;    /* maximum stack usage in bytes per command */
     SAPDB_UInt4                     totalMaxStack;      /* maximum stack usage in bytes over all commands */
     tsp00_PageNo                    lockedPageNo;       /* page number set if suspended via vSuspendForPageLock() */
