@@ -43,6 +43,7 @@
 #include "RunTime/System/RTESys_Time.h"
 #include "gen22.h"
 #include "SAPDBCommon/ErrorsAndMessages/SAPDBErr_MessageOutput.h"
+#include "RunTime/Diagnose/RTEDiag_Appldiag.h"
 
 /* exported functions */
 
@@ -666,6 +667,14 @@ void en22MessageOutputCall( SAPDB_Int4         msgOutputMask,
     eo60k_Message( msgPrio, msgType, msgNumber, msgLabel, msgText);
 }
 
+/*
+  @brief write "end of startup" line
+ */
+void en22MarkEndOfStartup(void)
+{
+    en22_writeToDiagFile(APPLDIAG_ENDOFSTARTUP"\n",strlen(APPLDIAG_ENDOFSTARTUP"\n"));
+}
+
 /*===========================================================================*
  *  END OF CODE                                                              *
  *===========================================================================*/
