@@ -209,6 +209,9 @@ static void en71_DoLeaveDispatcherTiming(ten50_UKT_Control *this_ukt);
 /*
  * ===========================================================================
  */
+#if  defined(IA64) || defined(HP_IA64) || defined(_M_IA64)
+extern void *RTE_IA64GetBsp(void);
+#endif
 
 void    en71Dispatcher ( ten50_UKT_Control *this_ukt)
 {
@@ -261,11 +264,25 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
               sleep(0);
         }
 #endif
-        /* PTS 1110953 */
+        /* PTS 1110953 + 1141648 */
+#if defined(PA20W)
         if ( pTaskCtrl->maxStackPointer < (SAPDB_UInt4 *)&rc )
         {
             pTaskCtrl->maxStackPointer = (SAPDB_UInt4 *)&rc;
         }
+#else
+        if ( pTaskCtrl->maxStackPointer > (SAPDB_UInt4 *)&rc )
+        {
+            pTaskCtrl->maxStackPointer = (SAPDB_UInt4 *)&rc;
+        }
+#endif
+#if  defined(IA64) || defined(HP_IA64) || defined(_M_IA64)
+        pTaskCtrl->pCurrBackingStorePointer = (SAPDB_Byte *)RTE_IA64GetBsp();
+        if ( pTaskCtrl->maxBackingStorePointer < pTaskCtrl->pCurrBackingStorePointer )
+        {
+            pTaskCtrl->maxBackingStorePointer = pTaskCtrl->pCurrBackingStorePointer;
+        }
+#endif
 
         en71_DoEnterDispatcherTiming(this_ukt, pTaskCtrl);
     }
@@ -608,7 +625,8 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
                         {
                             pTaskCtrl = this_ukt->RunQueue[idx].Task;
 
-                            if ( pTaskCtrl->moveLock.type.longTerm != 0 ) 
+                            if (( pTaskCtrl->moveLock.type.longTerm != 0 ) ||
+                                ( pTaskCtrl->TaskStateStat.runqueueEnqueueTime == 0 ))
                                 continue;
 
                             runnableMicroSeconds = timeNow - pTaskCtrl->TaskStateStat.runqueueEnqueueTime;
@@ -860,16 +878,10 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
                 if ( tempTaskCtrl->prio_flag ) 
                     this_ukt->SelfDispatch++;
 
-                if ( highestPrioTask == tempTaskCtrl ) /* More than one queue element for the same task found? */
-                {
-                    if ( REQ_RESCHEDULE_EO00 == runQueue[idx].Req->req_type ) /* Yield request? */
-                    {   /* We have use the yield element first because the task 
-                           is waiting for the yield request first. */
-                        highestPrioTask = tempTaskCtrl;
-                        runIndex        = idx;
-                    }
-                }
-                else if ( highestPrioTask->ulDynPrio < tempTaskCtrl->ulDynPrio )
+                if ( REQ_RESCHEDULE_EO00 == runQueue[idx].Req->req_type ) /* Yield request? */
+                    tempTaskCtrl->yieldRequestAtPos = idx;
+
+                if ( highestPrioTask->ulDynPrio < tempTaskCtrl->ulDynPrio )
                 { 
                     highestPrioTask = tempTaskCtrl;
                     runIndex        = idx;
@@ -878,6 +890,13 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
 
             if ( highestPrioTask )
             {
+                if ( -1 != highestPrioTask->yieldRequestAtPos )
+                {   
+                    /* Swap run queue index because yield has to be served first */
+                    runIndex = highestPrioTask->yieldRequestAtPos;
+                    highestPrioTask->yieldRequestAtPos = -1;
+                }
+
                 highestPrioTask->is_in_queue = TASK_IS_IN_NON_QUEUE;
                 highestPrioTask->ulDynPrio   = 0; 
 
@@ -2023,7 +2042,7 @@ static SAPDB_Bool en71TaskMoveCheck( ten50_UKT_Control**   srcUKT,
           microSecondsCompare = (*srcUKT)->maxRunnableMicroSeconds[prevTimeVar];
           break;
         case TASK_MOVE_TIME_COMP_EQUAL:
-          if (( *srcUKT == NULL ) ||( tmpUKT->runnableMicroSeconds > (*srcUKT)->runnableMicroSeconds ))
+          if (( *srcUKT == NULL ) ||( tmpUKT->runnableMicroSeconds[prevTimeVar] > (*srcUKT)->runnableMicroSeconds[prevTimeVar] ))
           {
             *srcUKT           = tmpUKT;
             microSecondsCompare = (*srcUKT)->maxRunnableMicroSeconds[prevTimeVar];
