@@ -129,17 +129,23 @@ ten50_UKT_Control               * this_ukt = THIS_UKT_CTRL;
      */
     tcb = this_ukt->curr_task ;
 
+    if (tcb)
+      en71TempMoveLock (tcb, 1, true );
+
     for ( this_ukt->curr_task = this_ukt->pFirstTaskCtrl ;
 		  this_ukt->curr_task ;
 		  this_ukt->curr_task = this_ukt->curr_task->next_task )
     {
 		DBG1 (( MF__,"Shutdown test T%d \n", this_ukt->curr_task->index ));
+
 		if ( (this_ukt->curr_task->type == TT_US || this_ukt->curr_task->type == TT_EV) 
-	      && e75_is_connected(this_ukt->curr_task) )
+   	          && e75_is_connected(this_ukt->curr_task) )
 		{
 		    e75_release_connection ( SP1CE_SHUTDOWN, FALSE ); /* no wait */
-		}
+        }
     }
+    if (tcb)
+      en71TempMoveLock (tcb, 1, false );
 
     this_ukt->curr_task = tcb ;
 
@@ -409,7 +415,7 @@ void e75_release_connection ( int reason ,
             cip->ci_connect_time = 0 ;
 
             /* cip->ci_state = CON_UNUSED ; already done above */
-            KGS->connectedUserTasks -= this_ukt->curr_task->type == TT_US ? 1 : 0;
+            KGS->connectedUserTasks -= tcb->type == TT_US ? 1 : 0;
         }
         CLEARLOCK ( tcb->ukt->exclusive );
     }
@@ -526,7 +532,6 @@ int e75_connect_request ( struct TASK_TYPE  * tcb,
 {
 #undef  MF__
 #define MF__ MOD__"e75_connect_request"
-    ten50_UKT_Control * this_ukt = THIS_UKT_CTRL;
     int				    rc ;
     int				    stack_avail = TRUE ;
     tsp1_comm_error		result ;
@@ -576,7 +581,7 @@ int e75_connect_request ( struct TASK_TYPE  * tcb,
 		return ( -1 );
     }
 
-    KGS->connectedUserTasks += this_ukt->curr_task->type == TT_US ? 1 : 0;
+    KGS->connectedUserTasks += tcb->type == TT_US ? 1 : 0;
 
     comseg = cip->ci_comseg ;
     sql32_unlock_comseg ( cip );
