@@ -373,7 +373,8 @@ extern "C" void *en88RunCoroutineUKT(void *arg)
     RTE_ContextPrepare( *(this_ukt->removeTaskContext), 0, 0, 0);
 
     /* as long as it need tasks on stack of pthread this will be true... */
-    if ( XPARAM(fUseStackOnStack) )
+#if defined ( USE_STACK_ON_STACK )
+    if( XPARAM(fUseCoroutines) )
     {
         SAPDB_Int4 totalAlignedStackSize;
         for ( totalAlignedStackSize = 0, pTask = this_ukt->pFirstTaskCtrl; 
@@ -440,6 +441,7 @@ extern "C" void *en88RunCoroutineUKT(void *arg)
 
     }
     else
+#endif
     {
         for ( pTask = this_ukt->pFirstTaskCtrl; pTask; pTask = pTask->next_task )
         {
@@ -652,6 +654,10 @@ extern "C" void en88_CallCoroutineKernelTaskMain ()
     en88_CallKernelTaskMain(RTE_ITaskStackControl::Instance().GetTaskControl());
 }
 
+#if  defined(IA64) || defined(HP_IA64) || defined(_M_IA64)
+extern "C" void *RTE_IA64GetBsp(void);
+#endif
+
 #ifdef DEBUG_RTE
 void whereIsTaskStack(struct  TASK_TYPE * tcb, ten50_UKT_Control *this_ukt)
 {
@@ -685,6 +691,14 @@ static void en88_CallKernelTaskMain ( struct  TASK_TYPE * tcb )
 #define MF__ MOD__"en88_CallKernelTaskMain"
 #ifndef OSF1
     try {
+        {
+            SAPDB_UInt4 stackConsumption = 0;
+            tcb->maxStackPointer = &stackConsumption;
+#if  defined(IA64) || defined(HP_IA64) || defined(_M_IA64)
+            tcb->maxBackingStorePointer = (SAPDB_Byte *)RTE_IA64GetBsp();
+#endif
+        }
+
 #endif /* !OSF1 */
         ten50_UKT_Control *this_ukt = tcb->ukt;
 #ifdef DEBUG_RTE
