@@ -45,6 +45,7 @@
 #include "hen40.h"
 #include "RunTime/RTE_IniFileHandling.h"
 #include "SAPDBCommon/SAPDB_Names.h"
+#include "RunTime/RTE_saveUNIXcalls.h"
 
 #if 0
 #define ERROR_TRACE(args) printf args
@@ -81,7 +82,6 @@ typedef struct RTEReqRespDataT {   /* from teo42_RTEReqRespData*/
 /* --- request/response types ( 1 - 32 ) reserved by geo42.h */
 #define REQ_RESP_TYPE_RAW_DATA                 1
 #define REQ_RESP_TYPE_EVENTLIST                2
-
 /* from geo44.h */
 #define REQ_RESP_TYPE_BUFFER_SIZE_REQUEST           33
 #define REQ_RESP_TYPE_BUFFER_SIZE_RESPONSE          34
@@ -731,10 +731,29 @@ static void terminateChildProcess_MF (connection_info     *cip)
 static int clearLocalManagerConnection_MF (connection_info     *cip,
         tsp00_ErrTextc    pErrText)
 {
+    RTEReqRespDataT *	requestHeader;
+    unsigned char   *	requestData;
+    int					requestLen = 0;
+	int					rc = va_ok;
+
+    /*
+     * send disconnect request
+     */
+
+    cip->ci_request = cip->ci_packet [0];
+    cip->ci_requestData = cip->ci_packetData [0];
+    requestHeader = (RTEReqRespDataT *) cip->ci_packetData [0];
+    requestData = ((unsigned char *) cip->ci_packetData [0])
+        + sizeof (RTEReqRespDataT);
+    fillRequestHeader_MF (requestHeader, requestLen);
+    cip->ci_request->rh_mess_class = REQ_RESP_TYPE_DISCONNECT_REQUEST;
+    cip->ci_request_lgt = sizeof (RTEReqRespDataT) + requestLen;
+    rc = requestReceive_MF (cip, pErrText);
+
     closePipes_MF (&cip->ci_pipe_info);
     freePackets_MF (cip, 1);
     terminateChildProcess_MF (cip);
-    return va_ok;
+    return rc;
 }
 
 /*----------------------------------------*/
@@ -816,12 +835,23 @@ static int replyAvailableFromLocalManager_MF (
     connection_info     *cip,
     tsp00_ErrTextc    pErrText)
 {
-    /*
-     * not really implemented, but answer OK to
-     * prevent endless loops
-     * implementation: use select
-     */
-    return va_ok;
+	int				rc;
+	fd_set			readFileDescriptors;
+	struct timeval	timeout;
+
+	FD_ZERO(&readFileDescriptors);
+	FD_SET(cip->ci_pipe_info.data.readHandle, &readFileDescriptors);
+
+	timeout.tv_sec = 0;
+	timeout.tv_usec = 0;
+
+	rc = RTE_save_select (1, &readFileDescriptors, NULL, NULL, &timeout);
+	if (0 == rc)
+	{
+		return commErrWouldBlock_esp01;
+	}
+
+    return commErrOk_esp01;
 }
 
 /*----------------------------------------*/
