@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -155,7 +156,8 @@
 /*
  *  mess_class  ( new )
  */
-#define RSQL_INFO_REQUEST_KEEP_ALIVE_EO003    50
+#define RSQL_INFO_REQUEST_KEEP_ALIVE_EO003    49 /* change from 50 to 49 due to PTS 1140311      */
+                                                 /* do not reuse 50 or old kernels will crash... */
 #define RSQL_INFO_REQUEST_EO003               51
 #define RSQL_INFO_REPLY_EO003                 52
 
@@ -185,13 +187,18 @@
 
 #define RSQL_DUMP_REQUEST_EO003               81
 
+#define RSQL_CTRL_INFO_REQUEST_EO003          88
+#define RSQL_CTRL_INFO_REPLY_EO003            89
+
 #define RSQL_CTRL_CONN_REQUEST_EO003		      91
 #define RSQL_CTRL_CONN_REPLY_EO003	    	    92
 #define RSQL_CTRL_CANCEL_REQUEST_EO003	      93
 
+
 /* !!! dbname in varpart only tsp00_DbName !!! */
 #define RSQL_NEW_USER_CONN_REQUEST_EO003      100
 
+#define RSQL_REQUEST_UNKNOWN_REPLY_EO003      255
 /*
  *  rte flags
  */
