@@ -146,8 +146,12 @@ typedef struct DDB4_SEMA    *PSEM_CTRL_REC ;
 #define TASK_REGION_ACCESS(_pTaskCtrl)  ZERO_IF_RESET_PENDING((_pTaskCtrl),(_pTaskCtrl)->ulBegExclCalls)
 #define TASK_AT_INDEX(_IDX)      (KGS->pFirstTaskCtrl + _IDX - 1)
 #define IS_DEVSP_IN_USE(_DevNo)  (DEVSP_NAME(_DevNo)[0] != '\0')
-#define LAST_DEV                 (FIRST_DEV + (XPARAM(lMaxDevspaces) * XPARAM(lDeviPerDevspace) - 1))
-
+#if defined(_WIN32)
+#define DEVI_PER_VOLUME          (XPARAM(lDeviPerDevspace))
+#else
+#define DEVI_PER_VOLUME          (KGS->devpsets)
+#endif
+#define LAST_DEV                 (FIRST_DEV + (XPARAM(lMaxDevspaces) * DEVI_PER_VOLUME - 1) )
 /*===========================================================================*
  *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
  *===========================================================================*/
@@ -476,13 +480,15 @@ static bool eo922GetRteInfoIO( tsp00_Int4          DevNo,
   PDEVI_CTRL_REC     pDeviCtrl;
   tsp00_Longuint     ulDevi;
   PUKT_CTRL_REC      pTmpUKTCtrl;
-
+#if defined(_WIN32)
+  tsp00_Longuint lastDevi = (tsp00_Longuint)DEVI_PER_VOLUME;
+#else
+  tsp00_Longuint lastDevi = (tsp00_Longuint)(DevNo ? DEVI_PER_VOLUME : 1);
+#endif
   // --- get counts of DEVi's
-  for ( ulDevi = 0; ulDevi < (tsp00_Longuint) XPARAM(lDeviPerDevspace); ulDevi++ )
+  for ( ulDevi = 0; ulDevi < lastDevi; ulDevi++ )
   {
-    pDeviCtrl = FIRST_DEV +
-                DevNo * XPARAM(lDeviPerDevspace) + ulDevi;
-
+    pDeviCtrl = FIRST_DEV + (DevNo * DEVI_PER_VOLUME) + ulDevi;
     if ( DEVI_IN_USE(pDeviCtrl) && !pDeviCtrl->DevIOStat.ResetPending )
     {
       ulReadCnt      += pDeviCtrl->DevIOStat.DevRead.IOStat.ulCount;
@@ -971,7 +977,7 @@ externC tsp00_Bool vGetRteInfoIODetailsNext ( tsp92_RteIODetailsInfo *RteIODetai
         RteIODetailsInfo->ThreadId =THREAD_TID(pDeviCtrl) ;
         RteIODetailsInfo->QueLen     = (tsp00_Int4 ) pDeviCtrl->DevIOStat.ulIOQueLen ;
         RteIODetailsInfo->MaxQueLen  = (tsp00_Int4 ) pDeviCtrl->DevIOStat.ulMaxIOQueLen ;
-        RteIODetailsInfo->DevNo  = RteIODetailsInfo->InternalDevno / XPARAM(lDeviPerDevspace) ;
+        RteIODetailsInfo->DevNo  = RteIODetailsInfo->InternalDevno / DEVI_PER_VOLUME;
         RteIODetailsInfo->ActDEV = ( tsp00_Longint) (pDeviCtrl+1) ;
       }
     }
