@@ -26,6 +26,26 @@
     ---------- licence end
 
 
+\endif
+\if EMIT_LICENCE
+
+    ========== licence begin  GPL
+    Copyright (c) 2005 SAP AG
+
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 \endif
 */
 
@@ -331,8 +351,7 @@ int e952_call_vserver ( PROG_ID *vserver,
           || !strcmp( &args[i][1], &OPT_NEW_DEBUG_LEVEL[1] ) ) /* PTS 1111208 */
 		{
             ++i;
-		    if ( IS_OPT_CHR (*args[i])
-			    || i >= num_args )
+		    if ( i >= num_args || IS_OPT_CHR (*args[i]))
             {
                 call_ret = NOTOK ;
             }
