@@ -179,4 +179,13 @@ kb67GetBeforeImage (tgg00_TransContext &Trans,
                     tgg91_PageRef      &ObjHistRef,         
                     tsp00_Int4         &LogReadAccesses);   
 
+/*---------------------------------------------------------------------------*/
+
+externCpp void
+kb67ResetObjLock (tgg00_TransContext &Trans,
+                  tgg91_TransNo       LockTransId,
+                  tgg00_TransIndex    LockTransIndex,
+                  tgg92_KernelOid     Oid,
+                  tgg00_ObjTransInfo &ObjTransInfo);
+
 #endif /*HKB67_H*/
