@@ -631,6 +631,23 @@ kb67NewObj (tgg00_TransContext &Trans,
 }
 
 
+/*---------------------------------------------------------------------------*/
+
+externCpp void
+kb67ResetObjLock (tgg00_TransContext &Trans,
+                  tgg91_TransNo       LockTransId,
+                  tgg00_TransIndex    LockTransIndex,
+                  tgg92_KernelOid     Oid,
+                  tgg00_ObjTransInfo &ObjTransInfo)
+{ 
+    ROUTINE_DBG_MSP00 ("kb67ResetObjLock");
+    
+    if (e_ok != Trans.trError_gg00) return;    
+    
+    kb50TryCollisionEntryRemove (Trans.trTaskId_gg00, LockTransId, LockTransIndex, Oid, ObjTransInfo);
+}
+
+
 /*---------------------------------------------------------------------------*/
 
 externCpp tsp00_Bool
