@@ -669,7 +669,15 @@ externC tsp01_CommErr_Enum  SqlAPing (   char*                          pszServe
       }
       else
       {
-          commError = os23XServerPing( pszServerNode, szServerVersion, pErrText ) ;
+          if (strlen (pszServerNode) >= sizeof (SQL_NODEIDC))
+          {
+              eo46BuildErrorStringRC ( pErrText, ERRMSG_COM_SERVER_NODE_NAME_TOO_LONG, 0 );
+              commError = commErrNotOk_esp01;
+          }
+          else
+          {
+              commError = os23XServerPing( pszServerNode, szServerVersion, pErrText ) ;
+          }
       }
     }
   }
@@ -879,6 +887,26 @@ VOID sql03u_xconnect (PSZ               pszServerNode,
   ULONG                     ulMaxReplyDataLen;
 
   DBGIN;
+  if (strlen (pszServerDB) >= sizeof (SQL_DBNAMEC))
+  {
+      eo46BuildErrorStringRC ( pErrText, ERRMSG_COM_SERVERDB_NAME_TOO_LONG, 0 );
+      *pRC = commErrNotOk_esp01;
+      return;
+  }
+
+  if (strlen (pszServerDBRoot) >= sizeof (tsp00_Pathc))
+  {
+      eo46BuildErrorStringRC ( pErrText, ERRMSG_COM_SERVERDBROOT_NAME_TOO_LONG, 0 );
+      *pRC = commErrNotOk_esp01;
+      return;
+  }
+
+  if (strlen (pszServerPgm) >= sizeof (tsp00_Pathc))
+  {
+      eo46BuildErrorStringRC ( pErrText, ERRMSG_COM_SERVERPGM_NAME_TOO_LONG, 0 );
+      *pRC = commErrNotOk_esp01;
+      return;
+  }
 
   *pRC = sql03u_connect (pszServerNode,
                           pszServerDB,
@@ -1644,6 +1672,7 @@ static LONG sql03u_get_protocol ( PSZ                    pszServerNode,
   SQL_NODEIDC             szNodeName;
   LONG                    rc;
   int                     IsSaprouterString = FALSE ;
+  SQL_NODEIDC             tmpNodeName;
 
   DBGIN;
 
@@ -1664,50 +1693,55 @@ static LONG sql03u_get_protocol ( PSZ                    pszServerNode,
   }   
 
   if ( ulServerNodeLen != 0 )
-    {
-    if ( szLocalNodeName[0] == '\0' )
+  {
+      if ( szLocalNodeName[0] == '\0' )
       {
-      rc = sql43_get_my_host_name ( szNodeName, sizeof(szNodeName) );
+          rc = sql43_get_my_host_name ( szNodeName, sizeof(szNodeName) );
 
-      if (( rc == NO_ERROR ) && ( ulTCPIP_InitResult == TCPIP_INIT_OK ))
-        {
-        rc = sql43_get_official_node_name ( szNodeName, szLocalNodeName,
-                                            sizeof(szLocalNodeName));
+          if (( rc == NO_ERROR ) && ( ulTCPIP_InitResult == TCPIP_INIT_OK ))
+          {
+              rc = sql43_get_official_node_name ( szNodeName, szLocalNodeName,
+                  sizeof(szLocalNodeName));
 
-        if ( rc != NO_ERROR )
-          strcpy ( szLocalNodeName, szNodeName );
-        }
-      else
-        strcpy ( szLocalNodeName, szNodeName );
-      DBG3 (( MF__, "Local node: '%s'", szLocalNodeName ));
+              if ( rc != NO_ERROR )
+                  strcpy ( szLocalNodeName, szNodeName );
+          }
+          else
+              strcpy ( szLocalNodeName, szNodeName );
+          DBG3 (( MF__, "Local node: '%s'", szLocalNodeName ));
       }
 
-    IsSaprouterString = eo40NiIsSaprouterSring ( pszServerNode ) ;
+      IsSaprouterString = eo40NiIsSaprouterSring ( pszServerNode ) ;
 
-    if ( !IsSaprouterString )
+      if ( !IsSaprouterString )
       {    
+          if (strlen (pszServerNode) >= sizeof (SQL_NODEIDC))
+          {
+              eo46BuildErrorStringRC ( pErrText, ERRMSG_COM_SERVER_NODE_NAME_TOO_LONG, 0 );
+              DBGOUT;
+              return (-1);
+          }
 
-      if (strlen (pszServerNode) >= sizeof (SQL_NODEIDC))
-      {
-          eo46BuildErrorStringRC ( pErrText, ERRMSG_COM_SERVER_NODE_NAME_TOO_LONG, 0 );
-          DBGOUT;
-          return (-1);
-      }
+          strcpy (tmpNodeName, pszServerNode);
+          if (NULL != strchr(tmpNodeName, ':'))
+          {
+              //port is removed from tmpNodeName 
+              memset (strchr(tmpNodeName, ':'), '\0', 1);
+          }
 
-      if (( sql43_is_inet_addr(pszServerNode)   == TRUE ) || 
-          ( stricmp(pszServerNode, "localhost") == 0 ))
-      {
-        strcpy ( szNodeName, pszServerNode );
+          if (!sql43_is_inet_addr(tmpNodeName) && 
+              strnicmp(tmpNodeName, "localhost", strlen("localhost")) != 0)
+          {
+              rc = sql43_get_official_node_name (tmpNodeName, szNodeName, sizeof(szNodeName));
+              if ( rc != NO_ERROR )
+                  strcpy ( szNodeName, tmpNodeName);
+          }
+          else
+          {
+             strcpy (szNodeName, pszServerNode);
+          }
       }
-      else
-        {
-        rc = sql43_get_official_node_name ( pszServerNode, szNodeName,
-                                            sizeof(szNodeName) );
-        if ( rc != NO_ERROR )
-          strcpy ( szNodeName, pszServerNode );
-        }
-      }
-    }
+  }
 
   // ---  Default server type
   if ( IsSaprouterString )
