@@ -304,6 +304,7 @@ ULONG  sql33c_connect ( PCONNECT_PARAM_REC      pConnParam,
 
    if ( ulCommState != commErrOk_esp01 )
      {
+	 sql33c_free_flag_comm_seg ( hFCS, pFCS, NULL );
      DBGOUT;
      return ( ulCommState );
      }
@@ -1245,9 +1246,12 @@ ULONG sql33c_release ( PSHM_CONNECT_INFO_REC   pShmConnInfo,
        }
 
      if ( ulCommState == commErrOk_esp01 )
+	   {
        ulCommState = sql33c_free_comm_seg( pShmConnInfo->hCS,
                                            pShmConnInfo->pCSHeader,
                                            pErrText );
+	   pShmConnInfo->pCSHeader = NULL;
+	   }
      }
 
   if ( ulCommState == commErrOk_esp01 )
@@ -1265,9 +1269,12 @@ ULONG sql33c_release ( PSHM_CONNECT_INFO_REC   pShmConnInfo,
   #endif
 
   if (( ulCommState == commErrOk_esp01 ) && ( pShmConnInfo->pFCS != NULL ))
+    {
     ulCommState = sql33c_free_flag_comm_seg ( pShmConnInfo->hFCS,
                                               pShmConnInfo->pFCS,
                                               pErrText );
+	pShmConnInfo->pFCS = NULL;
+    }
   if ( ulCommState != commErrOk_esp01 )
     {
     // --- close without error handling !
@@ -1275,6 +1282,12 @@ ULONG sql33c_release ( PSHM_CONNECT_INFO_REC   pShmConnInfo,
     sql33c_close_all_server_sems ( pShmConnInfo, NULL );
     sql33c_close_server_process ( pShmConnInfo->hServerProcess, NULL );
 
+	if ( pShmConnInfo->pFCS != NULL )
+      sql33c_free_flag_comm_seg( pShmConnInfo->hFCS, pShmConnInfo->pFCS, NULL );
+
+	if ( pShmConnInfo->pCSHeader != NULL )
+	    sql33c_free_comm_seg( pShmConnInfo->hCS, pShmConnInfo->pCSHeader, NULL );
+
     #if !defined (KERNEL)
      sql33c_close_client_sem     ( pShmConnInfo->hClientSem, NULL );
     #endif
@@ -1938,7 +1951,7 @@ static ULONG  sql33c_create_comm_seg( ULONG                 ulCSSize,
   pszPath = SHM_COMMSEG;
   pszName = pszClientObjName;
 
-  rc = sql41c_create_shrd_mem ( (PVOID*) ppCSHeader, ulCSSize,
+  rc = sql41c_create_shrd_mem ( (PVOID*) ppCSHeader, ulCSSize, ulCSSize,
                                 pszPath, pszName,
                                 pWorldSA,
                                 phCS );
