@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -46,6 +47,7 @@
 #include "geo007_2.h"
 #include "gos44.h"
 
+#include "SAPDBCommon/SAPDB_string.h"
 
 /*
  *  DEFINES
@@ -136,7 +138,7 @@ tsp00_Int sql44c_get_dev_type_by_filename ( char * pszName )
 
   // --- Convert diagnostic file name to uppercase
   strncpy (szName, pszName, sizeof (PATHNAME) - 1);
-  szName[sizeof(PATHNAME)] = '\0';
+  szName[sizeof(PATHNAME)-1] = '\0';
   strupr(szName);
 
    //
@@ -305,7 +307,7 @@ tsp00_Bool sql44c_subst_log_parts ( char*  pszOutName,
   #undef  MF__
   #define MF__ MOD__"sql44c_subst_log_parts"
 
-  PATHNAME                               szVarName;
+  SAPDB_Char                            *szVarName;
   PSZ                                    pszResult;
   PCHAR                                  pch1stPercent;
   PCHAR                                  pch2ndPercent;
@@ -328,7 +330,7 @@ tsp00_Bool sql44c_subst_log_parts ( char*  pszOutName,
 
     if (cbOutLength > sizeof (PATHNAME))
       {
-      strcpy (pszOutName, pszInName);
+      SAPDB_strncpy_zero_terminated (pszOutName, pszInName, sizeof (PATHNAME)-(cbOutLength-cbLength));
       return (FALSE);
       }
 
@@ -343,10 +345,11 @@ tsp00_Bool sql44c_subst_log_parts ( char*  pszOutName,
        * environment variable found:
        * scan environment for result string
        */
+
       cbLength = pch2ndPercent - pch1stPercent - 1;
-      strncpy (szVarName, pch1stPercent+1, cbLength);
+      szVarName = (SAPDB_Char *)alloca(cbLength+1);
+      SAPDB_strncpy_zero_terminated(szVarName,pch1stPercent+1,cbLength+1);
       strupr  (szVarName);
-      *(szVarName+cbLength) = '\0';
 
       GETENV ( szVarName, &pszResult );
 
@@ -361,7 +364,7 @@ tsp00_Bool sql44c_subst_log_parts ( char*  pszOutName,
 
         if (cbOutLength > sizeof(PATHNAME))
           {
-          strcpy (pszOutName, pszInName);
+          SAPDB_strncpy_zero_terminated (pszOutName, pszInName, sizeof (PATHNAME)-(cbOutLength-cbLength) );
           return (FALSE);
           }
 
@@ -380,7 +383,7 @@ tsp00_Bool sql44c_subst_log_parts ( char*  pszOutName,
 
         if (cbOutLength > sizeof(PATHNAME))
           {
-          strcpy (pszOutName, pszInName);
+          SAPDB_strncpy_zero_terminated (pszOutName, pszInName, sizeof (PATHNAME)-(cbOutLength-cbLength) );
           return (FALSE);
           }
 
@@ -402,7 +405,7 @@ tsp00_Bool sql44c_subst_log_parts ( char*  pszOutName,
 
       if (cbOutLength > sizeof(PATHNAME))
         {
-        strcpy (pszOutName, pszInName);
+        SAPDB_strncpy_zero_terminated (pszOutName, pszInName, sizeof (PATHNAME)-(cbOutLength-strlen (pch1stPercent)) );
         return (FALSE);
         }
 
@@ -420,7 +423,7 @@ tsp00_Bool sql44c_subst_log_parts ( char*  pszOutName,
 
     if (cbOutLength > sizeof(PATHNAME))
       {
-      strcpy (pszOutName, pszInName);
+      SAPDB_strncpy_zero_terminated (pszOutName, pszInName, sizeof (PATHNAME)-(cbOutLength-strlen (pch2ndPercent+1)) );
       return (FALSE);
       }
 
