@@ -805,22 +805,30 @@ _INLINE VOID __os74SearchRUN ( PUKT_CTRL_REC    pUKT,
       if ( pTempTaskCtrl->PrioFlag ) 
         pUKT->ulImmediateDispatch++;
 
-      if ( HighestPrioTask == pTempTaskCtrl )  // More than one queue element for the same task found?
-        {
-        if ( REQ_RESCHEDULE_EO00 == pRUNQue[uldx].pRequest->ulReqType ) // Yield request?
-          {   // We have use the yield element first because the task 
-              // is waiting for the yield request first.
-          HighestPrioTask = pTempTaskCtrl;
-          RunIndex        = uldx;
-          }
+      if ( REQ_DEBUG_TASK == pRUNQue[uldx].pRequest->ulReqType )
+        { 
+        HighestPrioTask = pTempTaskCtrl;
+        RunIndex        = uldx;
+        break;
         }
-      else if ( HighestPrioTask->ulDynPrio < pTempTaskCtrl->ulDynPrio ) 
+
+      if ( REQ_RESCHEDULE_EO00 == pRUNQue[uldx].pRequest->ulReqType ) // Yield request?
+        pTempTaskCtrl->yieldRequestAtPos = uldx;
+
+      if ( HighestPrioTask->ulDynPrio < pTempTaskCtrl->ulDynPrio ) 
         { 
         HighestPrioTask = pTempTaskCtrl;
         RunIndex        = uldx;
         }
       }
 
+    if ( (SAPDB_UInt4)-1 != HighestPrioTask->yieldRequestAtPos )
+      {   
+      // Swap run queue index because yield has to be served first
+      RunIndex = HighestPrioTask->yieldRequestAtPos;
+      HighestPrioTask->yieldRequestAtPos = (SAPDB_UInt4)-1;
+      }
+
     HighestPrioTask->QueLocation = TASK_IS_IN_NON_QUEUE;
     HighestPrioTask->ulDynPrio   = 0;
 
@@ -1070,7 +1078,7 @@ _INLINE VOID __os74SearchUKT ( PUKT_CTRL_REC    pUKT,
 
         case REQ_DEBUG_TASK:
 #         if defined ( ALLOW_TASK_DEBUG_REQUESTS )
-           if ( (*ppCTask)->fDebugTask == FALSE )
+           if ( (*ppCTask)->TaskState != TSK_INACTIVE && (*ppCTask)->fDebugTask == FALSE )
            {
              (*ppCTask)->fDebugTask = TRUE;
              ulBasePrio = (UINT)-1; // - maximum priority
@@ -1114,8 +1122,9 @@ _INLINE VOID __os74SearchUKT ( PUKT_CTRL_REC    pUKT,
             {
                 PTASK_CTRL_REC  pTempTaskCtrl = pUKT->RUNQue[uldx].pTaskCtrl;
 
-                // long term move lock set?
-                if ( pTempTaskCtrl->MoveLock.Type.LongTerm == 0 ) 
+                // long term move lock set, or task was not in run queue?
+                if (( pTempTaskCtrl->MoveLock.Type.LongTerm != 0 ) || 
+                    ( pTempTaskCtrl->TaskStateStat.runqueueEnqueueTime == 0 ))
                     continue;
 
                 RunnableMicroSeconds = timeNow - pTempTaskCtrl->TaskStateStat.runqueueEnqueueTime;
@@ -1570,6 +1579,10 @@ void __os74DoLeaveDispatcherTiming( PTASK_CTRL_REC pCurrTaskCtrl )
         pUKT->MaxRunnableMicroSeconds[CurrUKTTimeVar] = RunnableMicroSeconds;
     }
   }
+  else
+  {
+      pCurrTaskCtrl->TaskStateStat.runqueueEnqueueTime = timeNow;
+  }
 }
 
 /*------------------------------*/
@@ -1729,7 +1742,7 @@ SAPDB_Bool __os74TaskMoveCheck( PUKT_CTRL_REC *ppSrcUKT, PUKT_CTRL_REC *ppDstUKT
           MicroSecondsCompare = (*ppSrcUKT)->MaxRunnableMicroSeconds[PrevTimeVar];
           break;
         case TASK_MOVE_TIME_COMP_EQUAL:
-          if (( *ppSrcUKT == NULL ) ||( pTmpUKT->RunnableMicroSeconds > (*ppSrcUKT)->RunnableMicroSeconds ))
+          if (( *ppSrcUKT == NULL ) ||( pTmpUKT->RunnableMicroSeconds[PrevTimeVar] > (*ppSrcUKT)->RunnableMicroSeconds[PrevTimeVar] ))
             {
             *ppSrcUKT           = pTmpUKT;
             MicroSecondsCompare = (*ppSrcUKT)->MaxRunnableMicroSeconds[PrevTimeVar];
