@@ -77,6 +77,14 @@
 #define HEURISTICS_HIBERNATION_POS    6
 #define MAX_UKT_START_WAIT_TIME       60      // -- sleep time
 
+#if defined (_WIN64)
+# define RESERVED_COMMUNICATION_FLAGS 10000
+# define RESERVED_UKTS                5000
+#else
+# define RESERVED_COMMUNICATION_FLAGS 5000
+# define RESERVED_UKTS                1000
+#endif
+
 /*
  *  MACROS
  */
@@ -407,6 +415,7 @@ static void sql81PrintStartUpInformation ( )
   PSZ                    ProductSuite;
   ULONG                  majorVersion;
   ULONG                  ulNumOfPhysicalProcessors;
+  SAPDB_Char             CPUType[64];
 
   MSGD (( INFO_DB_START_SERVERDB,   kgs.szServerDB ));
   /* PTS 1116151 */
@@ -458,11 +467,14 @@ static void sql81PrintStartUpInformation ( )
   if ( ProductSuite )
     MSGD (( INFO_DB_START_PRODUCT_SUITE, ProductSuite));
 
+  if( true == RTESys_GetCPUType(  CPUType, 64 ))
+	MSGD (( INFO_DB_START_MACHINE, CPUType ));
+
   ulNumOfPhysicalProcessors = RTESys_NumberOfPhysicalCPUs( );
   if ( kgs.ulNumOfProcessors != ulNumOfPhysicalProcessors )
     MSGD (( INFO_DB_START_NUM_LOGICAL_PROCESSORS, ulNumOfPhysicalProcessors, kgs.ulNumOfProcessors ))
   else
-    MSGD (( INFO_DB_START_NUM_POROCESSORS, kgs.ulNumOfProcessors ));
+    MSGD (( INFO_DB_START_NUM_PROCESSORS, kgs.ulNumOfProcessors ));
 
   MSGD (( INFO_DB_START_FIBER, XPARAM(fUseFibers) ? "YES" : "NO" ));
   MSGD (( INFO_DB_START_MAX_ADDRESS,           TotalVirtual >> 20 ));
@@ -1413,6 +1425,7 @@ static LONG sql81k_init_kernel_shared_segments ( VOID )
   LONG                   rc;
   HANDLE                 hShrdMem;
   ULONG                  ulNumOfSemaphores;
+  ULONG                  reservSize;
 
   DBGIN;
 
@@ -1420,7 +1433,7 @@ static LONG sql81k_init_kernel_shared_segments ( VOID )
   // --- create kernel shared section
   //
   kgs.ulKSSSize = sizeof (KERNEL_SHARED_SEG);
-  rc = sql41c_create_shrd_mem ((PPVOID)&pkss, kgs.ulKSSSize,
+  rc = sql41c_create_shrd_mem ((PPVOID)&pkss, kgs.ulKSSSize, kgs.ulKSSSize,
                                SHM_KSS, kgs.szServerDB,
                                &kgs.WorldSA,
                                &hShrdMem);
@@ -1454,8 +1467,16 @@ static LONG sql81k_init_kernel_shared_segments ( VOID )
                       (ulNumOfSemaphores    * sizeof(ULONG)) +
                       (ulNumOfSemaphores    * sizeof(IPC_BASE_OBJ_NAME));
 
-  rc = sql41c_create_shrd_mem ((PPVOID)&pfcs, kgs.ulFCSSize,
-                               SHM_FCS, kgs.szServerDB,
+  // If a client keeps the shared memory open and we have reconfigured the
+  // user or UKT count, its not posible to established the shared memory with the new 
+  // The reservation helps us.                      
+  reservSize  = sizeof (FLAG_COMM_SEG)                                                        +
+                        ((kgs.ulNumOfCommFlags + RESERVED_COMMUNICATION_FLAGS ) * sizeof(ULONG)) +
+                        ((ulNumOfSemaphores    + RESERVED_UKTS)                 * sizeof(ULONG))                                 +
+                        ((ulNumOfSemaphores    + RESERVED_UKTS)                 * sizeof(IPC_BASE_OBJ_NAME));
+
+  rc = sql41c_create_shrd_mem ((PPVOID)&pfcs, reservSize, kgs.ulFCSSize,                               
+	                           SHM_FCS, kgs.szServerDB,
                                &kgs.WorldSA,
                                &hShrdMem);
 
