@@ -48,7 +48,9 @@
 #include		   "geo007_1.h"
 #include		   "gos962.h"
 #include		   "geo908.h"
-#include           "hsp100.h" /* nocheck */
+#include           "hsp100.h"   /* nocheck */
+#include           "gsp09.h"
+
 /*===========================================================================*
  *  DEFINES                                                                  *
  *===========================================================================*/
@@ -725,7 +727,7 @@ static ULONG os962NiGetRequest ( PTCPIP_SERV_CONNECT_INFO_REC pConnInfo )
       ConPktParamRec.szReceiverServerDB[0] = '\0';
       ConPktParamRec.ulReceiverRef         = ConPktParamRec.ulSenderRef;
       ConPktParamRec.ulSenderRef           = (ULONG)UNDEF;
-      ConPktParamRec.usServicePort         = UNDEF; /* unused */
+      ConPktParamRec.usServicePort         = UNDEF; /* unused for NI connects */
       ConPktParamRec.ulMaxSegmentSize      = gxr.NICoord.ulMaxSegmentSize;
       ConPktParamRec.ulMessClass           = RSQL_INFO_REPLY_EO003;
       ConPktParamRec.ulCommState           = ulCommState;
@@ -940,10 +942,13 @@ static ULONG os962NiGetRequest ( PTCPIP_SERV_CONNECT_INFO_REC pConnInfo )
       break;
 
     default :
-      MSGALL (( ERR_XSER_ILL_FRST_MESS_CLASS,
-                ConPktParamRec.ulMessClass ));
-      ulCommState                = commErrNotOk_esp01;
-      ConPktParamRec.ulCommState = commErrNotOk_esp01;
+      MSG8 (( INFO_NI_SERV_ILL_FRST_MESS_CLASS, ConPktParamRec.ulMessClass ));
+      pConnInfo->ulConnStatus       = CON_KEEP_ALIVE_EO003;
+      ulCommState                   = commErrOk_esp01;    /* do not force a disconnect! */
+      ConPktParamRec.ulCommState    = commErrRequestUnknown_esp01;
+      ConPktParamRec.ulMessClass    = RSQL_REQUEST_UNKNOWN_REPLY_EO003;
+      ConPktParamRec.ulReceiverRef  = pConnInfo->ulSenderRef;
+      ConPktParamRec.ulSenderRef    = 0;
       break;
     }
 
