@@ -91,7 +91,7 @@ UDWORD pa60_ComputePosition (UDWORD           long_pos,
 tsp00_Int pa60_ComputeKernelPosition (UDWORD           long_pos,
                                       tpa21DescRecord *impl_rec_ptr);
 int pa60_isConnected (tpa40DBC *dbc_block_ptr);
-void pa60_initFetchChunk(sqlmfentry *fChunk);
+static void pa60_initFetchChunk(sqlmfentry *fChunk);
 /*!**********************************************************************
 
   Chapter: ODBC functions
