@@ -501,7 +501,7 @@ void pr01cBeg(tpr01_SQLDesc *SQLDesc)
                   p01pparsidtrace(sqlca, sqlxa, ka, ka->kaParseInfo.ParseId, TraceParseIDSQLStmt_epr00);
                   cmdfetch = cpr_is_true;
                   p01adbsexecute (sqlca, sqlxa, gae, ka, ore, cu, &cmdfetch, &SQLDesc->MessType, true);
-                  pr04LongRemoveDescriptors (sqlca);
+                  pr04LongRemoveDescriptors (sqlca, gae);
                   if (ka->kastate != cpr_state_parse)
 		    {
                       /* nur wenn nicht parse again */
@@ -908,7 +908,7 @@ void pr01cDynmfetch(tpr01_SQLDesc *SQLDesc)
               }
 	    else
               {
-	        *sqlloop = (sqlpa->lo.paloopmin==0) ? 1 : sqlpa->lo.paloopmin;
+	        *sqlloop = (sqlpa->lo.paloopmin==0) ? 32768 : sqlpa->lo.paloopmin;
               }
           }
         else
@@ -970,7 +970,7 @@ void pr01cDescribe(tpr01_SQLDesc *SQLDesc)
       if (CursorDesc){
         ore = CursorDesc->StmtNameDesc->ore;
         stmtParseInfo = &(CursorDesc->StmtNameDesc->ka->kaParseInfo);
-        PacketEncoding = CursorDesc->StmtNameDesc->SQLStatement->encodingType;
+        PacketEncoding = SQLDesc->PacketEncoding;
       }
       else if (SQLDesc->StmtNameDesc->StmtTypeDesc.CursorLength == 0){
         /*unlabeled resultset*/      
@@ -995,7 +995,7 @@ void pr01cDescribe(tpr01_SQLDesc *SQLDesc)
       /*describe for prepared command*/ 
         ore = SQLDesc->ore;
         stmtParseInfo = &(SQLDesc->ka->kaParseInfo);
-        PacketEncoding = SQLDesc->StmtNameDesc->SQLStatement->encodingType;
+        PacketEncoding = SQLDesc->PacketEncoding;
         if (  sqlca->sqldbmode == cpr_kind_internal
             ||SQLDesc->ComType != cpr_com_ora_descr_sel)
           descKind = Describe_Params_epr00;
