@@ -866,8 +866,9 @@ void pr02ConAnalyzeConnectStmt (sqlcatype *sqlca, sqlxatype *sqlxa, sqlgatype* s
                           p03encrypt (passw, ga->gaxuserrec.xu_passwordUCS2);
                         else {
                           tsp00_Pw xupassw;
+                          tsp00_Uint4 xupasswLen = (encodingType != sp77encodingAscii)?2*sizeof (xupassw):sizeof (xupassw);
                           ConvRes = sp78convertString (sp77encodingAscii, xupassw, sizeof (xupassw), &dlen, 
-                                                       TRUE, encodingType, rawString, sizeof (xupassw), &slen);
+                                                       TRUE, encodingType, rawString, xupasswLen, &slen);
                           p03encrypt (xupassw, ga->gaxuserrec.xu_password);
                         }
                       }
