@@ -56,9 +56,9 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-  void pr04LongGetHostInfo(sqlcatype *sqlca, sqlxatype *sqlxa, 
+  void pr04LongGetHostInfo(sqlcatype *sqlca, sqlxatype *sqlxa, sqlgaentry *ga,
 			   tpr_longvarcharrec *lvcrec, char inp);
-  void pr04LongInitLD(sqlcatype *sqlca, sqlxatype *sqlxa);
+  void pr04LongInitLD(sqlcatype *sqlca, sqlxatype *sqlxa, sqlgaentry *ga);
   void pr04LongLvcInitRec (sqlcatype *sqlca, tpr_longvarcharrec *lvcrec);
   bool pr04LongILvcOneRecord (sqlcatype*, sqlxatype*, sqlgaentry*,
 			      tpr00_ParseId*, tsp1_part_ptr,
@@ -68,16 +68,16 @@ extern "C" {
 			  struct tpr_sqlloop);
   bool pr04LongGetvalOutput (sqlcatype*, sqlxatype*, sqlgaentry*, int);
   bool pr04LongCloseDescriptors (tpr01_ConDesc*); 
-  void pr04LongRemoveDescriptors (sqlcatype*);
+  void pr04LongRemoveDescriptors (sqlcatype*, sqlgaentry*);
   boolean pr04LongPOdbcData (sqlcatype *sqlca, sqlxatype *sqlxa,
 			     sqlgaentry *ga, tpr_longvarcharrec *lvcrec,
 			     tsp00_Int2 *spindex, bool *first);
   boolean pr04LongGOdbcData (sqlcatype *sqlca, sqlxatype *sqlxa,
 			     sqlgaentry *ga, tpr_longvarcharrec *lvcrec,
 			     tsp00_Int2 *spindex);
-  boolean pr04LongOdbcColIsTrunc (sqlcatype *sqlca, int colno);
+  boolean pr04LongOdbcColIsTrunc (sqlcatype *sqlca, sqlgaentry *ga, int colno);
   void pr04LongTraceInit (sqlcatype *sqlca, int trtxt, tsp00_Lname *vnam, int colno);
-  boolean pr04LongGetTotalLength (sqlcatype *sqlca, int ind, int *len);
+  boolean pr04LongGetTotalLength (sqlcatype *sqlca, sqlgaentry *ga, int ind, int *len);
 #ifdef __cplusplus
 }
 #endif
