@@ -423,7 +423,7 @@ p04oradin (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, sqlcuentry *cu
   tsp1_packet *pck = (tsp1_packet*) gae->gareqptr;
   tsp1_segment *seg = (tsp1_segment *) sqlca->sqlrap->rasegptr;
   struct SQLDA   *da = (struct SQLDA *) sqlda;
-  struct SQLLD   *ldp = sqlca->sqlrap->rasqlldp;
+  struct SQLLD   *ldp = gae->gasqlldp;
   tsp00_Int2       *ldmaxi = &ldp->ldmaxi;
   tsp00_Int2       *ldcolkind = &ldp->ldcolkind;
   char           *allsend = &ldp->ldallsend;
@@ -467,7 +467,7 @@ p04oradin (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, sqlcuentry *cu
     ka = sqlxa->xaSQLDesc->ka;
 
     da->sqloffset = 0;
-    da->sqlloop = (ka->kapaindex == 0) ? 1 : (ka->kapaindex < 0)
+    da->sqlloop = (ka->kapaindex == 0) ? 32768 : (ka->kapaindex < 0)
       ? 2 : (p08runtimeerror (sqlca, sqlxa, cpr_not_implemented), 0);
   }
   p04mode (sqlca, gae);
@@ -493,7 +493,7 @@ p04oradin (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, sqlcuentry *cu
       else {
 	trfirst = 1;
 	lp->lpcnt = lpcnt;
-	pr04oPutResultCount(cnt, lpcnt);
+	pr04oPutResultCount(cnt, 32768);
       }
     }
   }
@@ -586,7 +586,7 @@ p04oradin (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, sqlcuentry *cu
           if (vl == 0 && sqlca->sqlrap->rakamode == CPR_KIND_ORACLE)
             *I = CPR_NULL_DATA;
           if (datapart->sp1p_part_header.sp1p_buf_size > col->colpos + lppos) {
-            p04coltobuf (sqlca->sqlrap, (char*)data, &datapart->sp1p_part_header.
+            p04coltobuf (sqlca->sqlrap, gae, (char*)data, &datapart->sp1p_part_header.
                          sp1p_buf_len, col, (char*)name, V, vt, vl, (tsp00_Int2) vl,
                          vf, *I, lppos, i + 1, sqlca->sqlemp);
             err = (char) sqlca->sqlemp->eprerr;
@@ -641,7 +641,7 @@ p04oradin (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, sqlcuentry *cu
 	      && *pid != csp1_p_mass_command
 	      && *pid != csp1_p_for_upd_mselect_found
 	      && *pid != csp1_p_reuse_upd_mselect_found)
-	    pr04oPutResultCount(cnt, lpcnt);
+	    pr04oPutResultCount(cnt, 32768);
 	}
 	else {
 	  /* PTS 1103453 */
@@ -660,7 +660,7 @@ p04oradin (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, sqlcuentry *cu
 	p03csqlemptosqlca (sqlca, sqlca->sqlemp);
 	if (da->sqlloop != 0) {
 	  lppos = datapart->sp1p_part_header.sp1p_buf_len;
-	  pr04LongInitLD (sqlca, sqlxa);
+	  pr04LongInitLD (sqlca, sqlxa, gae);
 	  if (*allsend && sqlca->sqlcode == 0) {
 	    short sint = (short) sqlca->sqlerrd[2];
 
@@ -721,7 +721,7 @@ p04oradin (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, sqlcuentry *cu
 	sqlca->sqlemp->ereturncode = 0;
 	sqlca->sqlemp->eprerr   = cpr_p_ok;
       }
-  if (!sqlca->sqlrap->rasqlldp->ldallsend
+  if (!gae->gasqlldp->ldallsend
       && datapart->sp1p_part_header.sp1p_buf_len > 0)
     s26finish_part (pck, datapart);
   else {
@@ -739,7 +739,7 @@ p04oradout (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, void *sqlda,
   tsp1_segment *seg = (tsp1_segment *) sqlca->sqlrap->rasegptr;
   struct SQLERROR *em = sqlca->sqlemp;
   struct SQLDA   *da = (struct SQLDA *) sqlda;
-  struct SQLLD   *ldp = sqlca->sqlrap->rasqlldp;
+  struct SQLLD   *ldp = gae->gasqlldp;
   tsp00_Int2       *ldmaxo = &ldp->ldmaxo;
   tsp00_Int2       *ldcolkind = &ldp->ldcolkind;
   tsp00_Int2        dbmode = sqlca->sqlrap->rakamode;
@@ -759,7 +759,7 @@ p04oradout (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, void *sqlda,
   tsp00_Int4        vl;
   tsp00_Int4        pnofirst;
   tsp00_Int4        errd3;
-  int             i;
+  int             i, j;
   char            err, rownotfound;
   int             cntlen;
   tsp1_part *datapart;
@@ -900,7 +900,7 @@ p04oradout (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, void *sqlda,
       }
       err = cpr_p_ok;
       p04orat (da->L[i], da->T[i], S, C, (char*)name, &vt, &vl, &vf, &err, sqlxa);
-      p04colfrombuf (sqlca->sqlrap, (char*)data,
+      p04colfrombuf (sqlca->sqlrap, gae, (char*)data,
 		     &datapart->sp1p_part_header.sp1p_buf_len, col,
 		     (char*)name, V, vt, vl, (tsp00_Int2) vl, vf, &ival,
 		     *lppos, i + 1, sqlca->sqlemp);
@@ -955,6 +955,8 @@ p04oradout (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, void *sqlda,
     lp->lpnext = cpr_is_false;
   }
   else {
+    tsp00_Int4 tmplppos = 0;
+    tsp00_Int4 tmpnextlpcnt = 0;
     errd3 = (sqlca->sqlcode == 0) ? lpind : lpind - 1;
     lp->lperrd3 += errd3;
     lp->lpindo = (short) (errd3 + pnofirst);
@@ -973,6 +975,65 @@ p04oradout (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, void *sqlda,
 	lp->lpnext = cpr_is_true;
       }
     }
+#ifndef SQLODBC
+    if (lppos && (da->sqlloop != 0))
+      tmplppos = *lppos;
+    else if (lppos && (da->sqlloop == 0))
+      tmplppos = lp->lpreclo;
+#else
+    if (lppos)
+      tmplppos = *lppos;
+#endif
+    if (nextlpcnt) {
+      tmpnextlpcnt = *nextlpcnt;
+      if (da->sqlloop == 0)
+        tmpnextlpcnt--;
+    }
+    if (lp->lpreclo > 0) {
+      for (j = tmplppos / lp->lpreclo; j < lpcnt + tmpnextlpcnt; j++) {
+        int outpfound = 0;
+        struct SQLLD   **ld = &gae->gasqlldp;
+        for (i = 0; i < PR07MIN(da->N,da->F) ; i++) {
+          struct SQLCOL *col = da->sqlcol + i;
+          
+          if (col->colislong == CPR_OLDLONG) {
+            struct SQLSPLD *ldldsp;
+            struct SQLPCLD *ldldpc;
+            struct OLDSQLSPLD *ldsp, tmpldsp;
+            struct SQLPCLD *ldpc;
+            tsp00_Int4      pos = col->colpos + tmplppos;
+            char           *buf = (char *) data + pos;
+            
+            if (col->colio == CPR_INFO_INPUT)
+              continue;
+            outpfound = 1;
+            
+            memcpy (&tmpldsp, buf+1, sizeof (tmpldsp));
+            if (tmpldsp.ld_valmode == vm_datapart) {
+              
+              ldldsp = (struct SQLSPLD*) p03dynalloc (&(*ld)->ldsp_mdesc);
+              ldsp = &(*ld)->ldsp[(*ld)->ldmaxo+(*ld)->ldmaxoc].ld.o;
+              
+              ldldsp->ldkind = cpr_is_false;
+              ldldsp->ldlength = sizeof (*ldsp);
+              (*ld)->ldcolkind = cpr_is_true;
+              memcpy (ldsp, ++buf, sizeof (*ldsp));
+              ldsp->ld_valind = (*ld)->ldmaxo+(*ld)->ldmaxoc + 1;
+              
+              ldldpc = (struct SQLPCLD*) p03dynalloc (&(*ld)->ldpc_mdesc);
+              ldpc = &(*ld)->ldpc[(*ld)->ldmaxo+(*ld)->ldmaxoc];
+              
+              memset (ldpc, 0, sizeof(*ldpc));
+              
+              ++(*ld)->ldmaxoc;
+            }
+          }
+        }
+        if (outpfound) {
+          tmplppos += lp->lpreclo;
+        }
+      }
+    }
   }
   if (lpind == 0 || (rownotfound && sqlca->sqlcode == 0)) {
     em->ereturncode = 100;
